import { inject } from '@angular/core';
import { CanActivateFn, Router } from '@angular/router';
import AuthService from '../auth/auth.service';

export const guardGuard: CanActivateFn = (route, state) => {
  const authService = inject(AuthService);
  const router = inject(Router);
  const perfilRequerido = route.data['permisoRol'];
  const token = authService.tieneToken();
  
  if (token) {
    if (authService.tokenExpirado()) {
      router.navigate(['/']);  // Redirigir al usuario a la página de inicio si el token ha expirado
      return false;
    }
    
    const decodedToken = authService.decodeToken();
    if (decodedToken) {
      if (decodedToken.roles.includes('ADMIN') && perfilRequerido.includes('ADMIN')) {
        return true; // Permitir acceso si el usuario es administrador y se requiere el rol de administrador
      } else if (decodedToken.roles.includes('USUARIO') && perfilRequerido.includes('USUARIO')) {
        return true; // Permitir acceso si el usuario es usuario normal y se requiere el rol de usuario normal
      } else if (decodedToken.roles.includes('ASISTENTE') && perfilRequerido.includes('ASISTENTE')) {
        return true; // Permitir acceso si el usuario es asistente y se requiere el rol de asistente
      } else if (decodedToken.roles.includes('DISTRIBUIDOR') && perfilRequerido.includes('DISTRIBUIDOR')) {
        return true; // Permitir acceso si el usuario es distribuidor y se requiere el rol de distribuidor
      } else if (decodedToken.roles.includes('SOPORTE') && perfilRequerido.includes('SOPORTE')) {
        return true; // Permitir acceso si el usuario es soporte y se requiere el rol de soporte
      } else if (decodedToken.roles.includes('SUPERVISOR') && perfilRequerido.includes('SUPERVISOR')) {
        return true; // Permitir acceso si el usuario es supervisor y se requiere el rol de supervisor
      } else {
        router.navigate(['/']); // Redirigir al usuario a la página de inicio si no tiene los permisos necesarios
        return false;
      }
    } else {
      router.navigate(['/']); // Redirigir al usuario a la página de inicio si no está autenticado
      return false;
    }
  } else {
    router.navigate(['/']);  // Redirigir al usuario a la página de inicio si no está autenticado
    return false;
  }
}
