import { HttpErrorResponse, HttpInterceptorFn } from '@angular/common/http';
import { inject } from '@angular/core';
import { catchError, throwError } from 'rxjs';
import { Router } from '@angular/router';
import AuthService from '../auth/auth.service';
import { ServiceService } from '../service/service.service';
import Swal from 'sweetalert2';

export const authInterceptor: HttpInterceptorFn = (req, next) => {
  const authService = inject(AuthService);
  const router = inject(Router);
  const token = authService.tieneToken();
  const service = inject(ServiceService)

  // Lista de rutas que no requieren autorización
  const urlsSinAutorizacion: string[] = ['/auth/login'];

  // Verificar si la URL actual está en la lista de rutas sin autorización
  if (urlsSinAutorizacion.some(url => req.url.includes(url))) {
    return next(req);
  }

  if (token) {
    const request = req.clone({
      setHeaders: {
        Authorization: `Bearer ${token}`
      }
    });
    return next(request).pipe(
      catchError((error: HttpErrorResponse) => {
        console.error('Error en la solicitud:', error.error); // Registro del error
        if ([401, 403].includes(error.status)) {
          // Manejo de errores de autenticación
          console.error('Error de Permisos:', error.error.message);
          service.logout(); // Asegúrate de tener un método de logout en AuthService para limpiar el token y otros datos de sesión.
          Swal.fire({
            icon: 'error',
            title: 'Error de autenticación',
            text: `${error.error.message}`,
            confirmButtonText: 'Aceptar'
          }).then(() => {
            router.navigate(['/']);
          });
        }
        return throwError(() => error);
      })
    );
  } else {
    return next(req).pipe(
      catchError((error: HttpErrorResponse) => {
        console.error('Error en la solicitud:', error.error); // Registro del error
        if ([401, 403].includes(error.status)) {
          // Manejo de errores de autenticación
          console.error('Error de Permisos:', error.message);
          Swal.fire({
            icon: 'error',
            title: 'Error de autenticación',
            text: `${error.error.message}`,
            confirmButtonText: 'Aceptar'
          }).then(() => {
            router.navigate(['/']);
          });
        }
        return throwError(() => error);
      })
    );
  }
};
