import { CommonModule } from '@angular/common';
import { Component } from '@angular/core';
import { AbstractControl, FormBuilder, FormGroup, ReactiveFormsModule, ValidatorFn, Validators } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../core/service/service.service';
import AuthService from '../../../../core/auth/auth.service';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-cambiarcontra',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './cambiarcontra.component.html',
  styleUrl: './cambiarcontra.component.css'
})
export class CambiarcontraComponent {

  passwordForm: FormGroup;

  constructor(private fb: FormBuilder, private dataservice : ServiceService, private authService: AuthService) {
    this.passwordForm = this.fb.group({
      password: ['', [Validators.required, Validators.minLength(8)]],
      confirmPassword: ['', Validators.required]
    }, { validator: this.passwordMatchValidator });
  }

  passwordMatchValidator: ValidatorFn = (form: AbstractControl) => {
    const password = form.get('password')?.value;
    const confirmPassword = form.get('confirmPassword')?.value;
    if (password !== confirmPassword) {
      form.get('confirmPassword')?.setErrors({ passwordMismatch: true });
    } else {
      form.get('confirmPassword')?.setErrors(null);
    }
    return null;
  }

  decodeDatos: any;

  id = '';

  ngOnInit(): void {
    const decode = this.authService.decodeToken();
    if (decode) {
      this.decodeDatos = decode;
      this.id = this.decodeDatos.idusuario;
    }
  }

  loading = false;

  onSubmit() {
    if (this.passwordForm.valid) {

      this.loading = true;
      if (this.loading) {
        Swal.fire({
          title: 'Cambiando Contraseña ... ',
          html: `
            <style>
              .spinner {
                border: 4px solid rgba(0, 0, 0, 0.1);
                width: 36px;
                height: 36px;
                border-radius: 50%;
                border-left-color: #09f;
                animation: spin 1s linear infinite;
                display: inline-block;
                margin-top: 10px;
              }
        
              @keyframes spin {
                0% {
                  transform: rotate(0deg);
                }
                100% {
                  transform: rotate(360deg);
                }
              }
            </style>
  
            <div class="spinner"></div>
          `,
          icon: 'info',
          allowOutsideClick: false,
          allowEscapeKey: false,
          showConfirmButton: false,
          showCancelButton: false,
          showCloseButton: false,
          timerProgressBar: true,
        });
      }

      const confirmPasswordValue = this.passwordForm.get('confirmPassword')?.value;
      console.log('Confirm Password:', confirmPasswordValue);

      const url = import.meta.env.NG_APP_API + '/distribuidor/restablecer-contrasena/' + this.id  ;

      this.dataservice.putApi(url, { password: confirmPasswordValue }).subscribe({
        next: (data) => {
          Swal.fire(
            {
              title: 'Contraseña cambiada',
              text: 'La contraseña se ha cambiado correctamente',
              icon: 'success',
              confirmButtonText: 'Aceptar'
            }
          ).then(() => {
            window.location.reload();
          
          })
        },
        error: (error) => {
          this.loading = false;
          console.error(error);
          Swal.fire(
            {
              title: 'Error',
              text: 'Ha ocurrido un error al cambiar la contraseña',
              icon: 'error',
              confirmButtonText: 'Aceptar'
            }
          )
        }
      })

    }
  }
}


