import { Component, Inject, Input, inject } from '@angular/core';
import { SeguridadComponent } from './seguridad/seguridad.component';
import { CasosComponent } from './casos/casos.component';
import { ServiceService } from '../../../core/service/service.service';
import AuthService from '../../../core/auth/auth.service';
import { EquiposComponent } from './equipos/equipos.component';
import { PrioridadatencionComponent } from './prioridadatencion/prioridadatencion.component';
import { FallasComponent } from './fallas/fallas.component';
import { TipoMantenimientoComponent } from './tipo-mantenimiento/tipo-mantenimiento.component';
import { SeguimientoComponent } from './seguimiento/seguimiento.component';
import { CasosdistribuidorComponent } from './casosdistribuidor/casosdistribuidor.component';
import { CasossoporteComponent } from './casossoporte/casossoporte.component';
import { CasostotalComponent } from './casostotal/casostotal.component';
import { CasossupervisorComponent } from './casossupervisor/casossupervisor.component';
import { ClientesComponent } from './clientes/clientes.component';
import { ReportesComponent } from './reportes/reportes.component';
import { CasosasistenteComponent } from './casosasistente/casosasistente.component';
import { consumerPollProducersForChange } from '@angular/core/primitives/signals';
import { ModulocasComponent } from './modulocas/modulocas.component';
import { ManualesComponent } from './manuales/manuales.component';
import { SucursalesComponent } from './sucursales/sucursales.component';



@Component({
  selector: 'app-sidebar',
  standalone: true,
  imports: [
    SeguridadComponent,
    CasosComponent,
    EquiposComponent,
    PrioridadatencionComponent,
    FallasComponent,
    TipoMantenimientoComponent,
    SeguimientoComponent,
    CasosdistribuidorComponent,
    CasossoporteComponent,
    CasostotalComponent,
    CasossupervisorComponent,
    ClientesComponent,
    ReportesComponent,
    CasosasistenteComponent,
    ModulocasComponent,
  ManualesComponent,
  SucursalesComponent
    
],
  templateUrl: './sidebar.component.html',
  styleUrl: './sidebar.component.css',
})
export class SidebarComponent {
  @Input() showSidebar = false;
  private dataservice = inject(ServiceService);
  private url = import.meta.env.NG_APP_API;

  public modulos: any[] = [];
  private ordenDeseado: string[] = [
    "Registrar Caso",
    "Clientes",
    "Casos Total",
    "Equipos",
    "Fallas",
    "Manuales",
    "Mantenimiento",
    "Casos Asistente",
    "Sucursales",
    "Reportes",
    "Casos Supervisor",
    "Casos Soporte",
    "Casos Distribuidor",
    "Seguridad",
  ];

  constructor(private AuthService: AuthService) {}
  perfildeSesion = '';
  decodeDatos: any;
  ngOnInit(): void {
    this.cargarModulos();
    this.detectarDispositivo();
    const decode = this.AuthService.decodeToken();
    if (decode) {
      this.decodeDatos = decode;
      this.perfildeSesion = this.decodeDatos.roles;
    }
 
  }

  private cargarModulos(): void {
    const decodedToken = this.AuthService.decodeToken();
    this.dataservice.postApi(`${this.url}/usuarios/modulos`, {
      idusuario: decodedToken?.idusuario
    }).subscribe(modulos => {
      console.log(modulos)
      this.modulos = this.ordenarModulos(modulos);
    });
  }

  private detectarDispositivo(): void {
    const isMobile = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
    this.showSidebar = !isMobile;
  }

  private ordenarModulos(modulos: any[]): any[] {
    return modulos.sort((a, b) => {
      return this.ordenDeseado.indexOf(a.nombre) - this.ordenDeseado.indexOf(b.nombre);
    });
  }
}
