import { Component, OnInit, ViewChild } from '@angular/core';
import {
  ChartComponent,
  ApexAxisChartSeries,
  ApexChart,
  ApexXAxis,
  ApexTitleSubtitle,
  NgApexchartsModule,
  ApexDataLabels,
  ApexNonAxisChartSeries,
  ApexResponsive,
  ApexPlotOptions,
  ApexStroke,
  ApexFill,
  ApexMarkers,
  ApexLegend,
  ApexYAxis,
  ApexTooltip,
} from 'ng-apexcharts';
import { ServiceService } from '../core/service/service.service';
import { forkJoin } from 'rxjs';
import AuthService from '../core/auth/auth.service';

export type ChartOptionsCasosMes = {
  series: ApexAxisChartSeries;
  chart: ApexChart;
  xaxis: ApexXAxis;
  title: ApexTitleSubtitle;
  dataLabels: ApexDataLabels;
  legend: ApexLegend;
  responsive: ApexResponsive[];
  markers: ApexMarkers;
  stroke: ApexStroke;
  yaxis: ApexYAxis;
};

export type ChartOptionsCasosEquipos = {
  series2: ApexNonAxisChartSeries;
  chart: ApexChart;
  labels: string[];
  title: ApexTitleSubtitle;
  responsive: ApexResponsive[];
  plotOptions: ApexPlotOptions;
  legend: ApexLegend;
};

export type ChartOptionsCasosClientes = {
  chart: ApexChart;
  series: ApexAxisChartSeries;
  title: ApexTitleSubtitle;
  dataLabels: ApexDataLabels;
  stroke: ApexStroke;
  fill: ApexFill;
  responsive: ApexResponsive[];
  labels: string[];
  plotOptions: ApexPlotOptions;
  legend: ApexLegend;
};

export type ChartOptions = {
  plotOptions: ApexPlotOptions;
  series: ApexAxisChartSeries;
  chart: ApexChart;
  xaxis: ApexXAxis;
  dataLabels: ApexDataLabels;
  yaxis: ApexYAxis;
  legend: ApexLegend;
  title: ApexTitleSubtitle;
  responsive: ApexResponsive[];
  tooltip: ApexTooltip;
  colors: string[];
};

interface Mantenimiento {
  id: number;
  descripcion: string;
  estadoGarantia: boolean;
  tipoMantenimientoId: number;
  seguimiento: any;
  fallas: Falla[];
}
interface Falla {
  id: number;
  codigoFalla: string;
  descripcion: string;
}

@Component({
  selector: 'app-dashboard',
  standalone: true,
  imports: [NgApexchartsModule],
  templateUrl: './dashboard.component.html',
  styleUrl: './dashboard.component.css',
})
export class DashboardComponent implements OnInit {
  constructor(
    private apiservice: ServiceService,
    private authService: AuthService
  ) {}
  @ViewChild('chart') chart!: ChartComponent; // Marcar como definitely assigned
  public chartCasosMes: Partial<ChartOptionsCasosMes> = {
    title: {
      text: 'Nro de Casos por Mes',
    },
  }; // Inicialización aquí
  public chartCasosEquipo: Partial<ChartOptionsCasosEquipos> = {
    title: {
      text: 'Nro de Casos por Equipo',
    },
  };
  public chartCasosClientes: Partial<ChartOptionsCasosClientes> = {
    title: {
      text: 'Nro de Casos por Cliente',
    },
  };
  public chartOptionsFallas: Partial<ChartOptions> = {
    title: {
      text: 'Fallas más comunes',
    },
  };

  rolAsignado: string = '';

  ngOnInit(): void {
    const decodedToken = this.authService.decodeToken();
    this.rolAsignado = decodedToken.roles;
    this.getData();
  }
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/reportes/casos/all';
    const url2 = import.meta.env.NG_APP_API + '/reportes/equipos';
    const url4 = import.meta.env.NG_APP_API + '/reportes/diagnosticos';
    const request = this.apiservice.getApi(url);
    const request2 = this.apiservice.getApi(url2);
    const request4 = this.apiservice.getApi(url4);
    forkJoin([request, request2, request4]).subscribe(
      ([casosData, productsData, diagnosticoData]) => {
        // Aquí puedes trabajar con los datos obtenidos

        const equipos = productsData.map(
          (equipo: { marca: string }) => equipo.marca
        );
        // Crear un conjunto único de usuarios asignados
        const usuariosAsignadosSet = new Set<string>(
          casosData.map((caso: any) => caso.usuarioAsignado.nombres)
        );

        // Convertir el Set a un Array
        const usuariosAsignados: string[] = Array.from(usuariosAsignadosSet);

        // Contar ocurrencias de cada código de falla
        const ocurrenciasFallas: Record<string, number> = {};
        diagnosticoData
          .flatMap((mantenimiento: Mantenimiento) =>
            mantenimiento.fallas.map((falla) => falla.codigoFalla)
          )
          .forEach((codigo: string) => {
            ocurrenciasFallas[codigo] = (ocurrenciasFallas[codigo] || 0) + 1;
          });

        // Preparar los datos del gráfico
        const dataSeries = Object.entries(ocurrenciasFallas).map(
          ([codigo, count]) => {
            return {
              x: codigo,
              y: count,
            };
          }
        );

        const casosPorEquipo = new Array(equipos.length).fill(0);
        const casosPorUsuario = new Array(usuariosAsignados.length).fill(0);
        // Inicializar un array con 12 elementos, todos en 0
        // Crear un mapa para contar casos por fecha
        const casosPorFecha = new Map<string, number>();
        casosData.forEach((caso: any) => {
          if (caso.equipo.marca) {
            const index = equipos.indexOf(caso.equipo.marca);
            casosPorEquipo[index]++;
          }
          if (caso.usuarioAsignado.nombres) {
            const index = usuariosAsignados.indexOf(
              caso.usuarioAsignado.nombres
            );
            casosPorUsuario[index]++;
          }
          // Utilizar fechaRegistro para contar casos por fecha
          const fechaRegistro = caso.fechaRegistro;
          if (casosPorFecha.has(fechaRegistro)) {
            casosPorFecha.set(
              fechaRegistro,
              casosPorFecha.get(fechaRegistro)! + 1
            );
          } else {
            casosPorFecha.set(fechaRegistro, 1);
          }
        });
        // Ordenar fechas y preparar datos para el gráfico
        const sortedFechas = Array.from(casosPorFecha.keys()).sort();
        const casosPorFechaData = sortedFechas.map(
          (fecha) => casosPorFecha.get(fecha) || 0
        );
        this.chartCasosMes = {
          series: [
            {
              name: 'Casos',
              data: casosPorFechaData,
            },
          ],
          stroke: {
            curve: 'straight',
          },
          dataLabels: {
            enabled: false,
          },
          chart: {
            type: 'area',
            height: 400,
            zoom: {
              enabled: true,
            },
          },
          title: {
            text: 'Nro de Casos por Fecha',
          },
          xaxis: {
            categories: sortedFechas,
            labels: {
              show: false, // Deshabilita las etiquetas en el eje X
            },
          },
          yaxis: {
            opposite: true,
            labels: {
              show: true, // Deshabilita las etiquetas en el eje Y
            },
          },
          legend: {
            horizontalAlign: 'left',
          },
          responsive: [
            {
              breakpoint: 480,
              options: {
                chart: {
                  width: 200,
                },
                legend: {
                  position: 'bottom',
                },
              },
            },
          ],
        };

        this.chartCasosEquipo = {
          series2: casosPorEquipo,
          chart: {
            type: 'donut',
          },
          labels: equipos,
          title: {
            text: 'Nro de Casos por Equipo',
          },
          legend: {
            position: 'bottom',
          },
          responsive: [
            {
              breakpoint: 400,
              options: {
                chart: {
                  width: 100,
                },
                legend: {
                  position: 'bottom',
                },
              },
            },
          ],
          plotOptions: {
            pie: {
              donut: {
                labels: {
                  show: true,
                  name: {
                    show: true,
                    fontSize: '22px',
                  },
                  value: {
                    show: true,
                    fontSize: '16px',
                    formatter: function (val: any) {
                      return val;
                    },
                  },
                },
              },
            },
          },
        };
        this.chartCasosClientes = {
          series: casosPorUsuario,
          chart: {
            type: 'polarArea',
          },
          title: {
            text: 'Nro de Casos por Usuario Asignado',
          },
          labels: usuariosAsignados,
          stroke: {
            colors: ['#fff'],
          },
          fill: {
            opacity: 0.7,
          },
          legend: {
            position: 'bottom',
          },
          responsive: [
            {
              breakpoint: 480,
              options: {
                chart: {
                  width: 200,
                },
                legend: {
                  position: 'bottom',
                },
              },
            },
          ],
          plotOptions: {
            polarArea: {
              rings: {
                strokeWidth: 0,
              },
            },
          },
        };

        this.chartOptionsFallas = {
          colors: ['#234987'],
          series: [
            {
              name: 'Ocurrencias de Fallas',
              data: dataSeries,
            },
          ],
          title: {
            text: 'Fallas más comunes',
          },
          chart: {
            type: 'bar',
            height: 400,
          },
          plotOptions: {
            bar: {
              horizontal: true,
            },
          },
          xaxis: {
            categories: dataSeries.map((data) => data.x),
            labels: {
              formatter: function (val) {
                return 'Falla: ' + val;
              },
            },
          },
          yaxis: {
            title: {
              text: 'Número de Ocurrencias',
            },
          },
          dataLabels: {
            enabled: true,
          },
          legend: {
            show: false,
          },
          tooltip: {
            y: {
              formatter: function (val) {
                return `${val} ocurrencias`;
              },
            },
          },
          responsive: [
            {
              breakpoint: 480,
              options: {
                chart: {
                  width: 200,
                },
                legend: {
                  position: 'bottom',
                },
              },
            },
          ],
        };
      },
      (error) => {
        console.error('Error al cargar datos:', error);
      }
    );
  }
}
