import { Component, EventEmitter, Input, Output, inject } from '@angular/core';
import {
  FormBuilder,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { ServiceService } from '../../../core/service/service.service';
import { GetFallas } from '../tabla-fallas/datos';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-put-fallas',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './put-fallas.component.html',
  styleUrl: './put-fallas.component.css',
})
export class PutFallasComponent {
  formFallas: FormGroup;
  loading: boolean = false;
  url = import.meta.env.NG_APP_API + '/fallas';
  apiservice = inject(ServiceService);
  @Input() id: number = 0;
  @Input() datos!: GetFallas;
  @Output() closeModalEvent = new EventEmitter<boolean>();
  constructor(private formbuild: FormBuilder) {
    this.formFallas = this.formbuild.group({
      codigoFalla: ['', [Validators.required, Validators.maxLength(10)]],
      descripcion: ['', [Validators.required, Validators.maxLength(100)]],
    });
  }
  ngOnInit() {
    if (this.datos) {
      this.formFallas.patchValue(this.datos);
    }
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.formFallas.get(controlName)?.hasError(errorType) &&
      this.formFallas.get(controlName)?.touched
    );
  }
  actualizarDatos() {
    this.loading = true;
    if (this.formFallas.invalid) {
      this.loading = false;
      this.formFallas.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Campos requeridos incompletos. Por favor, llene todos los campos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    this.apiservice
      .putApi(this.url + '/' + this.id, this.formFallas.value)
      .subscribe({
        next: (data: any) => {
          this.loading = false;
          Swal.fire({
            title: 'Success',
            text: 'Falla actualizada correctamente!',
            icon: 'success',
            confirmButtonText: 'OK',
            allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
          }).then((result) => {
            if (result.isConfirmed) {
              window.location.reload();
            }
          });
        },
        error: (error) => {
          this.loading = false;
          let errorMessage = 'Algo salió mal';
          if (error.error && error.error.message) {
            errorMessage = error.error.message;
          }
  
          Swal.fire({
            title: 'Error',
            text: errorMessage,
            icon: 'error',
            confirmButtonText: 'OK',
          });
        },
      });
  }
  closeModal(estado: boolean) {
    this.closeModalEvent.emit(estado);
  }
}
