import { Component } from '@angular/core';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../core/service/service.service';
import { Router } from '@angular/router';
import { SeguimientoServicio } from '../../../seguimiento-editar/seguimiento-editar';
import AuthService from '../../../core/auth/auth.service';
import { ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { EditCasoComponent } from '../../modules/casos/casos/edit-caso/edit-caso.component';
import { TableComponent } from '../../modules/casos/shared/table/table.component';
import { ServicioGuradarDatosFallas } from '../tabla-fallas/guardarDatosFallas';

@Component({
  selector: 'app-tabla-casos-por-falla',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    CommonModule,
    EditCasoComponent,
    TableComponent,
  ],
  templateUrl: './tabla-casos-por-falla.component.html',
  styleUrl: './tabla-casos-por-falla.component.css'
})
export class TablaCasosPorFallaComponent {

  constructor(
    private dataService: ServiceService,
    private router: Router,
    private seguimientoServicio: SeguimientoServicio,
    private token: AuthService,
    private fallaServicioGuardado: ServicioGuradarDatosFallas
  ) {}
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: any[] = [];
  keyword: string = '';
  iconConfig: any = {};
  idUsuario: number = 0;

  
  tipoDocumento: any;
  areaPerteneciente: any
  usuarioRegistro: any

  columns = [
    { header: 'N° CASO', field: ['numeroCaso'], isTablaHeader: true },
    {
      header: 'CLIENTE',
      field: ['cliente.nombre', 'cliente.apellido'],
      subField: ['cliente.correoElectronico'],
    },
    {
      header: 'SUCURSAL',
      field: ['sucursal.nombre'],
    },
    {
      header: 'TIPO DOC',
      field: ['cliente.tipoDocumento'],
      subField: ['cliente.numeroDocumento'],
    },
    { header: 'TIPO SERVICIO', field: ['tipoServicio'] },
    { header: 'EQUIPO', field: ['equipo.marca'], subField: ['equipo.modelo'] },
    {
      header: 'USUARIO ASIGNADO',
      field: ['usuarioAsignado.nombres'],
      subField: ['usuarioAsignado.perfiles[0].nombre'],
    },
    { header: 'ESTADO', field: ['estadoCaso'], subField: ['etapa'] },
  ];

  idSucursal: any

  perfilSesion: any;

  datosFallas: any
  idFalla: any

  ngOnInit(): void {
    this.idFalla = localStorage.getItem('falla');
    const tokenData = this.token.decodeToken();
    this.idUsuario = tokenData.idusuario;
    this.perfilSesion = tokenData.roles;
    this.idSucursal = tokenData.idSucursal;
    this.configureIcons(tokenData.roles);
    this.loadData({ page: 0, keyword: '', sucursal: ''  });
    this.datosFallas = this.fallaServicioGuardado.getDatosServicioById()
  }


  


  configureIcons(perfil: string): void {
    if (perfil === 'ADMIN') {
      this.iconConfig = {
        icons: [
          {
            name: 'enviarWhatsapp',
            action: (dato: any) => this.clickWhatsapp(dato),
          },
          {
            name: 'verSeguimiento',
            action: (dato: any) => this.clickOjito(dato),
          },

          {
            name: 'editarSeguimiento',
            action: (dato: any) => this.editarseguimiento(dato),
          },
          { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    } else if (perfil === 'ASISTENTE') {
      this.iconConfig = {
        icons: [
          {
            name: 'enviarWhatsapp',
            action: (dato: any) => this.clickWhatsapp(dato),
          },
          {
            name: 'verSeguimiento',
            action: (dato: any) => this.clickOjito(dato),
          },
        ],
      };
    } else {
      this.iconConfig = {
        icons: [
          {
            name: 'verSeguimiento',
            action: (dato: any) => this.clickOjito(dato),
          },
        ],
      };
    }
  }


  loadData({ page, keyword, sucursal }: { page: number; keyword: string; sucursal: string }): void {
    console.log('loadData called'); // Verifica que la función se esté llamando
    console.log(`Parameters - Page: ${page}, Keyword: ${keyword}, Sucursal: ${sucursal}`);
    
    this.arregloget = [];
    this.isLoading = true;
    const tokenData = this.token.decodeToken();
    const perfil = tokenData.roles;
    let url = '';
    let request;

    if (perfil === 'SOPORTE') {
      url = `${import.meta.env.NG_APP_API}/casos/falla/${this.idFalla}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
      request = this.dataService.getApi(url);
    } else if (perfil === 'DISTRIBUIDOR') {
      url = `${import.meta.env.NG_APP_API}/casos/falla/${this.idFalla}?page=${page}&size=10&keyword=${keyword}`;
      const data: any = { idUsuarioDistribuidor: this.idUsuario };
      request = this.dataService.postApi(url, data);
    }else if (perfil === 'ASISTENTE' || perfil === 'SUPERVISOR') {
      url = `${import.meta.env.NG_APP_API}/casos/falla/${this.idFalla}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
            request = this.dataService.getApi(url);
    }
     else {
           if(sucursal === ""){
            url = `${import.meta.env.NG_APP_API}/casos/falla/${this.idFalla}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
            request = this.dataService.getApi(url);
           }
           else{
            url = `${import.meta.env.NG_APP_API}/casos/falla/${this.idFalla}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
            request = this.dataService.getApi(url);
           }
    }

    console.log(`Request URL: ${url}`);

    request.subscribe({
      next: (data) => {
        console.log('Response Data:', data);
        this.arregloget = data.content;
        if (this.arregloget && this.arregloget.length > 0) {
          this.arregloget.forEach(item => {
            if (item.cliente.tipoDocumento === 'DNI') {
              item.areaPerteneciente = item.areaPerteneciente ?? "NO APLICA PORQUE ES DNI";
              item.usuarioRegistro = item.usuarioRegistro ?? "SOLO SE ACEPTA CLIENTE";
            } else if (item.cliente.tipoDocumento === 'RUC') {
              item.areaPerteneciente = item.areaPerteneciente === '' ? "NO SE REGISTRO NADA" : item.areaPerteneciente;
              item.usuarioRegistro = item.usuarioRegistro === '' ? "NO SE REGISTRO NADA" : item.usuarioRegistro;
            }
          });
        }
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log('Error:', error);
        this.isLoading = false;
      },
    });
  }


  clickOjito(datos: any) {
    localStorage.setItem('numerocaso', datos.numeroCaso);
    this.router.navigate(['/dashboard/seguimiento']);
  }
  clickWhatsapp(datos: any) {
    const mensaje = `Hola ${datos.cliente.nombre} ${datos.cliente.apellido} , ¡tu caso ha sido registrado con éxito! 🎉 Gracias por confiar en nosotros. Para hacer seguimiento a tu caso, simplemente copia este enlace en el navegador: https://www.datasumaqpro.com/casos-equipos, Ingresas tu número de caso en el buscador: ${datos.numeroCaso}. ¡Y te aparecerá toda la información sobre tu equipo! 😊`;

    // Formatea el número de WhatsApp si no incluye el prefijo (+51)
    const telefono = '51' + datos.cliente.celularesContacto;

    // Detecta si el usuario está en un dispositivo móvil
    var isMobile =
      /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(
        navigator.userAgent
      );

    if (isMobile) {
      // Si el usuario está en un dispositivo móvil, utiliza el enlace wa.me
      const api_mobile =
        'https://wa.me/' +
        encodeURIComponent(telefono) +
        '?text=' +
        encodeURIComponent(mensaje);
      window.open(api_mobile, '_blank');
    } else {
      // Si el usuario está en una computadora, utiliza el enlace web.whatsapp.com
      const api_pc =
        'https://web.whatsapp.com/send/?phone=' +
        encodeURIComponent(telefono) +
        '&text=' +
        encodeURIComponent(mensaje) +
        '&app_absent=0';
      window.open(api_pc, '_blank');
    }
  }
  editarseguimiento(datos: any) {
    localStorage.setItem('numerocaso', datos.numeroCaso);
    this.seguimientoServicio.setData(datos);
    this.router.navigate(['/dashboard/seguimiento-editar']);
  }


   // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
   deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/casos/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
            this.loadData({ page: 0, keyword: '', sucursal: "" });
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }

}
