import { Component, inject } from '@angular/core';
import { GetFallas } from './datos';
import { ServiceService } from '../../../core/service/service.service';
import Swal from 'sweetalert2';
import { PutFallasComponent } from '../put-fallas/put-fallas.component';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { TableComponent } from '../../modules/casos/shared/table/table.component';
import { ServicioGuradarDatosFallas } from './guardarDatosFallas';
import { Router } from '@angular/router';
import AuthService from '../../../core/auth/auth.service';

@Component({
  selector: 'app-tabla-fallas',
  standalone: true,
  imports: [PutFallasComponent, ReactiveFormsModule,TableComponent],
  templateUrl: './tabla-fallas.component.html',
  styleUrl: './tabla-fallas.component.css',
})
export class TablaFallasComponent {

  constructor(private fallaServicioGuardado: ServicioGuradarDatosFallas, private router: Router ,  private token: AuthService) {}

  apiService = inject(ServiceService);
  /////////////////DATOS DE ACTUALIZACION
  idFalla: number = 0;
  datosFalla: any = {};
  estadoModal: boolean = false;
  ////////////////////////////
    //DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  datosFallas: GetFallas[] = [];
  keyword: string = '';
  /////////////////////////////////////
  columns = [
    { header: 'CODIGO DE FALLA', field: ['codigoFalla'], isTablaHeader: true },
    { header: 'DESCRIPCION', field: ['descripcion'] },
  ];
  iconConfig: any = {};

  configureIcons(perfil: string): void {
    if (perfil === 'ADMIN') {
      this.iconConfig = {
        icons: [
          {
            name: 'editar',
            action: (id: number, dato: any) => this.showmodal(id, dato),
          },
          {
            name: 'verSeguimiento',
            action: (dato: any) => this.pasarAverlosCasosPorfalla(dato),
          },
          { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    } else {
      this.iconConfig = {
        icons: [
          // {
          //   name: 'editar',
          //   action: (id: number, dato: any) => this.enviarmodal(id, dato),
          // },
          // { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    }
  }
  
  
  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.loadData({ page: 0, keyword: '' });
    this.configureIcons(tokenData.roles);
  }


  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.datosFallas=[]
    this.isLoading = true;
    const url = `${
      import.meta.env.NG_APP_API
    }/fallas?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    this.apiService.getApi(url).subscribe({
      next: (data) => {
        this.datosFallas = data.content;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }

  pasarAverlosCasosPorfalla(datos: any) {
    localStorage.setItem('falla', datos.id);
    this.fallaServicioGuardado.setDatosServicioById(datos);
    this.router.navigate(['/dashboard/seguimiento-por-falla']);
  }


  showmodal(id: number, datos: any) {
    console.log(id, datos);
    this.idFalla = id;
    this.datosFalla = datos;
    this.estadoModal = !this.estadoModal;
    console.log(id);
    console.log(datos);
  }
  closemodal(estado: boolean) {
    this.estadoModal = !this.estadoModal;
  }

  deleteApi(id: number) {
    Swal.fire({
      title: '¿Estás seguro de que deseas eliminar esta falla?',
      text: 'No podrás revertir esta acción',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminar',
      cancelButtonText: 'Cancelar',
    }).then((result) => {
      if (result.isConfirmed) {
        const url = import.meta.env.NG_APP_API + '/fallas/'+ id;
        this.apiService.deleteApi(url).subscribe({
          next: (data) => {
            Swal.fire(
              '¡Falla eliminada!',
              'La falla ha sido eliminada con éxito',
              'success'
            );
            this.loadData({ page: 0, keyword: '' });
          },
          error: (error) => {
            Swal.fire(
              'Error',
              'Ha ocurrido un error al eliminar la falla',
              'error'
            );
          },
        });
      }
    });
  }
}
