import { Component } from '@angular/core';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../core/service/service.service';
import { ClientsComponent } from './clients/clients.component';
import { initFlowbite } from 'flowbite';
import { CommonModule } from '@angular/common';
import { PostequiposcasosComponent } from './postequiposcasos/postequiposcasos.component';
import AuthService from '../../../../core/auth/auth.service';

@Component({
  selector: 'app-casos',
  standalone: true,
  imports: [ClientsComponent, CommonModule, PostequiposcasosComponent],
  templateUrl: './casos.component.html',
  styleUrl: './casos.component.css',
})
export class CasosComponent {
  constructor(private dataService: ServiceService, private authService: AuthService) {}


  
  arregloSucursales: any[] = [];
  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  perfildeSesion : any
  idSucursalToken: any
  ngOnInit(): void {
    initFlowbite();
    this.getSucursales()
    this.getDataEquipos();
    this.GetCasoNombre();
    this.getDataUsuarios();
    this.getDataPrioridad();
    this.getDistribuidor();
    this.getDataFecha();

    const decode = this.authService.decodeToken();
    if (decode) {
      this.perfildeSesion = decode.roles;
      this.idSucursalToken = decode.idSucursal;
    }

  }

  recibirLaRepuestaDelPostHiJOParaActualizarNumeroCliente(event: any) {
    console.log(event);
    if (event) {
      this.dni = event;
    }
  }

  getDistribuidor(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor/all';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetDistribuidor = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  getDataEquipos(): void {
    const url = import.meta.env.NG_APP_API + '/equipos/all';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetEquipos = data;
        // Refiltro los equipos después de obtener los datos
        this.filtrarEquiposPorDistribuidor(this.distribuidorSeleccionado);
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  distribuidorSeleccionado: string = '';
  // Método para manejar el clic en un distribuidor
  onDistribuidorClick(e: any) {
    this.distribuidorSeleccionado = e.target.value;
    this.filtrarEquiposPorDistribuidor(this.distribuidorSeleccionado);
  }

  filtrarEquiposPorDistribuidor(distribuidor: string) {
    this.equiposFiltrados = this.arreglogetEquipos.filter(
      (equipo) => equipo.distribudor.id === Number(distribuidor)
    );
  }

  consulta: string = '';
  sugerencias: any[] = [];
  sugerenciasFiltradas: any[] = [];
  sugerenciasVisibles: boolean = false;
  idSeleccionado: number | null = null;

  mostrarSugerencias(): void {
    this.sugerenciasVisibles = true;
    this.filtrarSugerencias();
  }

  ocultarSugerencias(): void {
    setTimeout(() => (this.sugerenciasVisibles = false), 200);
  }

  filtrarSugerencias(): void {
    const consultaLowerCase = this.consulta.toLowerCase();

    this.sugerenciasFiltradas = this.equiposFiltrados.filter((sugerencia) => {
      const modeloLowerCase = sugerencia.modelo.toLowerCase();
      const marcaLowerCase = sugerencia.marca.toLowerCase();
      const colorLowerCase = sugerencia.color.toLowerCase();
      return (
        modeloLowerCase.includes(consultaLowerCase) ||
        marcaLowerCase.includes(consultaLowerCase) ||
        colorLowerCase.includes(consultaLowerCase)
      );
    }); // Limitar a las primeras 10 sugerencias
  }

  seleccionarSugerencia(sugerencia: any): void {
    this.consulta = `${sugerencia.color} - ${sugerencia.marca} - ${sugerencia.modelo}`;
    this.idSeleccionado = sugerencia.id;
    this.sugerenciasVisibles = false;

    // Actualizar el valor del input directamente
    const inputElement = document.getElementById(
      'autocompletado-input'
    ) as HTMLInputElement;
    if (inputElement) {
      inputElement.value = this.consulta;
    }
  }

  alIngresar(event: any): void {
    this.consulta = event.target.value;
    this.filtrarSugerencias();
  }

  recibirLaRepuestaDelPostHiJOParaActualizar(event: boolean) {
    if (event) {
      this.getDataEquipos(); // Actualizar la tabla después de la solicitud POST
    }
  }

  showModal: boolean = false;
  imagenes: any = [];
  mostrarModal: boolean = false;
  fieldlocked: boolean = true;

  lastSelectedFiles: any;

  onFileSelected(event: any) {
    const files = event.target.files;

    const input = event.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    if (files) {
      for (let i = 0; i < files.length; i++) {
        const file = files[i];

        // Verificar si el archivo no supera los 10 MB
        const fileSizeInMB = file.size / (1024 * 1024);
        if (fileSizeInMB > 15) {
          alert('¡El tamaño de la imagen no debe superar los 15 MB!');
          if (this.imagenes.length === 0) {
            const fileInput = document.getElementById(
              'file_input3'
            ) as HTMLInputElement;
            fileInput.value = '';
          }
          continue; // Saltar a la siguiente iteración si el archivo es demasiado grande
        }

        const imageUrl = URL.createObjectURL(file); // Obtén la URL temporal
        const guardarFileyURL = { file: file, url: imageUrl };

        // Verificar si la imagen ya está en la lista
        const existingImage = this.imagenes.find(
          (img: any) => img.file.name === file.name
        );
        if (existingImage) {
          alert('¡Imagen repetida!');
        } else if (this.imagenes.length >= 5) {
          alert('¡Ya has alcanzado el límite de 5 imágenes!');
          break; // Salir del bucle si se alcanza el límite
        } else {
          this.imagenes.push(guardarFileyURL);
          console.log(this.imagenes);
        }
      }
    }
  }

  eliminarImagen(url: any) {
    const index = this.imagenes.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.imagenes.splice(index, 1);
    }
    if (this.imagenes.length === 0) {
      const fileInput = document.getElementById(
        'file_input3'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  openModal() {
    this.showModal = true;
  }

  closeModal() {
    this.showModal = false;
  }

  arreglogetCliente: any[] = [];
  arreglogetUsuarios: any[] = [];
  arreglogetPrioridad: any[] = [];

  arreglogetEquipos: any[] = [];
  arreglogetDistribuidor: any[] = [];

  equiposFiltrados: any[] = [];

  getDataPrioridad(): void {
    const url = import.meta.env.NG_APP_API + '/prioridad-atencion';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetPrioridad = data.content;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  idSucursalUsuarioSoporte:any

  getDataUsuarios(): void {
    const url = import.meta.env.NG_APP_API + '/usuarios';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
          console.log(data);

          if (this.perfildeSesion === 'ADMIN') {
           
          this.arreglogetUsuarios = data.filter((usuario: any) => {
            // Verificar si el usuario tiene el perfil "SOPORTE"
            return usuario.perfil === 'SOPORTE';
          });
          } else {
            // Si el perfil es diferente de ADMIN, filtrar por la sucursal
            this.arreglogetUsuarios = data.filter((usuario: any) => {
              return usuario.perfil === 'SOPORTE' && usuario.idSucursal === this.idSucursalToken;
            });
          }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  idUsuarioAsignado: any;

changeAgarrar(e: any) {
  let valor = e.target.value;
  // Realizamos el split en el valor obtenido
  const partes = valor.split(' - ');

  this.idUsuarioAsignado = partes[0];
  this.idSucursalUsuarioSoporte = partes[1];
}


  datosFiltrados: any[] = [];
  dni: string = '';

  onChange(event: any) {
    this.dni = event.target.value;
  }

  //PARA VALIDAR EL CELULAR
  validateInputNumero(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 9); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  validateInputperiodo_garantia(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 2); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  nombreCliente: any;

  tipodocumento: string = '';

  razonsocial: string = '';

  clickbuscar() {
    const url = import.meta.env.NG_APP_API + '/clientes';
    const valor = this.dni;
  
    console.log(valor);
  
    // Reiniciar datosFiltrados al hacer clic en buscar
    this.datosFiltrados = [];
  
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        // Asignar los datos recibidos a arreglogetCliente
        this.arreglogetCliente = data;
  
        // Verificar la longitud del valor ingresado
        if (valor.length === 8 || valor.length === 11) {
          // Filtrar clientes por número de documento exacto
          const datosFiltrados = this.arreglogetCliente.filter(
            (cliente: any) => cliente.numeroDocumento === valor
          );
  
          if (datosFiltrados.length === 0) {
            this.datosFiltrados = [];
            this.mostrarMensajeError('No se encontró el cliente');
          } else {
            this.datosFiltrados = datosFiltrados;
            console.log(datosFiltrados);
  
            // Asignar los datos del cliente a las variables correspondientes
            this.nombreCliente = datosFiltrados[0].nombre + ' ' + datosFiltrados[0].apellido;
            this.tipodocumento = datosFiltrados[0].tipoDocumento;
            console.log(this.tipodocumento);
            this.razonsocial = datosFiltrados[0].representanteLegal ? datosFiltrados[0].representanteLegal : '';
            this.fieldlocked = false;
          }
        } else {
          this.datosFiltrados = [];
          this.mostrarMensajeError(
            'El número de documento debe tener 8 o 11 dígitos.'
          );
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }
  

  mostrarMensajeError(mensaje: string) {
    Swal.fire({
      icon: 'error',
      title: 'Oops...',
      text: mensaje,
    });
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagen(link: string) {
    this.linkimagen = link;
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }
  limpiarformulario(e: any) {
    e.preventDefault();
    const formulario = document.getElementById('formulario') as HTMLFormElement;
    if (formulario) {
      // Selecciona todos los elementos del formulario excepto el campo 'numerocaso'
      const elementos = formulario.querySelectorAll('input:not(#numerocaso)');
      // Itera sobre los elementos seleccionados y establece su valor en vacío
      elementos.forEach((elemento: any) => {
        elemento.value = '';
      });
    }
    this.imagenes = [];
    this.dni = '';
    this.datosFiltrados = [];
    this.fieldlocked = true;
  }

  fechaActual: string = '';

  getDataFecha(): void {
    const fecha = new Date();
    const dia = fecha.getUTCDate();
    const mes = fecha.getUTCMonth() + 1; // Los meses comienzan desde 0
    const anio = fecha.getUTCFullYear();

    // Formatear la fecha
    const fechaFormateada = `${dia < 10 ? '0' + dia : dia}-${
      mes < 10 ? '0' + mes : mes
    }-${anio}`;

    this.fechaActual = fechaFormateada;
  }

  numeroCaso: string = '';

  GetCasoNombre() {
    const url = import.meta.env.NG_APP_API + '/casos/last-number';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        // Obtener solo el campo 'numeroCaso' de cada objeto
        let repuesta = data.numeroCaso;
        // Obtener el último número de caso si hay al menos uno
        if (repuesta.length > 0) {
          const splitString = repuesta.split('-');
          var secondPart = splitString[1];
          secondPart = parseInt(secondPart) + 1;
          var nuevoNumeroCaso = 'C-' + secondPart.toString().padStart(4, '0');
          this.numeroCaso = nuevoNumeroCaso;
        } else {
          this.numeroCaso = 'Hubo un error al obtener el número de caso ultimo';
        }
      },
      error: (error) => {
        console.log(error);
        this.numeroCaso = 'C-0001';
      },
    });
  }
  formatDate(date: Date): string {
    const day = date.getDate();
    const month = date.getMonth() + 1; // Los meses en JavaScript son 0-indexados
    const year = date.getFullYear();

    // Asegúrate de que el día y el mes tengan siempre dos dígitos
    const formattedDay = day < 10 ? '0' + day : day;
    const formattedMonth = month < 10 ? '0' + month : month;

    return `${formattedDay}/${formattedMonth}/${year}`;
  }
  mostrarPeriodogarantia: boolean = true;
  eligirCaso(e: any) {
    const caso = e.target.value;
    if (caso === 'si') {
      this.mostrarPeriodogarantia = true;
    } else {
      this.mostrarPeriodogarantia = false;
    }
  }

  loading: boolean = false;
  enviarDatos(e: any) {
    e.preventDefault();
    this.loading = true;
    if (this.loading) {
      Swal.fire({
        title: 'Guardando',
        html: `
            <style>
              .spinner {
                border: 4px solid rgba(0, 0, 0, 0.1);
                width: 36px;
                height: 36px;
                border-radius: 50%;
                border-left-color: #09f;
                animation: spin 1s linear infinite;
                display: inline-block;
                margin-top: 10px;
              }
        
              @keyframes spin {
                0% {
                  transform: rotate(0deg);
                }
                100% {
                  transform: rotate(360deg);
                }
              }
            </style>
            <div>Se está guardando la información, por favor esperar...</div>
            <div class="spinner"></div>
          `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        timerProgressBar: true,
      });
    }
    const date = new Date();
    const fecha_formateada = this.formatDate(date);
    const formData = new FormData(e.target);
    const aceptoTerminosCheckbox = e.target.querySelector('#link-checkbox');

    // Agregar las imágenes al FormData
    for (let i = 0; i < this.imagenes.length; i++) {
      formData.append(
        'media[]',
        this.imagenes[i].file,
        this.imagenes[i].file.name
      );
    }

    formData.append('fechaRegistro', fecha_formateada);

    formData.append('etapa', '1');
    formData.append('estadoCaso', 'Completado');
    console.log(formData);
    if (this.idSeleccionado !== null) {
      formData.append('idEquipo', this.idSeleccionado.toString());
    } else {
      // Aquí decides qué hacer si idSeleccionado es null, por ejemplo:
      formData.append('idEquipo', '0'); // O algún otro valor por defecto
    }

    formData.append('idUsuarioAsignado', this.idUsuarioAsignado);

    formData.append('idSucursal', this.idSucursalUsuarioSoporte);

    // Verificar si el checkbox está marcado
    const aceptoTerminos = aceptoTerminosCheckbox.checked;
    formData.set('aceptoTerminos', aceptoTerminos ? 'true' : 'false');
    const url = import.meta.env.NG_APP_API + '/casos';
    console.log("area registrada" + formData.get('areaPerteneciente'));
    console.log("usuario registrada" +formData.get('usuarioRegistro'));
    console
    this.dataService.postApi(url, formData).subscribe({
      next: (response: any) => {
        Swal.fire({
          icon: 'success',
          title: '¡Registro exitoso!',
          text: 'El caso ha sido registrado con éxito. Ahora enviaremos el código de seguimiento por WhatsApp.',
          showCancelButton: true,
          confirmButtonColor: '#3085d6',
          cancelButtonColor: '#d33',
          confirmButtonText: 'Enviar Información a WhatsApp',
          cancelButtonText: 'Cancelar',
          allowOutsideClick: false,
          allowEscapeKey: false,
          timerProgressBar: true,
        }).then((result) => {
          if (result.isConfirmed) {
            const nombre = formData.get('Nombre');
            const numeroCaso = formData.get('numeroCaso');
            const mensaje = `Hola ${nombre}, ¡tu caso ha sido registrado con éxito! 🎉 Gracias por confiar en nosotros.

  Para hacer seguimiento a tu caso, simplemente haga click en el siguiente enlace: https://www.datasumaqpro.com/casos-equipos, ingresa tu número de caso en el buscador: ${numeroCaso}. ¡Y te aparecerá toda la información sobre tu equipo! 😊

  Estimado Cliente,

  **DataSumaqPro** informa que el tratamiento de sus datos personales se realizará conforme a la Ley de Protección de Datos Personales. Sus datos serán tratados con confidencialidad y se utilizarán exclusivamente para los fines de nuestros servicios.
  `;

            console.log(mensaje);

            // Formatea el número de WhatsApp si no incluye el prefijo (+51)
            const telefono = '51' + formData.get('Celular');

            // Detecta si el usuario está en un dispositivo móvil
            const isMobile =
              /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(
                navigator.userAgent
              );

            if (isMobile) {
              // Si el usuario está en un dispositivo móvil, utiliza el enlace wa.me
              const api_mobile = `https://wa.me/${encodeURIComponent(
                telefono
              )}?text=${encodeURIComponent(mensaje)}`;
              window.open(api_mobile, '_blank');
            } else {
              // Si el usuario está en una computadora, utiliza el enlace web.whatsapp.com
              const api_pc = `https://web.whatsapp.com/send/?phone=${encodeURIComponent(
                telefono
              )}&text=${encodeURIComponent(mensaje)}&app_absent=0`;
              window.open(api_pc, '_blank');
            }

            this.loading = false;
            window.location.reload();
          } else {
            this.loading = false;
            window.location.reload();
          }
        });
      },
      error: (atrapar) => {
        this.loading = false;

        let mensajeAmostar;

        if (atrapar.error) {
          mensajeAmostar = atrapar.error.message;
        } else {
          mensajeAmostar = 'Error al registrar el caso';
        }

        Swal.fire({
          icon: 'error',
          title: '¡Error!',
          text: mensajeAmostar,
          confirmButtonText: 'Aceptar',
        });
      },
    });
  }
}
