import {
  Component,
  EventEmitter,
  Input,
  Output,
  OnInit,
  ChangeDetectorRef,
} from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';
import { CommonModule } from '@angular/common';
import { forkJoin, Observable } from 'rxjs';
import { SeguimientoServicio } from '../../../../../seguimiento-editar/seguimiento-editar';

@Component({
  selector: 'app-edit-caso',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './edit-caso.component.html',
  styleUrls: ['./edit-caso.component.css'],
})
export class EditCasoComponent implements OnInit {
  constructor(
    private servicioApi: ServiceService,
    private cdr: ChangeDetectorRef,
    // private datosRecibidos : SeguimientoServicio
  ) {}
  arreglogetCliente: any[] = [];
  arreglogetUsuarios: any[] = [];
  arreglogetPrioridad: any[] = [];
  arreglogetEquipos: any[] = [];
  arreglogetDistribuidor: any[] = [];
  equiposFiltrados: any[] = [];
  datosFiltrados: any[] = [];
  dni: string = '';
  fieldlocked: boolean = true;
  loading: boolean = false;

  @Input() id: number = 0;
  @Input() datos: any;
  @Output() addshowModalEvent = new EventEmitter<boolean>();
  

  form: FormGroup = new FormGroup({
    numeroCaso: new FormControl(''),
    dni: new FormControl(''),
    nombreCliente: new FormControl(''),
    direccionCliente: new FormControl(''),
    celularCliente: new FormControl(''),
    tipoServicio: new FormControl(''),
    ordenServicio: new FormControl(''),
    idUsuarioAsignado: new FormControl(''),
    idDistribuidor: new FormControl(''),
    idEquipo: new FormControl(''),
    numeroSerie: new FormControl(''),
    idPrioridadAtencion: new FormControl(''),
    descripcion: new FormControl(''),
    aceptoTerminos: new FormControl(''),
    //
    garantia: new FormControl(''),
    proximoMantenimiento: new FormControl(''),
    contometroLLegada: new FormControl(''),
    contometroSalida: new FormControl(''),
    nivelTintaNegraLLegada: new FormControl(''),
    nivelTintaNegraSalida: new FormControl(''),
    nivelTintaCianLLegada: new FormControl(''),
    nivelTintaCianSalida: new FormControl(''),
    nivelTintaMagentaLLegada: new FormControl(''),
    nivelTintaMagentaSalida: new FormControl(''),
    nivelTintaAmarillaLLegada: new FormControl(''),
    nivelTintaAmarillaSalida: new FormControl(''),
  });

  getDistribuidor(): Observable<any> {
    const url = import.meta.env.NG_APP_API + '/distribuidor';
    return this.servicioApi.getApi(url);
  }

  getDataEquipos(): Observable<any> {
    const url = import.meta.env.NG_APP_API + '/equipos';
    return this.servicioApi.getApi(url);
  }

  getDataPrioridad(): Observable<any> {
    const url = import.meta.env.NG_APP_API + '/prioridad-atencion';
    return this.servicioApi.getApi(url);
  }

  getDataUsuarios(): Observable<any> {
    const url = import.meta.env.NG_APP_API + '/usuarios';
    return this.servicioApi.getApi(url);
  }

  // Método para manejar el clic en un distribuidor
  onDistribuidorClick(e: any) {
    const distribuidor = e.target.value;
    // Filtrar los equipos relacionados al distribuidor seleccionado
    this.equiposFiltrados = this.arreglogetEquipos.filter(
      (equipo) => equipo.distribudor.id === Number(distribuidor)
    );
    this.cdr.detectChanges(); // Detecta cambios en el DOM si es necesario
  }
  isLoading = true;
  ngOnInit(): void {
    initFlowbite();

    console.log(this.datos);

    forkJoin([
      this.getDataEquipos(),
      this.getDataUsuarios(),
      this.getDataPrioridad(),
      this.getDistribuidor(),
    ]).subscribe(
      ([equipos, usuarios, prioridades, distribuidores]) => {
        this.arreglogetEquipos = equipos;
        this.arreglogetUsuarios = usuarios.filter((usuario: any) => {
          // Filtrar usuarios con perfiles que incluyan 'SOPORTE'
          return usuario.perfiles?.some((perfil: any) =>
            perfil.nombre.includes('SOPORTE')
          );
        });
        this.arreglogetPrioridad = prioridades;
        this.arreglogetDistribuidor = distribuidores;

        // console.log(this.datosRecibidos.getData());

        // Parchear los valores del formulario después de que todos los datos estén cargados
        if (this.datos) {
          this.form.patchValue({
            numeroCaso: this.datos.numeroCaso,
            dni: this.datos.cliente.numeroDocumento,
            nombreCliente:
              this.datos.cliente.nombre + ' ' + this.datos.cliente.apellido,
            direccionCliente: this.datos.cliente.direccionLegal,
            celularCliente: this.datos.cliente.telefonosContacto,
            tipoServicio: this.datos.tipoServicio,
            ordenServicio: this.datos.ordenServicio,
            idUsuarioAsignado: this.datos.usuarioAsignado.id,
            idDistribuidor: this.datos.equipo.distribudor.id,
            idEquipo: this.datos.equipo.id,
            numeroSerie: this.datos.numeroSerie,
            idPrioridadAtencion: this.datos.idPrioridad,
            descripcion: this.datos.descripcion,
            aceptoTerminos: this.datos.aceptoTerminos,
            garantia: this.datos.garantia,
            proximoMantenimiento: this.datos.proximoMantenimiento,
            contometroLLegada: this.datos.contometroLLegada,
            contometroSalida: this.datos.contometroSalida,
            nivelTintaNegraLLegada: this.datos.nivelTintaNegraLLegada,
            nivelTintaNegraSalida: this.datos.nivelTintaNegraSalida,
            nivelTintaCianLLegada: this.datos.nivelTintaCianLLegada,
            nivelTintaCianSalida: this.datos.nivelTintaCianSalida,
            nivelTintaMagentaLLegada: this.datos.nivelTintaMagentaLLegada,
            nivelTintaMagentaSalida: this.datos.nivelTintaMagentaSalida,
            nivelTintaAmarillaLLegada: this.datos.nivelTintaAmarillaLLegada,
            nivelTintaAmarillaSalida: this.datos.nivelTintaAmarillaSalida,
          });
          // Filtrar los equipos después de parchear el distribuidor
          this.onDistribuidorClick({
            target: { value: this.datos.equipo.distribudor.id },
          });
        }

        // Cambiar el estado de carga a false cuando los datos están cargados
        this.isLoading = false;
      },
      (error) => {
        console.error(error);
        // Cambiar el estado de carga a false en caso de error
        this.isLoading = false;
      }
    );
  }

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  enviarDatos(e: any) {
    e.preventDefault(); // Evita el comportamiento predeterminado del formulario
    this.loading = true;
    const formData = new FormData();

    // Función auxiliar para añadir campos al FormData solo si tienen un valor
    const appendIfDefined = (key: any, value: any) => {
      if (value !== null && value !== undefined) {
        formData.append(key, value);
      }
    };

    appendIfDefined('numeroCaso', this.form.get('numeroCaso')?.value);
    appendIfDefined('tipoServicio', this.form.get('tipoServicio')?.value);
    appendIfDefined('ordenServicio', this.form.get('ordenServicio')?.value);
    appendIfDefined(
      'idUsuarioAsignado',
      this.form.get('idUsuarioAsignado')?.value
    );
    appendIfDefined('calificacion', this.datos.calificacion);
    appendIfDefined('etapa', this.datos.etapa);
    appendIfDefined('estadoCaso', this.datos.estadoCaso);
    appendIfDefined('idDistribuidor', this.form.get('idDistribuidor')?.value);
    appendIfDefined('idEquipo', this.form.get('idEquipo')?.value);
    appendIfDefined('numSerie', this.form.get('numeroSerie')?.value);
    appendIfDefined(
      'IdPrioridadAtencion',
      this.form.get('idPrioridadAtencion')?.value
    );

    if (this.datosFiltradosClientes.length > 0) {
      appendIfDefined('idCliente', this.datosFiltradosClientes[0].id);
    } else {
      appendIfDefined('idCliente', this.datos.cliente.id);
    }

    appendIfDefined('descripcion', this.form.get('descripcion')?.value);
    appendIfDefined('aceptoTerminos', this.datos.aceptoTerminos);
    appendIfDefined('garantia', this.datos.garantia);
    appendIfDefined('proximoMantenimiento', this.datos.proximoMantenimiento);
    appendIfDefined('contometroLLegada', this.datos.contometroLLegada);
    appendIfDefined('contometroSalida', this.datos.contometroSalida);
    appendIfDefined(
      'nivelTintaNegraLLegada',
      this.datos.nivelTintaNegraLLegada
    );
    appendIfDefined('nivelTintaNegraSalida', this.datos.nivelTintaNegraSalida);
    appendIfDefined('nivelTintaCianLLegada', this.datos.nivelTintaCianLLegada);
    appendIfDefined('nivelTintaCianSalida', this.datos.nivelTintaCianSalida);
    appendIfDefined(
      'nivelTintaMagentaLLegada',
      this.datos.nivelTintaMagentaLLegada
    );
    appendIfDefined(
      'nivelTintaMagentaSalida',
      this.datos.nivelTintaMagentaSalida
    );
    appendIfDefined(
      'nivelTintaAmarillaLLegada',
      this.datos.nivelTintaAmarillaLLegada
    );
    appendIfDefined(
      'nivelTintaAmarillaSalida',
      this.datos.nivelTintaAmarillaSalida
    );

    // Extrae los nombres de las imágenes y videos
    const imagenes = this.datos.media.imagenes.map((img: any) => img.rutaFoto);
    const videos = this.datos.media.videos.map((video: any) => video.rutaVideo);

    // Agrega los nombres de las imágenes y videos al FormData
    imagenes.forEach((imagen: any, index: any) => {
      formData.append(`imagenes[${index}]`, imagen);
    });

    videos.forEach((video: any, index: any) => {
      formData.append(`videos[${index}]`, video);
    });

    const url = import.meta.env.NG_APP_API + '/casos/' + this.datos.id;

    this.servicioApi.putApi(url, formData).subscribe({
      next: (data) => {
        Swal.fire({
          icon: 'success',
          title: '¡Caso actualizado!',
          text: 'El caso se actualizó correctamente.',
        }).then(() => {
          setTimeout(() => {
            window.location.reload();
          }, 1000); // 1 segundo de retraso
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  mostrarMensajeError(mensaje: string) {
    Swal.fire({
      icon: 'error',
      title: 'Oops...',
      text: mensaje,
    });
  }

  onChange(event: any) {
    this.dni = event.target.value;
  }

  buscar(event: any) {
    event.preventDefault();
    this.dni = event.target.value;
    const valor = event.target.value;

    // Verificar la longitud del valor ingresado
    if (valor.length === 8 || valor.length === 11) {
      const datosFiltrados = this.arreglogetCliente.filter((cliente: any) => {
        return cliente.numeroDocumento.includes(valor);
      });
      if (datosFiltrados.length === 0) {
        this.datosFiltrados = [];
        this.mostrarMensajeError('No se encontró el cliente');
      } else {
        this.datosFiltrados = datosFiltrados;
      }
    } else {
      this.datosFiltrados = [];
      this.mostrarMensajeError(
        'El número de documento debe tener 8 o 11 dígitos.'
      );
    }
  }

  datosFiltradosClientes: any[] = [];

  clickbuscar() {
    const url = import.meta.env.NG_APP_API + '/clientes';
    const valor = this.dni;

    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        // Asignar los datos recibidos a arreglogetCliente
        this.arreglogetCliente = data;

        // Verificar la longitud del valor ingresado
        if (valor.length === 8 || valor.length === 11) {
          this.datosFiltradosClientes = this.arreglogetCliente.filter(
            (cliente: any) => {
              this.fieldlocked = false;
              return cliente.numeroDocumento.includes(valor);
            }
          );
          if (this.datosFiltradosClientes.length === 0) {
            this.datosFiltrados = [];
            this.mostrarMensajeError('No se encontró el cliente');
          } else {
            this.datosFiltrados = this.datosFiltradosClientes;
          }
        } else {
          this.datosFiltrados = [];
          this.mostrarMensajeError(
            'El número de documento debe tener 8 o 11 dígitos.'
          );
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }
}
