import { Component, ElementRef, EventEmitter, Output, ViewChild } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../../core/service/service.service';
import { initFlowbite } from 'flowbite';

@Component({
  selector: 'app-postequiposcasos',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './postequiposcasos.component.html',
  styleUrl: './postequiposcasos.component.css'
})
export class PostequiposcasosComponent {

  constructor(private servicioApi: ServiceService) {}


  @Output() Completed = new EventEmitter<any>();
 
  @ViewChild('cerrarBoton') cerrarBotonRef!: ElementRef;


  loading: boolean = false;
  arregloDistribuidores: any[] = [];
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloDistribuidores = data.content;
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }
  ngOnInit(): void {
    initFlowbite();
    this.getData();
  }

  soloNumeros(event: any) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    if (!pattern.test(inputChar)) {
      // Si el carácter ingresado no es un número, se previene su ingreso en el campo
      event.preventDefault();
    }
  }

  form: FormGroup = new FormGroup({
    modelo: new FormControl('', Validators.required),
    marca: new FormControl(''),
    color: new FormControl('', [
      Validators.required,
    ]),
    anioFabricacion: new FormControl('', [
      Validators.required,
      Validators.maxLength(4),
      Validators.minLength(4),
    ]),
    especificaciones: new FormControl(''),
    idDistribuidor: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }
  cerrarModal() {
    this.form.reset();
  }
  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Por favor llenar todo los campos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    const distribuidorSeleccionado = this.form.get('idDistribuidor')?.value;
    const idDistribuidor = parseInt(distribuidorSeleccionado, 10);

    if (isNaN(idDistribuidor)) {
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'Please select a valid distributor.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }
    const anioFabricacion2 = parseInt(
      this.form.get('anioFabricacion')?.value,
      10
    );

    const formulario = this.form.value;
    formulario.idDistribuidor = idDistribuidor;
    formulario.anioFabricacion = anioFabricacion2;

    const url = import.meta.env.NG_APP_API + '/equipos';

    this.servicioApi.postApi(url, formulario).subscribe({
      next: (data) => {
        this.loading = false;
        this.Completed.emit(true)
        Swal.fire({
          title: 'Success',
          text: 'Equipo creado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {

             // Reiniciar el formulario
          this.form.reset();

             // Simular clic en el botón 'cerrarBoton'
             this.cerrarBotonRef.nativeElement.click();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}

