import { Component, Input } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';
import AuthService from '../../../../../core/auth/auth.service';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-postclientes',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './postclientes.component.html',
  styleUrl: './postclientes.component.css',
})
export class PostclientesComponent {
  constructor(
    private dataService: ServiceService,
    private token: AuthService
  ) {}

  loading: boolean = false;




 
  idSucursalToken : string | null = null;
  ngOnInit(): void {
    initFlowbite();
    const tokenData = this.token.decodeToken();
    this.perfilSesion = tokenData.roles;


    if(this.perfilSesion !== 'ADMIN'){
      this.idSucursalToken = tokenData.idSucursal || null;
      console.log(this.idSucursalToken)
    }



  

    this.getSucursales();
    this.jalarUbigeo();
  }

  idSucursalEnviar: any;

  arregloSucursales: any[] = [];
  getSucursales() {
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
        console.log(this.arregloSucursales);
        if(this.perfilSesion !== 'ADMIN'){
          this.arregloSucursales = this.arregloSucursales.filter((sucursal: any) => sucursal.id === this.idSucursalToken);
          this.idSucursalEnviar = this.arregloSucursales[0].id;
        }


      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  perfilSesion: any;


  ubigeosData: any[] = [];
  departamentos: any[] = [];
  provincias: any[] = [];
  distritos: any[] = [];
  selectedDepartamento: string = '';
  selectedProvincia: string = '';
  selectedDistrito: string = '';

  jalarUbigeo() {
    const ubigeoUrl = import.meta.env.NG_APP_API_UBIGEO;

    this.dataService.getApi(ubigeoUrl).subscribe({
      next: (data) => {
        this.ubigeosData = data;
        this.departamentos = Array.from(
          new Set(
            this.ubigeosData
              .filter(
                (ubigeo) =>
                  ubigeo.provincia === '00' && ubigeo.distrito === '00'
              )
              .map((ubigeo) => ({
                codigo: ubigeo.departamento,
                nombre: ubigeo.nombre,
              }))
          )
        );
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  changeDepartamento(event: any) {
    this.selectedDepartamento = event.target.value;
    this.selectedProvincia = '';
    this.selectedDistrito = '';
    this.provincias = [];
    this.distritos = [];

    this.provincias = Array.from(
      new Set(
        this.ubigeosData
          .filter(
            (ubigeo) =>
              ubigeo.departamento === this.selectedDepartamento &&
              ubigeo.provincia !== '00' &&
              ubigeo.distrito === '00'
          )
          .map((ubigeo) => ({
            codigo: ubigeo.provincia,
            nombre: ubigeo.nombre,
          }))
      )
    );
  }

  changeProvincia(event: any) {
    this.selectedProvincia = event.target.value;
    this.selectedDistrito = '';
    this.distritos = [];

    this.distritos = Array.from(
      new Set(
        this.ubigeosData
          .filter(
            (ubigeo) =>
              ubigeo.departamento === this.selectedDepartamento &&
              ubigeo.provincia === this.selectedProvincia &&
              ubigeo.distrito !== '00'
          )
          .map((ubigeo) => ({
            codigo: ubigeo.distrito,
            nombre: ubigeo.nombre,
          }))
      )
    );
  }

  changeDistrito(event: any) {
    this.selectedDistrito = event.target.value;
  }

  imageUrl: string | ArrayBuffer | null = null;

  imagenParaEnviar: File | null = null;

  onFileSelected(event: any) {
    const file = event.target.files[0];
    this.imagenParaEnviar = file;
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        if (typeof e.target?.result === 'string') {
          this.imageUrl = e.target.result;
        }
      };
      reader.readAsDataURL(file);
    }
  }

  //PARA VALIDAR EL CELULAR
  validateInputNumero(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 9); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  validateInputNumeroDOCUMENTO(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 11); // Limita la longitud a 11 dígitos (para RUC)
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  numeroDocumento: any;
  changeAgarrarNumero(event: any) {
    this.numeroDocumento = event.target.value;
  }

  form: FormGroup = new FormGroup({
    nombre: new FormControl(''),
  });

  enviarDatos(e: any) {
    e.preventDefault();
    this.loading = true;
    const formulario = new FormData(e.target);

    if(this.perfilSesion !== 'ADMIN'){
      formulario.append('idSucursal', this.idSucursalEnviar );
    }
   

    const url = import.meta.env.NG_APP_API + '/clientes';

    // Encuentra el nombre del departamento, provincia y distrito basado en el código seleccionado
    const departamento = this.departamentos.find(
      (dep) => dep.codigo === this.selectedDepartamento
    )?.nombre;
    const provincia = this.provincias.find(
      (prov) => prov.codigo === this.selectedProvincia
    )?.nombre;
    const distrito = this.distritos.find(
      (dist) => dist.codigo === this.selectedDistrito
    )?.nombre;

    // Agrega el código y nombre del departamento, provincia y distrito al FormData
    if (this.selectedDepartamento && departamento) {
      formulario.append(
        'departamento',
        `${this.selectedDepartamento} - ${departamento}`
      );
    }
    if (this.selectedProvincia && provincia) {
      formulario.append(
        'provincia',
        `${this.selectedProvincia} - ${provincia}`
      );
    }
    if (this.selectedDistrito && distrito) {
      formulario.append('distrito', `${this.selectedDistrito} - ${distrito}`);
    }

    const numeroDocumento = formulario.get('numerodoc') as string;

    const Celular = formulario.get('celularescontacto') as string;

    // Validación del número de documento
    if (
      !numeroDocumento ||
      (numeroDocumento.length !== 8 && numeroDocumento.length !== 11)
    ) {
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'El número de documento debe tener 8 dígitos (DNI) o 11 dígitos (RUC).',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return; // Detiene la ejecución si la validación falla
    }

    // Validación del número de documento
    if (!Celular || Celular.length !== 9) {
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'El número de celular debe tener 9 dígitos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return; // Detiene la ejecución si la validación falla
    }

    console.log(
      formulario.get('departamento'),
      formulario.get('provincia'),
      formulario.get('distrito')
    );

    this.dataService.postApi(url, formulario).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Cliente guardado correctamente!.',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  //llave para manejar el contenedor de representante legal
  showRepLegal: boolean = false;
  //para manejar el cambio de documento
  onDocumentTypeChange(event: any) {
    const value = event.target.value;
    if (value === 'RUC') {
      this.showRepLegal = true;
    } else if (value === 'DNI') {
      this.showRepLegal = false;
    } else {
      this.showRepLegal = false;
    }
  }
}
