import { Component, Input, Output, EventEmitter } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';
import { CommonModule } from '@angular/common';
import AuthService from '../../../../../core/auth/auth.service';

@Component({
  selector: 'app-putclients',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './putclients.component.html',
  styleUrl: './putclients.component.css',
})
export class PutclientsComponent {
  constructor(private servicioApi: ServiceService,  private token: AuthService) {}

  loading: boolean = false;


  arregloSucursales: any[] = [];
  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  validateInputNumeroDOCUMENTO(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, '');
    const truncatedValue = numericValue.substring(0, 11);
    event.target.value = truncatedValue;
  }

  numeroDocumento: any;
  changeAgarrarNumero(event: any) {
    this.numeroDocumento = event.target.value;
  
  }

  validateInputNumero(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, '');
    const truncatedValue = numericValue.substring(0, 9);
    event.target.value = truncatedValue;
  }

  form: FormGroup = new FormGroup({
    nombre: new FormControl(''),
    apellido: new FormControl(''),
    tipodoc: new FormControl(''),
    numerodoc: new FormControl(''),
    direccionlegal: new FormControl(''),
    telefonoscontacto: new FormControl(''),
    celularescontacto: new FormControl(''),
    correo: new FormControl(''),
    urlweb: new FormControl(''),
    representanteLegal: new FormControl(''),
    departamento: new FormControl(''),
    provincia: new FormControl(''),
    distrito: new FormControl(''),
    idSucursal: new FormControl('', Validators.required),
  });


  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }

  @Input() id: number = 0;
  @Input() datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();

  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  
  tipoDocumento : any

  perfilSesion: any;

  datos2: any = {};
  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.perfilSesion = tokenData.roles;

    initFlowbite();
    this.jalarUbigeo();
    this.jalargetPoRID();
    this.getSucursales();
  }
  
  ubigeosData: any[] = [];
  departamentos: any[] = [];
  provincias: any[] = [];
  distritos: any[] = [];
  selectedDepartamento: string = '';
  selectedProvincia: string = '';
  selectedDistrito: string = '';
  
  jalarUbigeo(){
    const ubigeoUrl = import.meta.env.NG_APP_API_UBIGEO;
    
    this.servicioApi.getApi(ubigeoUrl).subscribe({
      next: (data) => {
        this.ubigeosData = data;
        this.departamentos = Array.from(
          new Set(
            this.ubigeosData
              .filter((ubigeo) => ubigeo.provincia === '00' && ubigeo.distrito === '00')
              .map((ubigeo) => ({
                codigo: ubigeo.departamento,
                nombre: ubigeo.nombre,
              }))
          )
        );
      },
      error: (error) => {
        console.log(error);
      },
    });
  }
  
  jalargetPoRID() {
    const url = import.meta.env.NG_APP_API + '/clientes/' + this.id;
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.datos2 = data;
  
        // Extraer solo los números de departamento, provincia y distrito
        const departamentoNumero = this.datos2.departamento ? this.datos2.departamento.split(' - ')[0] : null;
        const provinciaNumero = this.datos2.provincia ? this.datos2.provincia.split(' - ')[0] : null;
        const distritoNumero = this.datos2.distrito ? this.datos2.distrito.split(' - ')[0] : null;
  

        // Actualizar valores seleccionados
        this.selectedDepartamento = departamentoNumero;
        this.selectedProvincia = provinciaNumero;
        this.selectedDistrito = distritoNumero;
  
        // Actualizar las provincias y distritos basados en los valores seleccionados
        this.updateProvincias();
        this.updateDistritos();
  
        this.form.patchValue({
          nombre: this.datos2?.nombre ?? "",
          apellido: this.datos2?.apellido ?? "",
          tipodoc: this.datos2?.tipoDocumento ?? "",
          numerodoc: this.datos2?.numeroDocumento ?? "",
          direccionlegal: this.datos2?.direccionLegal ?? "",
          telefonoscontacto: this.datos2?.telefonosContacto ?? "",
          celularescontacto: this.datos2?.celularesContacto ?? "",
          correo: this.datos2?.correoElectronico ?? "",
          urlweb: this.datos2?.urlweb ?? "",
          representanteLegal: this.datos2?.representanteLegal ?? "",
          departamento: departamentoNumero ?? "",
          provincia: provinciaNumero ?? "",
          distrito: distritoNumero ?? "",
          idSucursal: this.datos2?.sucursal?.id ?? ""
        });
        

      },
      error: (error) => {
        console.log(error);
      }
    });
  }
  
  updateProvincias() {
    this.provincias = Array.from(
      new Set(
        this.ubigeosData
          .filter(
            (ubigeo) =>
              ubigeo.departamento === this.selectedDepartamento &&
              ubigeo.provincia !== '00' &&
              ubigeo.distrito === '00'
          )
          .map((ubigeo) => ({
            codigo: ubigeo.provincia,
            nombre: ubigeo.nombre,
          }))
      )
    );
  }
  
  updateDistritos() {
    this.distritos = Array.from(
      new Set(
        this.ubigeosData
          .filter(
            (ubigeo) =>
              ubigeo.departamento === this.selectedDepartamento &&
              ubigeo.provincia === this.selectedProvincia &&
              ubigeo.distrito !== '00'
          )
          .map((ubigeo) => ({
            codigo: ubigeo.distrito,
            nombre: ubigeo.nombre,
          }))
      )
    );
  }
  
  changeDepartamento(event: any) {
    this.selectedDepartamento = event.target.value;
    this.selectedProvincia = '';
    this.selectedDistrito = '';
    this.updateProvincias();
    this.distritos = [];
  }
  
  changeProvincia(event: any) {
    this.selectedProvincia = event.target.value;
    this.selectedDistrito = '';
    this.updateDistritos();
  }
  
  changeDistrito(event: any) {
    this.selectedDistrito = event.target.value;
  }
  









  onDocumentTypeChange(event: any) {
    this.tipoDocumento = event.target.value;
  }


  imageUrl: string | ArrayBuffer | null = null;
  imagenParaEnviar: File | null = null;

  onFileSelected(event: any) {
    const file = event.target.files[0];
    this.imagenParaEnviar = file;
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        if (typeof e.target?.result === 'string') {
          this.imageUrl = e.target.result;
        }
      };
      reader.readAsDataURL(file);
    }
  }

  

  enviarDatos() {
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Advertencia',
        text: 'Debe llenar todos los campos requeridos para actualizar.',
        icon: 'info',
        confirmButtonText: 'OK',
      });
      return;
    }
    this.loading = true;



    const formData = new FormData();

     // Encuentra el nombre del departamento, provincia y distrito basado en el código seleccionado
  const departamento = this.departamentos.find((dep) => dep.codigo === this.selectedDepartamento)?.nombre;
  const provincia = this.provincias.find((prov) => prov.codigo === this.selectedProvincia)?.nombre;
  const distrito = this.distritos.find((dist) => dist.codigo === this.selectedDistrito)?.nombre;

  // Agrega el código y nombre del departamento, provincia y distrito al FormData y al FormGroup
  if (this.selectedDepartamento && departamento) {
    formData.append('departamento', `${this.selectedDepartamento} - ${departamento}`);
  }
  if (this.selectedProvincia && provincia) {
    formData.append('provincia', `${this.selectedProvincia} - ${provincia}`);
  }
  if (this.selectedDistrito && distrito) {
    formData.append('distrito', `${this.selectedDistrito} - ${distrito}`);
  }

    // Append each form control value to the FormData object, excluding departamento, provincia, and distrito
    Object.keys(this.form.controls).forEach(key => {
      if (key !== 'departamento' && key !== 'provincia' && key !== 'distrito') {
        formData.append(key, this.form.get(key)?.value);
      }
    });

    // Append the image file if it exists
    if (this.imagenParaEnviar) {
      formData.append('imagen', this.imagenParaEnviar);
    }



    const url = import.meta.env.NG_APP_API + '/clientes/' + this.id;



    this.servicioApi.putApi(url, formData).subscribe({
      next: (data) => {
        console.log(data);
        Swal.fire({
          title: 'Success',
          text: 'Cliente actualizado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false,
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (atrapar) => {
        this.loading = false;
        console.log(atrapar);
        Swal.fire({
          title: 'Error',
          text: `${atrapar.error.message}`,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagenActualBD(id: string) {
    const url = `http://localhost:8085/clientes/imagen/${id}`;
    this.linkimagen = url;
    this.modalimg = !this.modalimg;
  }
  verimagen(link: string) {
    this.linkimagen = link;
    console.log(link);
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }
}