import { Component, inject } from '@angular/core';
import { PostclientesComponent } from '../postclientes/postclientes.component';
import { ServiceService } from '../../../../../core/service/service.service';
import { PutclientsComponent } from '../putclients/putclients.component';
import Swal from 'sweetalert2';
import { LoadingComponent } from '../../../../components/loading/loading.component';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { TableComponent } from '../../shared/table/table.component';
import AuthService from '../../../../../core/auth/auth.service';

@Component({
  selector: 'app-tablaclientes',
  standalone: true,
  imports: [
    PostclientesComponent,
    PutclientsComponent,
    LoadingComponent,
    ReactiveFormsModule,
    TableComponent,
  ],
  templateUrl: './tablaclientes.component.html',
  styleUrl: './tablaclientes.component.css',
})
export class TablaclientesComponent {
  dataService = inject(ServiceService);
  ////// Datos del modal de actualizacion de los clientes
  id: number = 0;
  datos: any = {};
  estadomodal: boolean = false;
  /////////////////////////////////////
  ///////DATOS DE LA TABLA MODULAR////
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: any[] = [];
  keyword: string = '';
  iconConfig: any = {};

  constructor(    private token: AuthService) {}
  perfilSesion
  idSucursal
  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.perfilSesion = tokenData.roles;
    this.idSucursal = tokenData.idSucursal;
    this.configureIcons(tokenData.roles);
    this.loadData({ page: 0, keyword: '', sucursal: ''  });
    
  }

  columns = [
    {
      header: 'CLIENTE',
      field: ['nombre', 'apellido'],
      subField: ['correoElectronico'],
      isTablaHeader: true,
    },
    {
      header: 'DOCUMENTO',
      field: ['tipoDocumento'],
      subField: ['numeroDocumento'],
    },
    {
      header: 'DIRECCION	',
      field: ['direccionLegal'],
      subField: ['departamento','provincia','distrito'],
    },
    {
      header: 'SUCURSAL',
      field: ['sucursal.nombre'],
    },
    { header: 'CONTACTO', field: ['celularesContacto'] },
  ];

  configureIcons(perfil: string): void {
    if (perfil === 'ADMIN') {
      this.iconConfig = {
        icons: [
          {
            name: 'editar',
            action: (id: number, dato: any) => this.enviarmodal(id, dato),
          },
          { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    } else {
      this.iconConfig = {
        icons: [
          // {
          //   name: 'editar',
          //   action: (id: number, dato: any) => this.enviarmodal(id, dato),
          // },
          // { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    }
  }


  loadData({ page, keyword, sucursal }: { page: number; keyword: string; sucursal: string }): void {
    this.arregloget = [];
    this.isLoading = true;

    let url = '';
  
   if (sucursal == '') {
       if(this.perfilSesion === 'ADMIN'){
        url = `${
          import.meta.env.NG_APP_API
        }/clientes/paginados?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
      }
      else{
          url = `${
            import.meta.env.NG_APP_API
          }/clientes/sucursal/datatable/${this.idSucursal}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
      }
    }
    else{
       url = `${
        import.meta.env.NG_APP_API
      }/clientes/sucursal/datatable/${sucursal}?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    }
  
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        console.log(data);
  
        // Procesa los datos para eliminar los números de los nombres de los departamentos, provincias y distritos
        this.arregloget = data.content.map((item:any) => ({
          ...item,
          departamento: item.departamento ? item.departamento.split(' - ')[1] : null,
          provincia: item.provincia ? item.provincia.split(' - ')[1] : null,
          distrito: item.distrito ? item.distrito.split(' - ')[1] : null,
        }));
  
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }
  

  enviarmodal(identificador: number, dato: any) {
    this.id = identificador;
    this.datos = dato;
    this.estadomodal = !this.estadomodal;
  }

  abremodal(show: boolean) {
    this.estadomodal = !this.estadomodal;
  }

  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/clientes/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            this.loadData({ page: 0, keyword: '', sucursal: '' });
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
