import { Component } from '@angular/core';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { PostDistribuidor } from '../distribuidor.interface';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-postdistribuidor',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './postdistribuidor.component.html',
  styleUrl: './postdistribuidor.component.css',
})
export class PostdistribuidorComponent {
  constructor(private servicioApi: ServiceService) {}

  ngOnInit(): void {
    initFlowbite();
  }

  form: FormGroup = new FormGroup({
    nombre: new FormControl('', Validators.required),
    ruc: new FormControl('', [
      Validators.required,
      Validators.minLength(11),
      Validators.maxLength(11),
      Validators.pattern('^[0-9]*$'),
    ]),
    direccionLegal: new FormControl('', Validators.required),
    representanteLegal: new FormControl(''),
    numTelefonos: new FormControl('', [Validators.pattern('^[0-9]*$')]),
    numCelulares: new FormControl('', [
      Validators.required,
      Validators.pattern('^[0-9]*$'),
      Validators.minLength(9),
      Validators.maxLength(9),
    ]),
    horarioAtencion: new FormControl(''),
  });
  hasErrors(formContorlName: string, errorType: string) {
    return (
      this.form.get(formContorlName)?.hasError(errorType) &&
      this.form.get(formContorlName)?.touched
    );
  }

  loading: boolean = false;
  cerrarModal() {
    this.form.reset();
  }
  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    const datos: PostDistribuidor = {
      nombre: this.form.get('nombre')?.value,
      ruc: this.form.get('ruc')?.value,
      direccionLegal: this.form.get('direccionLegal')?.value,
      numTelefonos: this.form.get('numTelefonos')?.value,
      numCelulares: this.form.get('numCelulares')?.value,
      horarioAtencion: this.form.get('horarioAtencion')?.value,
      representanteLegal: this.form.get('representanteLegal')?.value,
    };

    const url = import.meta.env.NG_APP_API + '/distribuidor';

    this.servicioApi.postApi(url, datos).subscribe({
      next: (data) => {
        console.log(data);
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Distribuidor guardado correctamente',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
