import { Component, EventEmitter, Input, Output } from '@angular/core';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-putdistruidor',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './putdistruidor.component.html',
  styleUrl: './putdistruidor.component.css',
})
export class PutdistruidorComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;

  form: FormGroup = new FormGroup({
    nombre: new FormControl('', Validators.required),
    ruc: new FormControl('', [
      Validators.required,
      Validators.minLength(11),
      Validators.maxLength(11),
      Validators.pattern('^[0-9]*$'),
    ]),
    direccionLegal: new FormControl('', Validators.required),
    representanteLegal : new FormControl(''),
    numTelefonos: new FormControl('', [
      Validators.required,
      Validators.pattern('^[0-9]*$'),
      Validators.minLength(9),
      Validators.maxLength(9),
    ]),
    numCelulares: new FormControl('', [
      Validators.required,
      Validators.pattern('^[0-9]*$'),
      Validators.minLength(9),
      Validators.maxLength(9),
    ]),
    horarioAtencion: new FormControl(''),
  });

  hasErrors(formContorlName: string, errorType: string) {
    return (
      this.form.get(formContorlName)?.hasError(errorType) &&
      this.form.get(formContorlName)?.touched
    );
  }

  ngOnInit() {
    initFlowbite();
    if (this.datos) {
      this.form.patchValue(this.datos);
    }
  }

  @Input() id: number = 0;
  @Input() datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    const datos = this.form.value;
    const url = import.meta.env.NG_APP_API + '/distribuidor/' + this.id;

    this.servicioApi.putApi(url, datos).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Distribuidor actualizado con exito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
