import { Component, EventEmitter, Output, inject } from '@angular/core';
import { ServiceService } from '../../../../../core/service/service.service';
import { GetDistribuidor } from './dato';
import { PutdistruidorComponent } from '../putdistruidor/putdistruidor.component';
import Swal from 'sweetalert2';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { TableComponent } from '../../shared/table/table.component';

@Component({
  selector: 'app-tabladistribuidor',
  standalone: true,
  imports: [PutdistruidorComponent, ReactiveFormsModule, TableComponent],
  templateUrl: './tabladistribuidor.component.html',
  styleUrl: './tabladistribuidor.component.css',
})
export class TabladistribuidorComponent {
  dataService = inject(ServiceService);
  ///////////Datos del modal de actualizacion de distribuidores
  id: number = 0;
  datos: any = {};
  estadomodal: boolean = false;
  /////////////////////////////////////
  //DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: GetDistribuidor[] = [];
  keyword: string = '';
  /////////////////////////////////////
  columns = [
    { header: 'NOMBRE', field: ['nombre'], isTablaHeader: true },
    {
      header: 'REPRESENTANTE LEGAL',
      field: ['representanteLegal'],
      isTablaHeader: true,
    },
    { header: 'RUC', field: ['ruc'] },
    { header: 'DIRECCION', field: ['direccionLegal'] },
    { header: 'TELEFONO', field: ['numTelefonos'] },
    { header: 'CELULAR', field: ['numCelulares'] },
    { header: 'HORA ATENCION', field: ['horarioAtencion'] },
  ];

  iconConfig = {
    icons: [
      {
        name: 'editar',
        action: (id: number, dato: any) => this.enviarmodal(id, dato),
      },
      { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
    ],
  };

  constructor() {}
  ngOnInit(): void {
    this.loadData({ page: 0, keyword: '' });
  }

  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.arregloget = [];
    this.isLoading = true;
    const url = `${
      import.meta.env.NG_APP_API
    }/distribuidor?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        console.log(data);
        this.arregloget = data.content;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }

  enviarmodal(identificador: number, dato: any) {
    console.log(identificador, dato);
    this.id = identificador;
    this.datos = dato;
    this.estadomodal = !this.estadomodal;
  }

  abremodal(show: boolean) {
    this.estadomodal = !this.estadomodal;
  }

  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/distribuidor/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            this.loadData({ page: 0, keyword: '' });
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
