import { Component } from '@angular/core';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-postequipos',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './postequipos.component.html',
  styleUrl: './postequipos.component.css',
})
export class PostequiposComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;
  arregloDistribuidores: any[] = [];
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloDistribuidores = data.content;
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }
  ngOnInit(): void {
    initFlowbite();
    this.getData();
  }

  soloNumeros(event: any) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    if (!pattern.test(inputChar)) {
      // Si el carácter ingresado no es un número, se previene su ingreso en el campo
      event.preventDefault();
    }
  }

  form: FormGroup = new FormGroup({
    modelo: new FormControl('', Validators.required),
    marca: new FormControl(''),
    color: new FormControl('', [
      Validators.required,
    ]),
    anioFabricacion: new FormControl('', [
      Validators.required,
      Validators.maxLength(4),
      Validators.minLength(4),
    ]),
    especificaciones: new FormControl(''),
    idDistribuidor: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }
  cerrarModal() {
    this.form.reset();
  }
  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    const distribuidorSeleccionado = this.form.get('idDistribuidor')?.value;
    const idDistribuidor = parseInt(distribuidorSeleccionado, 10);

    if (isNaN(idDistribuidor)) {
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'Please select a valid distributor.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }
    const anioFabricacion2 = parseInt(
      this.form.get('anioFabricacion')?.value,
      10
    );

    const formulario = this.form.value;
    formulario.idDistribuidor = idDistribuidor;
    formulario.anioFabricacion = anioFabricacion2;

    const url = import.meta.env.NG_APP_API + '/equipos';

    this.servicioApi.postApi(url, formulario).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Equipo creado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
