import { Component, Input, Output, EventEmitter } from '@angular/core';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import Swal from 'sweetalert2';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-putequipos',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './putequipos.component.html',
  styleUrl: './putequipos.component.css',
})
export class PutequiposComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;
  distribuidor: string = '';

  form: FormGroup = new FormGroup({
    modelo: new FormControl('', Validators.required),
    marca: new FormControl(''),
    color: new FormControl('', [
      Validators.required,
    ]),
    anioFabricacion: new FormControl('', [
      Validators.required,
      Validators.maxLength(4),
      Validators.minLength(4),
    ]),
    especificaciones: new FormControl(''),
    idDistribuidor: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }

  async ngOnInit() {
    initFlowbite();
    await this.getData();
    if (this.datos) {
      this.form.patchValue({
        nombre: this.datos.nombre,
        modelo: this.datos.modelo,
        marca: this.datos.marca,
        color: this.datos.color,
        anioFabricacion: this.datos.anioFabricacion,
        especificaciones: this.datos.especificaciones,
        idDistribuidor: String(this.datos.distribudor.id),
      });
    }
  }
  selectedOption: number = 0;
  arregloDistribuidores: any[] = [];
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor/all';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloDistribuidores = data;
        console.log(data);
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }

  soloNumeros(event: any) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    if (!pattern.test(inputChar)) {
      // Si el carácter ingresado no es un número, se previene su ingreso en el campo
      event.preventDefault();
    }
  }

  @Input() id: number = 0;
  @Input() datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    const distribuidorSeleccionado = this.form.get('idDistribuidor')?.value;
    const idDistribuidor = parseInt(distribuidorSeleccionado, 10);
    const formulario = this.form.value;
    formulario.idDistribuidor = idDistribuidor;
    const url = import.meta.env.NG_APP_API + '/equipos/' + this.id;

    this.servicioApi.putApi(url, formulario).subscribe({
      next: (data) => {
        console.log(data);
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Equipo actualizado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
