import { Component, inject } from '@angular/core';
import { ServiceService } from '../../../../../core/service/service.service';
import { PutequiposComponent } from '../putequipos/putequipos.component';
import Swal from 'sweetalert2';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { TableComponent } from '../../shared/table/table.component';
import AuthService from '../../../../../core/auth/auth.service';

@Component({
  selector: 'app-tablaequipos',
  standalone: true,
  imports: [PutequiposComponent, ReactiveFormsModule, TableComponent],
  templateUrl: './tablaequipos.component.html',
  styleUrl: './tablaequipos.component.css',
})
export class TablaequiposComponent {
  dataService = inject(ServiceService);
  ////// Datos del modal de actualizacion de equipos
  id: number = 0;
  datos: any = {};
  estadomodal: boolean = false;
  /////////////////////////////////////
  // DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: any[] = [];
  keyword: string = '';
  /////////////////////////////////////

  constructor(    private token: AuthService) {}
  columns = [
    { header: 'MARCA', field: ['marca'], isTablaHeader: true },
    { header: 'MODELO', field: ['modelo'] },
    { header: 'Tipo Equipo', field: ['color'] },
    { header: 'AÑO DE FABRICACIÓN', field: ['anioFabricacion'] },
    { header: 'ESPECIFICACIONES', field: ['especificaciones'] },
    { header: 'CAS', field: ['distribudor.nombre'] },
  ];

  iconConfig: any = {};

  configureIcons(perfil: string): void {
    if (perfil === 'ADMIN') {
      this.iconConfig = {
        icons: [
          {
            name: 'editar',
            action: (id: number, dato: any) => this.enviarmodal(id, dato),
          },
          { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    } else {
      this.iconConfig = {
        icons: [
          // {
          //   name: 'editar',
          //   action: (id: number, dato: any) => this.enviarmodal(id, dato),
          // },
          // { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    }
  }

  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.loadData({ page: 0, keyword: '' });
    this.configureIcons(tokenData.roles);
  }

  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.arregloget = [];
    this.isLoading = true;
    const url = `${
      import.meta.env.NG_APP_API
    }/equipos?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloget = data.content;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }

  enviarmodal(identificador: number, dato: any) {
    this.id = identificador;
    this.datos = dato;
    this.estadomodal = !this.estadomodal;
  }

  abremodal(show: boolean) {
    this.estadomodal = !this.estadomodal;
  }

  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/equipos/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            this.loadData({ page: 0, keyword: '' });
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
