import { Component } from '@angular/core';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-postmanuales',
  standalone: true,
  imports: [],
  templateUrl: './postmanuales.component.html',
  styleUrl: './postmanuales.component.css',
})
export class PostmanualesComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;
  arregloDistribuidores: any[] = [];

  soloNumeros(event) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    // Verificar si el carácter ingresado es un número
    if (!pattern.test(inputChar)) {
      event.preventDefault();
    }

    // Obtener el valor actual del campo de entrada
    const inputField = event.target;
    const currentValue = inputField.value;

    // Evitar que se ingresen más de 4 dígitos
    if (currentValue.length >= 4) {
      event.preventDefault();
    }
  }

  getData(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloDistribuidores = data.content;
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }
  ngOnInit(): void {
    initFlowbite();
    this.getData();
  }

  archivosPdf: any[] = [];
  lastSelectedFiles4: any;
  changePdf(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles4 = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles4) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles4.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles4[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      if (dataPdf) {
        alert('PDF repetido!');
      } else if (this.archivosPdf.length === 5) {
        alert('Solo se Admite 5 pdfs');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf.push(guardarFileyURL);
      }
    }
  }

  removePdf(url: string) {
    const index = this.archivosPdf.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf.splice(index, 1);
    }

    if (this.archivosPdf.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  lastSelectedFiles: any;

  archivosPdf2: any[] = [];
  changePdf2(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf2.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      
      if (dataPdf) {
        alert('PDF repetido!');
      } else if (this.archivosPdf2.length === 5) {
        alert('Solo se Admite 5 pdfs');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf2.push(guardarFileyURL);
      }
    }
  }

  removePdf2(url: string) {
    console.log(url);
    const index = this.archivosPdf2.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf2.splice(index, 1);
    }

    if (this.archivosPdf2.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf2'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }


  enviarDatos(e: any) {
    e.preventDefault();
    this.loading = true;

    // Mostrar Swal solo si loading es true
    if (this.loading) {
      Swal.fire({
        title: 'Guardando',
        html: `
        <style>
          .spinner {
            border: 4px solid rgba(0, 0, 0, 0.1);
            width: 36px;
            height: 36px;
            border-radius: 50%;
            border-left-color: #09f;
            animation: spin 1s linear infinite;
            display: inline-block;
            margin-top: 10px;
          }
      
          @keyframes spin {
            0% {
              transform: rotate(0deg);
            }
            100% {
              transform: rotate(360deg);
            }
          }
        </style>
        <div>Se está guardando la información, por favor espera...</div>
        <div class="spinner"></div>
      `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        showCloseButton: false,
        timerProgressBar: true,
      });
    }

    const formData = new FormData(e.target);

    // Agregar archivos PDF al FormData
    for (let i = 0; i < this.archivosPdf2.length; i++) {
      formData.append(
        'manualesDeServicio',
        this.archivosPdf2[i].file,
        this.archivosPdf2[i].file.name
      );
    }

    // Agregar archivos PDF al FormData
    for (let i = 0; i < this.archivosPdf.length; i++) {
      formData.append(
        'manualesDePartes',
        this.archivosPdf[i].file,
        this.archivosPdf[i].file.name
      );
    }

    const url = import.meta.env.NG_APP_API + '/manuales';

    this.servicioApi.postApi(url, formData).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Manual creado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  
  }




}
