import { Component, EventEmitter, Input, Output } from '@angular/core';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../../core/service/service.service';

@Component({
  selector: 'app-putmanuales',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './putmanuales.component.html',
  styleUrl: './putmanuales.component.css',
})
export class PutmanualesComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;
  distribuidor: string = '';

  form: FormGroup = new FormGroup({
    modeloEquipo: new FormControl('', Validators.required),
    marcaEquipo: new FormControl(''),
    tipoEquipo: new FormControl('', [Validators.required]),
    anioFabricacion: new FormControl('', [
      Validators.required,
      Validators.maxLength(4),
      Validators.minLength(4),
    ]),
    idDistribuidor: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }
  manualesServicios: any = [];
  manualesPartes: any = [];
  async ngOnInit() {
    initFlowbite();
    await this.getData();
    if (this.datos) {
      this.manualesServicios = this.datos.manuales.servicios;
      this.manualesPartes = this.datos.manuales.partes;
      this.form.patchValue({
        modeloEquipo: this.datos.modeloEquipo,
        marcaEquipo: this.datos.marcaEquipo,
        tipoEquipo: this.datos.tipoEquipo,
        anioFabricacion: this.datos.anioFabricacion,
        especificaciones: this.datos.especificaciones,
        idDistribuidor: String(this.datos.distribuidor.id),
      });
    }
  }
  selectedOption: number = 0;
  arregloDistribuidores: any[] = [];
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/distribuidor/all';
    this.servicioApi.getApi(url).subscribe({
      next: (data) => {
        this.arregloDistribuidores = data;
        console.log(data);
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }

  soloNumeros(event: any) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    if (!pattern.test(inputChar)) {
      // Si el carácter ingresado no es un número, se previene su ingreso en el campo
      event.preventDefault();
    }
  }

  @Input() id: number = 0;
  @Input() datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  urlPDF = import.meta.env.NG_APP_API + '/download-pdf/';

  elmiminarManualesPartesBackend(dato: any) {
    const index = this.manualesPartes.findIndex(
      (item: any) => item.url === dato
    );
    if (index !== -1) {
      this.manualesPartes.splice(index, 1);
    }

    console.log(this.manualesPartes);
  }

  archivosPdf: any[] = [];
  lastSelectedFiles4: any;
  changePdf(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles4 = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles4) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles4.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles4[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );

      const totalPdfs2 = this.archivosPdf.length + this.manualesPartes.length;

      if (dataPdf) {
        alert('PDF repetido!');
      } else if (totalPdfs2 === 5) {
        alert('Solo se Admite 5 pdfs');
        const fileInput = document.getElementById(
          'file_input_pdf'
        ) as HTMLInputElement;
        fileInput.value = '';
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf.push(guardarFileyURL);
      }
    }
  }

  removePdf(url: string) {
    const index = this.archivosPdf.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf.splice(index, 1);
    }

    if (this.archivosPdf.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  elmiminarManualesBackend(dato: any) {
    const index = this.manualesServicios.findIndex(
      (item: any) => item.url === dato
    );
    if (index !== -1) {
      this.manualesServicios.splice(index, 1);
    }

    console.log(this.manualesServicios);
  }

  lastSelectedFiles: any;

  archivosPdf2: any[] = [];
  changePdf2(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf2.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );

      const totalPdfs =
        this.archivosPdf2.length + this.manualesServicios.length;

      if (dataPdf) {
        alert('PDF repetido!');
      } else if (totalPdfs === 5) {
        alert('Solo se Admite 5 pdfs');

        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf2.push(guardarFileyURL);
      }
    }
  }

  removePdf2(url: string) {
    console.log(url);
    const index = this.archivosPdf2.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf2.splice(index, 1);
    }

    if (this.archivosPdf2.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf2'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  enviarDatos() {
    this.loading = true;

     // Mostrar Swal solo si loading es true
     if (this.loading) {
      Swal.fire({
        title: 'Actualizando',
        html: `
        <style>
          .spinner {
            border: 4px solid rgba(0, 0, 0, 0.1);
            width: 36px;
            height: 36px;
            border-radius: 50%;
            border-left-color: #09f;
            animation: spin 1s linear infinite;
            display: inline-block;
            margin-top: 10px;
          }
      
          @keyframes spin {
            0% {
              transform: rotate(0deg);
            }
            100% {
              transform: rotate(360deg);
            }
          }
        </style>
        <div>Se está actualizandeo la información, por favor espera...</div>
        <div class="spinner"></div>
      `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        showCloseButton: false,
        timerProgressBar: true,
      });
    }

    const url = import.meta.env.NG_APP_API + '/manuales/' + this.id;

    const formData = new FormData();
    const valoresFormulario = this.form.getRawValue();

    // Convertir todos los valores a string y agregarlos a formData
    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(
        key,
        value !== null && value !== undefined ? String(value) : ''
      );
    }

    // Agregar archivos PDF al FormData
    for (let i = 0; i < this.archivosPdf2.length; i++) {
      formData.append(
        'manualesDeServicio',
        this.archivosPdf2[i].file,
        this.archivosPdf2[i].file.name
      );
    }

    // Agregar archivos PDF al FormData de l backend
    for (let i = 0; i < this.manualesServicios.length; i++) {
      formData.append(
        'manualesExistentesServicio',
        this.manualesServicios[i].url
      );
    }

    // Agregar archivos PDF al FormData
    for (let i = 0; i < this.archivosPdf.length; i++) {
      formData.append(
        'manualesDePartes',
        this.archivosPdf[i].file,
        this.archivosPdf[i].file.name
      );
    }

    // Agregar archivos PDF al FormData de l backend
    for (let i = 0; i < this.manualesPartes.length; i++) {
      formData.append(
        'manualesExistentesPartes',
        this.manualesPartes[i].url
      );
    }

    this.servicioApi.putApi(url, formData).subscribe({
      next: (data) => {
        console.log(data);
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Manual actualizado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
