import { Component, inject } from '@angular/core';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';
import { TableComponent } from '../../shared/table/table.component';
import { PutmanualesComponent } from '../putmanuales/putmanuales.component';
import { ArchivosfilesComponent } from '../archivosfiles/archivosfiles.component';
import AuthService from '../../../../../core/auth/auth.service';

@Component({
  selector: 'app-tablamanuales',
  standalone: true,
  imports: [TableComponent,PutmanualesComponent,ArchivosfilesComponent],
  templateUrl: './tablamanuales.component.html',
  styleUrl: './tablamanuales.component.css'
})
export class TablamanualesComponent {
  dataService = inject(ServiceService);
  ////// Datos del modal de actualizacion de equipos
  id: number = 0;
  datos: any = {};
  estadomodal: boolean = false;
  /////////////////////////////////////
  // DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: any[] = [];
  keyword: string = '';
  /////////////////////////////////////

  constructor(
    private token: AuthService) {}

  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.configureIcons(tokenData.roles);
    this.loadData({ page: 0, keyword: '' });
  }

  columns = [
    { header: 'MARCA', field: ['marcaEquipo'], isTablaHeader: true },
    { header: 'MODELO', field: ['modeloEquipo'] },
    { header: 'Tipo Equipo', field: ['tipoEquipo'] },
    { header: 'AÑO DE FABRICACIÓN', field: ['anioFabricacion'] },
    { header: 'CAS', field: ['distribuidor.nombre'] },
  ];

  iconConfig: any = {};

  configureIcons(perfil: string): void {
    if (perfil === 'ADMIN') {
      this.iconConfig = {
        icons: [
          {
            name: 'editar',
            action: (id: number, dato: any) => this.enviarmodal(id, dato),
          },
    
          {
            name: 'files',
            action: (id: number, dato: any) => this.enviarmodal2(id, dato),
          },
    
          { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
        ],
      };
    }
    else{
      this.iconConfig = {
        icons: [
          {
            name: 'files',
            action: (id: number, dato: any) => this.enviarmodal2(id, dato),
          },
    
        ],
      };
    }
  }





  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.arregloget = [];
    this.isLoading = true;
    const url = `${
      import.meta.env.NG_APP_API
    }/manuales?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;


    // const url = `${
    //   import.meta.env.NG_APP_API
    // }/manuales`

    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloget = data.content;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }

  enviarmodal(identificador: number, dato: any) {
    this.id = identificador;
    this.datos = dato;
    this.estadomodal = !this.estadomodal;
  }

  abremodal(show: boolean) {
    this.estadomodal = !this.estadomodal;
  }

  estadomodal2: boolean = false;

  enviarmodal2(identificador: number, dato: any) {
    this.id = identificador;
    this.datos = dato;
    this.estadomodal2 = !this.estadomodal2;
  }

  abremodal2(show: boolean) {
    this.estadomodal2 = !this.estadomodal2;
  }


  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/manuales/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
            this.loadData({ page: 0, keyword: '' });
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
