import { Component, inject } from '@angular/core';
import {
  FormBuilder,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { ServiceService } from '../../../../../core/service/service.service';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-postprioridad',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './postprioridad.component.html',
  styleUrl: './postprioridad.component.css',
})
export class PostprioridadComponent {
  frmPrioridad: FormGroup;
  apiservice = inject(ServiceService);
  url = import.meta.env.NG_APP_API + '/prioridad-atencion';
  loading: boolean = false;

  constructor(private formbuild: FormBuilder) {
    this.frmPrioridad = this.formbuild.group({
      descripcion: ['', [Validators.required, Validators.maxLength(15)]],
    });
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.frmPrioridad.get(controlName)?.hasError(errorType) &&
      this.frmPrioridad.get(controlName)?.touched
    );
  }

  ngOnInit(): void {
    initFlowbite();
  }
  refreshform() {
    this.frmPrioridad.reset();
  }
  registrar() {
    this.loading = true;
    if (this.frmPrioridad.invalid) {
      this.frmPrioridad.markAllAsTouched();
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'Por favor, llene todos los campos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    this.apiservice.postApi(this.url, this.frmPrioridad.value).subscribe({
      next: (data) => {
        this.loading = false;
        console.log(data);
        Swal.fire({
          title: 'Success',
          text: 'Prioridad registrada correctamente!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            this.frmPrioridad.reset();
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
