import {
  Component,
  EventEmitter,
  Input,
  OnInit,
  Output,
  inject,
} from '@angular/core';
import {
  FormBuilder,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { GetPrioridadAtencion } from '../tablaprioridadatencion/datos';
import { ServiceService } from '../../../../../core/service/service.service';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-putprioridad',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './putprioridad.component.html',
  styleUrl: './putprioridad.component.css',
})
export class PutprioridadComponent implements OnInit {
  formPrioridad: FormGroup;
  loading: boolean = false;
  url = import.meta.env.NG_APP_API + '/prioridad-atencion';
  apiservice = inject(ServiceService);
  @Input() id: number = 0;
  @Input() datos!: GetPrioridadAtencion;
  @Output() closeModalEvent = new EventEmitter<boolean>();
  constructor(private formbuild: FormBuilder) {
    this.formPrioridad = this.formbuild.group({
      descripcion: ['', [Validators.required, Validators.maxLength(15)]],
    });
  }
  ngOnInit() {
    if (this.datos) {
      this.formPrioridad.patchValue(this.datos);
    }
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.formPrioridad.get(controlName)?.hasError(errorType) &&
      this.formPrioridad.get(controlName)?.touched
    );
  }
  actualizarDatos() {
    this.loading = true;
    if (this.formPrioridad.invalid) {
      this.loading = false;
      this.formPrioridad.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Porfavor llene todos los campos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    this.apiservice
      .putApi(this.url + '/' + this.id, this.formPrioridad.value)
      .subscribe({
        next: (data: any) => {
          this.loading = false;
          Swal.fire({
            title: 'Success',
            text: 'Prioridad actualizada correctamente!',
            icon: 'success',
            confirmButtonText: 'OK',
            allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
          }).then((result) => {
            if (result.isConfirmed) {
              this.closeModal(true); // Asumiendo que tienes una función closeModal para cerrar el modal
              window.location.reload();
            }
          });
        },
        error: (error) => {
          this.loading = false;
          let errorMessage = 'Algo salió mal';
          if (error.error && error.error.message) {
            errorMessage = error.error.message;
          }
  
          Swal.fire({
            title: 'Error',
            text: errorMessage,
            icon: 'error',
            confirmButtonText: 'OK',
          });
        },
      });
  }
  closeModal(estado: boolean) {
    this.closeModalEvent.emit(estado);
  }
}
