import { Component, inject } from '@angular/core';
import { GetPrioridadAtencion } from './datos';
import { ServiceService } from '../../../../../core/service/service.service';
import { PutprioridadComponent } from '../putprioridad/putprioridad.component';
import Swal from 'sweetalert2';
import { TableComponent } from '../../shared/table/table.component';

@Component({
  selector: 'app-tablaprioridadatencion',
  standalone: true,
  imports: [PutprioridadComponent,TableComponent],
  templateUrl: './tablaprioridadatencion.component.html',
  styleUrl: './tablaprioridadatencion.component.css',
})
export class TablaprioridadatencionComponent {
  apiservice = inject(ServiceService);
  /////////////////DATOS DE ACTUALIZACION
  idPrioridad: number = 0;
  datosPrioridad: any = {};
  estadoModal: boolean = false;
  ////////////////////////////
  //DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  datosPrioridades: GetPrioridadAtencion[] = [];
  keyword: string = '';
  /////////////////////////////////////

  columns = [
    { header: 'Nombre Prioridad Atencion',field: ['descripcion'], isTablaHeader: true },
  ];
  iconConfig = {
    icons: [
      {
        name: 'editar',
        action: (id: number, dato: any) => this.showmodal(id, dato),
      },
      { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
    ],
  };

  ngOnInit(): void {
    this.loadData({ page: 0, keyword: '' });
  }
  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.datosPrioridades=[]
    this.isLoading = true;
    const url = `${
      import.meta.env.NG_APP_API
    }/prioridad-atencion?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    this.apiservice.getApi(url).subscribe({
      next: (data) => {
        this.datosPrioridades = data.content;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }
  showmodal(id: number, datos: any) {
    this.idPrioridad = id;
    this.datosPrioridad = datos;
    this.estadoModal = !this.estadoModal;
  }
  
  closemodal(estado: boolean) {
    this.estadoModal = !this.estadoModal;
  }

  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a hacerla
        const url = import.meta.env.NG_APP_API + '/prioridad-atencion/' + id;
        this.apiservice.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            this.loadData({ page: 0, keyword: '' });
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
