import { NgClass } from '@angular/common';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import AuthService from '../../../../../core/auth/auth.service';
import { ServiceService } from '../../../../../core/service/service.service';
import { NavigationEnd, Router } from '@angular/router';

@Component({
  selector: 'app-table',
  standalone: true,
  imports: [NgClass, ReactiveFormsModule],
  templateUrl: './table.component.html',
  styleUrl: './table.component.css',
})
export class TableComponent {
  @Input() data: any[] = [];
  @Input() columns: any[] = [];
  @Input() actions: any[] = [];
  @Input() isLoading: boolean = false;
  @Input() totalPages: number = 0;
  @Input() keyword: string = '';
  @Output() loadPage = new EventEmitter<{
    page: number;
    keyword: string;
    sucursal: string;
  }>();
  @Input() iconConfig!: {
    icons: { name: string; action: (...args: any[]) => void }[];
  };

  form: FormGroup;
  page: number = 0;
  sucursalesForm: FormGroup;

  constructor(
    private authService: AuthService,
    private dataService: ServiceService,
    private router: Router
  ) {
    this.form = new FormGroup({
      search: new FormControl(''),
    });
    this.sucursalesForm = new FormGroup({
      idSucursalForm: new FormControl(''),
    });
  }
  perfildeSesion: any;
  urlVistaDelModulo: string = '';
  ngOnInit(): void {
    const decode = this.authService.decodeToken();
    if (decode) {
      this.perfildeSesion = decode.roles;
    }
    this.getSucursales();

    this.urlVistaDelModulo = this.router.url;
    console.log(this.urlVistaDelModulo);
  }

  idsucursalenviar: string = '';

  pasarAlPadreSucursal(e: any): void {
    this.idsucursalenviar = e.target.value;
    this.page = 0;
    this.loadPage.emit({
      page: this.page,
      keyword: this.keyword,
      sucursal: this.idsucursalenviar,
    });
  }

  buscar(): void {
    this.keyword = this.form.value.search;
    this.page = 0;
    this.loadPage.emit({
      page: this.page,
      keyword: this.keyword,
      sucursal: this.idsucursalenviar,
    });
  }

  reset(): void {
    this.form.reset();
    this.keyword = '';
    this.page = 0;
    this.loadPage.emit({
      page: this.page,
      keyword: this.keyword,
      sucursal: this.idsucursalenviar,
    });
  }

  handleNextPage() {
    if (this.page < this.totalPages - 1) {
      this.page++;
      this.loadPage.emit({
        page: this.page,
        keyword: this.keyword,
        sucursal: this.idsucursalenviar,
      });
    }
  }

  handlePreviousPage() {
    if (this.page > 0) {
      this.page--;
      this.loadPage.emit({
        page: this.page,
        keyword: this.keyword,
        sucursal: this.idsucursalenviar,
      });
    }
  }

  handleIconClick(
    action: (...args: any[]) => void,
    id: number | null,
    dato: any
  ): void {
    console.log(id, dato);
    if (id !== null) {
      action(id, dato);
    } else {
      action(dato);
    }
  }

  handleFilesClick(
    action: (...args: any[]) => void,
    id: number | null,
    dato: any
  ): void {
    console.log(id, dato);
    if (id !== null) {
      action(id, dato);
    } else {
      action(dato);
    }
  }

  getNestedValue(obj: any, paths: string[] | string): string {
    if (!Array.isArray(paths)) {
      paths = [paths];
    }
    return paths
      .map((path) => {
        return path.split('.').reduce((acc, part) => {
          // Check if part includes array index
          const arrayIndexMatch = part.match(/(\w+)\[(\d+)\]/);
          if (arrayIndexMatch) {
            const arrayName = arrayIndexMatch[1];
            const index = parseInt(arrayIndexMatch[2], 10);
            return acc && acc[arrayName] && acc[arrayName][index];
          }
          return acc && acc[part];
        }, obj);
      })
      .filter((value) => value !== undefined && value !== null)
      .join(' ');
  }

  arregloSucursales: any[] = [];
  getSucursales() {
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }
}
