import { Component } from '@angular/core';
import { ServiceService } from '../../../../../core/service/service.service';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-postsucursales',
  standalone: true,
  imports: [],
  templateUrl: './postsucursales.component.html',
  styleUrl: './postsucursales.component.css'
})
export class PostsucursalesComponent {
  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;


  ngOnInit(): void {
    initFlowbite();
  }


  enviarDatos(e: any) {
    e.preventDefault();
    this.loading = true;

    // Mostrar Swal solo si loading es true
    if (this.loading) {
      Swal.fire({
        title: 'Guardando',
        html: `
        <style>
          .spinner {
            border: 4px solid rgba(0, 0, 0, 0.1);
            width: 36px;
            height: 36px;
            border-radius: 50%;
            border-left-color: #09f;
            animation: spin 1s linear infinite;
            display: inline-block;
            margin-top: 10px;
          }
      
          @keyframes spin {
            0% {
              transform: rotate(0deg);
            }
            100% {
              transform: rotate(360deg);
            }
          }
        </style>
        <div>Se está guardando la información, por favor espera...</div>
        <div class="spinner"></div>
      `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        showCloseButton: false,
        timerProgressBar: true,
      });
    }

    const formData = new FormData(e.target);

    const datosEnviar ={
      nombre: formData.get('nombre'),
      direccion: formData.get('direccion'),
      telefono: formData.get('telefono'),
      descripcion: formData.get('descripcion'),
    }


   

    const url = import.meta.env.NG_APP_API + '/sucursales';

    this.servicioApi.postApi(url, datosEnviar).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Sucursales creado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }


}
