import { Component, EventEmitter, Input, Output } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../../core/service/service.service';

@Component({
  selector: 'app-putsucursales',
  standalone: true,
  imports: [ReactiveFormsModule, PutsucursalesComponent],
  templateUrl: './putsucursales.component.html',
  styleUrl: './putsucursales.component.css'
})
export class PutsucursalesComponent {

  constructor(private servicioApi: ServiceService) {}
  loading: boolean = false;
  distribuidor: string = '';

  form: FormGroup = new FormGroup({
    nombre: new FormControl('', Validators.required),
    direccion: new FormControl(''),
    telefono: new FormControl(0),
    descripcion: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }

  async ngOnInit() {
    initFlowbite();

    if (this.datos) {
      this.form.patchValue({
        nombre: this.datos.nombre,
        direccion: this.datos.direccion,
        telefono: this.datos.telefono,
        descripcion: this.datos.descripcion,
      });
    }
  }

  soloNumeros(event: any) {
    const pattern = /[0-9]/;
    const inputChar = String.fromCharCode(event.charCode);

    if (!pattern.test(inputChar)) {
      // Si el carácter ingresado no es un número, se previene su ingreso en el campo
      event.preventDefault();
    }
  }

  @Input() id: number = 0;
  @Input() datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  enviarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.loading = false;
      this.form.markAllAsTouched();
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }



    const formulario = this.form.value;

    const url = import.meta.env.NG_APP_API + '/sucursales/' + this.id;

    this.servicioApi.putApi(url, formulario).subscribe({
      next: (data) => {
        console.log(data);
        this.loading = false;
        Swal.fire({
          title: 'Success',
          text: 'Sucursal actualizado con éxito!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}

