import { Component, inject } from '@angular/core';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../../core/service/service.service';
import { TableComponent } from '../../shared/table/table.component';
import { PutequiposComponent } from '../../equipos/putequipos/putequipos.component';
import { PutsucursalesComponent } from "../putsucursales/putsucursales.component";

@Component({
  selector: 'app-tablasucursales',
  standalone: true,
  imports: [TableComponent, PutequiposComponent, PutsucursalesComponent],
  templateUrl: './tablasucursales.component.html',
  styleUrl: './tablasucursales.component.css'
})
export class TablasucursalesComponent {

  dataService = inject(ServiceService);
  ////// Datos del modal de actualizacion de equipos
  id: number = 0;
  datos: any = {};
  estadomodal: boolean = false;
  /////////////////////////////////////
  // DATOS DE LA TABLA MODULAR
  page: number = 0;
  totalPages: number = 0;
  isLoading: boolean = true;
  arregloget: any[] = [];
  keyword: string = '';
  /////////////////////////////////////

  constructor() {}

  columns = [
    { header: 'NOMBRE SUCURSAL', field: ['nombre'], isTablaHeader: true },
    { header: 'DIRECCION', field: ['direccion'] },
    { header: 'TELEFONO', field: ['telefono'] },
    { header: 'DESCRIPCION', field: ['descripcion'] },
  ];

  iconConfig = {
    icons: [
      {
        name: 'editar',
        action: (id: number, dato: any) => this.enviarmodal(id, dato),
      },
      { name: 'eliminar', action: (id: number) => this.deleteApi(id) },
    ],
  };

  ngOnInit(): void {
    this.loadData({ page: 0, keyword: '' });
  }

  loadData({ page, keyword }: { page: number; keyword: string }): void {
    this.arregloget = [];
    this.isLoading = true;

    const url = `${
      import.meta.env.NG_APP_API
    }/sucursales`;

    // const url = `${
    //   import.meta.env.NG_APP_API
    // }/sucursales?page=${page}&size=10&sort=id,desc&keyword=${keyword}`;
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloget = data;
        this.totalPages = data.totalPages;
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
        this.isLoading = false;
      },
    });
  }

  enviarmodal(identificador: number, dato: any) {
    this.id = identificador;
    this.datos = dato;
    this.estadomodal = !this.estadomodal;
  }

  abremodal(show: boolean) {
    this.estadomodal = !this.estadomodal;
  }

  // OJO ACA LO USO PARA NO CREAR MAS CARPETAS DEL DELETE OK
  deleteApi(id: number) {
    // Primero, mostramos la alerta de confirmación
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo!',
    }).then((result) => {
      if (result.isConfirmed) {
        // Si el usuario confirma la eliminación, procedemos a eliminar
        const url = import.meta.env.NG_APP_API + '/sucursales/' + id;
        this.dataService.deleteApi(url).subscribe({
          next: (data) => {
            // Actualizamos los datos después de la eliminación
            this.loadData({ page: 0, keyword: '' });
            // Mostramos una alerta de éxito
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            // Mostramos una alerta de error en caso de fallo
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
