import { Component, EventEmitter, inject, Input, Output } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import { ServiceService } from '../../../../../core/service/service.service';
import AuthService from '../../../../../core/auth/auth.service';

@Component({
  selector: 'app-put',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './put.component.html',
  styleUrl: './put.component.css',
})
export class PutComponentPerfiles {
  @Input() idPerfil: number = 0;
  @Output() addshowModalEvent = new EventEmitter<boolean>();
  @Input() nombrePerfil: string = '';
  authService = inject(AuthService);
  isModalOpen = false;
  loading: boolean = true;
  modulos: any[] = [];
  modulosdelPerfil: any[] = [];
  constructor(private dataService: ServiceService) {}

  ngOnInit() {
    initFlowbite();
    this.getallmodulos();
    this.getModulosByPerfil(this.idPerfil);
  }
  toggleCheckbox(modulo: any) {
    modulo.selected = !modulo.selected;
  }

  getallmodulos() {
    this.loading = true;
    const url = import.meta.env.NG_APP_API + '/modulos/all';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.modulos = data;
        this.markSelectedModules();
        this.loading = false;
        console.log(data);
      },
      error: (error) => {
        alert(error);
      },
    });
  }
  getModulosByPerfil(perfil: number) {
    this.loading = true;
    const url = import.meta.env.NG_APP_API + '/perfiles/' + perfil;
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.modulosdelPerfil = data.modulos;
        this.markSelectedModules();
        this.loading = false;
        console.log(data.modulos);
      },
      error: (error) => {
        alert(error);
      },
    });
  }
  markSelectedModules() {
    if (this.modulos.length > 0 && this.modulosdelPerfil.length > 0) {
      this.modulos.forEach((modulo) => {
        modulo.selected = this.modulosdelPerfil.some(
          (perfilModulo) => perfilModulo.id === modulo.id
        );
      });
    }
  }

  enviarDatos(e: any) {
    this.loading = true
    e.preventDefault();
    const selectedModulesIds = this.modulos
      .filter((modulo) => modulo.selected)
      .map((modulo) => modulo.id); // Mapear a una lista de IDs
    console.log(selectedModulesIds);
    const url =
      import.meta.env.NG_APP_API + '/perfiles/' + this.idPerfil + '/modulos';
    const datos = {
      idmodulos: selectedModulesIds,
    };
    this.dataService.postApi(url, datos).subscribe({
      next: (data) => {
        this.loading=false
        this.showmodalclose(false)
        window.location.reload()
      },
      error: (error) => {
        alert(error)
        this.loading=false
      },
    });
  }

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }
}
