import { Component, Input, Output, EventEmitter } from '@angular/core';
import { ServiceService } from '../../../../../core/service/service.service';
import {
  FormBuilder,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { CommonModule } from '@angular/common';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-actualizarusuarios',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './actualizarusuarios.component.html',
  styleUrl: './actualizarusuarios.component.css',
})
export class ActualizarusuariosComponent {
  showpassword: boolean = false;
  passwordFieldType: string = 'password';
  constructor(
    private dataService: ServiceService,
    private formbuild: FormBuilder
  ) {
    this.form = this.formbuild.group({
      idPerfil: ['', [Validators.required]],
      idDistribuidor: [''],
      idSucursal: [''],
      usuario: ['', [Validators.required, Validators.maxLength(50)]],
      nombres: ['', [Validators.required, Validators.maxLength(100)]],
      tipoDocumento: ['', [Validators.required]],
      numeroDocumento: ['', [Validators.required, Validators.maxLength(50)]],
      direccion: ['', [Validators.required, Validators.maxLength(100)]],
      email: ['', [Validators.required, Validators.maxLength(50)]],
      celulares: ['', [Validators.required, Validators.maxLength(50)]],
      telefonos: ['', [Validators.required, Validators.maxLength(50)]],
      linkRedSocial: [''],
      contrasena: [''],
    });
  }
  togglePasswordVisibility(): void {
    this.showFieldPassword = !this.showFieldPassword;
    if (!this.showFieldPassword) {
      this.form.get('contrasena')?.reset(); // Opcional: Limpiar la contraseña si se desactiva el checkbox
    }
  }
  showFieldPassword: boolean = false;
  form: FormGroup;
  @Input() id: number = 0;
  datos: any = {};
  @Output() addshowModalEvent = new EventEmitter<boolean>();
  selectedDistribuidorId: boolean = false;
  loading: boolean = false;


  
  arregloSucursales: any[] = [];
  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  ngOnInit(): void {
    this.getSucursales();
    this.getData();
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.form.get(controlName)?.hasError(errorType) &&
      this.form.get(controlName)?.touched
    );
  }

  //creamos un metodo para output
  showmodalclose(show: boolean) {
    this.addshowModalEvent.emit(show);
  }

  checkDistribuidor(perfilId: any): void {
    this.selectedDistribuidorId = perfilId === '4' || perfilId === 4;
  }

  onChangePerfil(event: any) {
    const selectedPerfilId = event?.target?.value;
    console.log(selectedPerfilId);
    this.checkDistribuidor(selectedPerfilId);
  }

  perfiles: any[] = [];
  distribuidores: any[] = [];
  getData(): void {
    const url = import.meta.env.NG_APP_API + '/usuarios/full/' + this.id;
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.datos = data;
        console.log(this.datos)
        this.form.patchValue(data);
        this.checkDistribuidor(data.idPerfil);
      },
      error: (e) => {
        console.log(e);
      },
    });

    const url2 = import.meta.env.NG_APP_API + '/perfiles';
    this.dataService.getApi(url2).subscribe({
      next: (data) => {
        this.perfiles = data;
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
    const url3 = import.meta.env.NG_APP_API + '/distribuidor';
    this.dataService.getApi(url3).subscribe({
      next: (data) => {
        console.log(data);
        this.distribuidores = data.content;
      },
      error: (atrapar) => {
        console.log(atrapar);
      },
    });
  }
  mostrarojito() {
    this.passwordFieldType =
      this.passwordFieldType === 'password' ? 'text' : 'password';
  }

  actualizarDatos() {
    this.loading = true;
    if (this.form.invalid) {
      this.form.markAllAsTouched();
      //TODO : mostrar un mensaje de alerta adecuado
      alert('Formulario invalido');
      return;
    }
    const sendData: any = {
      usuario: this.form.value.usuario,
      contrasena: null,
      nombres: this.form.value.nombres,
      tipoDocumento: this.form.value.tipoDocumento,
      numeroDocumento: this.form.value.numeroDocumento,
      direccion: this.form.value.direccion,
      email: this.form.value.email,
      celulares: this.form.value.celulares,
      telefonos: this.form.value.telefonos,
      linkRedSocial: this.form.value.linkRedSocial,
      idDistribuidor: this.form.value.idDistribuidor,
      idSucursal: this.form.value.idSucursal,
      perfiles: [Number(this.form.value.idPerfil)],
    };
    if (this.showFieldPassword) {
      sendData.contrasena = this.form.value.contrasena;
    }
    console.log(sendData);
    const url = import.meta.env.NG_APP_API + '/usuarios/' + this.id;
    this.dataService.putApi(url, sendData).subscribe({
      next: (data: any) => {
        this.showmodalclose(true);
        window.location.reload();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
