import { Component, OnInit } from '@angular/core';
import { initFlowbite } from 'flowbite';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { ServiceService } from '../../../../../core/service/service.service';
import { CommonModule } from '@angular/common';
import Swal from 'sweetalert2';

@Component({
  selector: 'componente-post-usuarios',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './post-usuarios.component.html',
  styleUrls: ['./post-usuarios.component.css'],
})
export class PostUsuariosComponent implements OnInit {
  showPassword: string = 'password';
  isModalOpen = false;
  imageUrl: string | ArrayBuffer | null = null;
  imagenParaEnviar: File | null = null;
  selectedDistribuidorId: boolean = false;
  perfiles: any[] = [];
  distribuidores: any[] = [];
  formData: any = {};
  estaOjito: boolean = false;
  loading: boolean = false;
  selectedDocument: string = ''; // Variable para almacenar el tipo de documento seleccionado

  constructor(private dataService: ServiceService) {}
  form: FormGroup = new FormGroup({
    nombres: new FormControl('', Validators.required),
    usuario: new FormControl('', Validators.required),
    contrasena: new FormControl('', Validators.required),
    tipoDocumento: new FormControl('', Validators.required),
    numeroDocumento: new FormControl('', Validators.required),
    email: new FormControl('', Validators.required),
    celulares: new FormControl('', Validators.required),
    telefonos: new FormControl('', Validators.required),
    perfiles: new FormControl('', Validators.required),
    linkRedSocial: new FormControl(''),
    direccion: new FormControl('', Validators.required),
    idDistribuidor: new FormControl(''),
    idSucursal: new FormControl(''),
  });

  clickOjo(): void {
    this.estaOjito = !this.estaOjito;
  }

  openModal() {
    this.isModalOpen = true;
  }

  closeModal() {
    this.isModalOpen = false;
    this.form.reset();
  }

  togglePasswordVisibility() {
    this.showPassword = this.showPassword === 'password' ? 'text' : 'password';
  }
  onFileSelected(event: any) {
    const file = event.target.files[0];
    this.imagenParaEnviar = file;
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        if (typeof e.target?.result === 'string') {
          this.imageUrl = e.target.result;
        }
      };
      reader.readAsDataURL(file);
    }
  }
  onChangePerfil(event: any) {
    const selectedPerfilId = event?.target?.value;
    this.selectedDistribuidorId = selectedPerfilId === '4';
  }

  getData(): void {
    const url = import.meta.env.NG_APP_API + '/perfiles';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.perfiles = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
    const url2 = import.meta.env.NG_APP_API + '/distribuidor';
    this.dataService.getApi(url2).subscribe({
      next: (data) => {
        this.distribuidores = data.content;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  arregloSucursales: any[] = [];
  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  ngOnInit(): void {
    this.getData();
    this.getSucursales();
    initFlowbite();
  }

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }

  enviarDatos(e: any) {
    this.loading = true;
    e.preventDefault();

    if (this.form.invalid) {
      this.loading = false;
      return;
    }

    const datosEnviar = {
      usuario: this.form.get('usuario')?.value,
      contrasena: this.form.get('contrasena')?.value,
      nombres: this.form.get('nombres')?.value,
      tipoDocumento: this.form.get('tipoDocumento')?.value,
      numeroDocumento: this.form.get('numeroDocumento')?.value,
      linkRedSocial: this.form.get('linkRedSocial')?.value,
      direccion: this.form.get('direccion')?.value,
      email: this.form.get('email')?.value,
      celulares: this.form.get('celulares')?.value,
      telefonos: this.form.get('telefonos')?.value,
      idDistribuidor:
        parseFloat(this.form.get('idDistribuidor')?.value) || null,
      perfiles: [Number(this.form.get('perfiles')?.value)],
      idSucursal: Number(this.form.get('idSucursal')?.value) || null,
    };

    if (datosEnviar.tipoDocumento == 'Seleccionar') {
      alert('Debe seleccionar un tipo de documento');
      this.loading = false;
      return;
    }

    if (this.form.get('perfiles')?.value == '') {
      alert('Debe seleccionar un perfil');
      this.loading = false;
      return;
    }

    const url = import.meta.env.NG_APP_API + '/usuarios';
    this.dataService.postApi(url, datosEnviar).subscribe({
      next: () => {
        window.location.reload();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  onDocumentTypeChange(event: any) {
    const selectedValue = event.target.value;
    const inputElement =
      event.target.parentElement.nextElementSibling.querySelector('input');
    this.selectedDocument = selectedValue;

    if (selectedValue === 'DNI' || selectedValue === 'RUC') {
      inputElement.value = '';
      inputElement.disabled = false;
      this.validateInputdni({ target: inputElement });
    } else {
      inputElement.value = '';
      inputElement.disabled = true;
    }
  }

  validateInputdni(event: any) {
    const inputValue = event.target.value;
    let maxLength = 0;

    if (this.selectedDocument === 'DNI') {
      maxLength = 8;
    } else if (this.selectedDocument === 'RUC') {
      maxLength = 11;
    }

    const numericValue = inputValue.replace(/\D/g, '');
    const truncatedValue = numericValue.substring(0, maxLength);
    event.target.value = truncatedValue;
  }

  validateInputcelular(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, '');
    const truncatedValue = numericValue.substring(0, 9);
    event.target.value = truncatedValue;
  }

  validateInputtelefono(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/[^\d() ]/g, '');
    const truncatedValue = numericValue.substring(0, 12);
    event.target.value = truncatedValue;
  }
}
