import { Component, OnInit, inject } from '@angular/core';

import { PostUsuariosComponent } from './post-usuarios/post-usuarios.component';
import { ServiceService } from '../../../../core/service/service.service';
import { LoadingComponent } from '../../../components/loading/loading.component';
import { ActualizarusuariosComponent } from './actualizarusuarios/actualizarusuarios.component';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { MasinfousuariosComponent } from './masinfousuarios/masinfousuarios.component';
import Swal from 'sweetalert2';
import AuthService from '../../../../core/auth/auth.service';

@Component({
  selector: 'componente-usuarios',
  standalone: true,
  imports: [
    PostUsuariosComponent,
    LoadingComponent,
    ActualizarusuariosComponent,
    ReactiveFormsModule,
    MasinfousuariosComponent
  ],
  templateUrl: './usuarios.component.html',
  styleUrl: './usuarios.component.css',
})
export class UsuariosComponent implements OnInit {

  sucursalesForm: FormGroup;
  arregloGet: any[] = [];
  datosUsuariosFiltrados: any[] = [];
  paginatedUsuarios: any[] = [];
  arregloSucursales: any[] = [];

  id: number = 0;
  idUsuario: number = 0;
  idSucursal: string = '';
  perfilSesion: string = '';
  pageSize: number = 5;
  currentPage: number = 1;
  totalPages: number = 0;
  loading: boolean = false;
  estadomodalActualizar: boolean = false;
  estadmodalVerMasInfo: boolean = false;

  constructor(private dataService: ServiceService, private token: AuthService) {
    // this.form = new FormGroup({
    //   search: new FormControl(''),
    // });
    // this.form.get('search')!.valueChanges.subscribe((value) => {
    //   this.filterData(value.toLowerCase());
    // });
    this.sucursalesForm = new FormGroup({
      idSucursalForm: new FormControl(''),
    });
  }


  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.idUsuario = tokenData.idusuario;
    this.perfilSesion = tokenData.roles;
    this.getData(this.idSucursal);
    this.getSucursales();
  }

  enviarmodal(identificador: number, dato: any) {
    this.id = dato.id;
    console.log('id', this.id);
    this.estadomodalActualizar = !this.estadomodalActualizar;
  }

  
  abremodal(show: boolean) {
    this.estadomodalActualizar = !this.estadomodalActualizar;
  }
  abremodalMasInfo(show: boolean) {
    this.estadmodalVerMasInfo = !this.estadmodalVerMasInfo;
  }


  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }


  changeSucursal(e: any) {
    this.idSucursal = e.target.value;
    this.getData(this.idSucursal);
  }
  
  url = import.meta.env.NG_APP_API + '/usuarios';
  
  getData(idSucursal: any): void {
    this.loading = true;
    this.url = idSucursal === '' 
      ? import.meta.env.NG_APP_API + '/usuarios/sucursal/0' 
      : import.meta.env.NG_APP_API + '/usuarios/sucursal/' + idSucursal;

    this.dataService.getApi(this.url).subscribe({
      next: (data) => {
        this.arregloGet = data.content;
        console.log('Data:', this.arregloGet); // Debug log
        this.datosUsuariosFiltrados = this.arregloGet;
        this.totalPages = Math.ceil(this.datosUsuariosFiltrados.length / this.pageSize);
        console.log('Data:', this.totalPages); // Debug log
        this.updatePaginatedUsuarios();
        this.loading = false;
      },
      error: (error) => {
        console.log('Error al obtener datos:', error);
        this.loading = false;
      }
    });
  }

  updatePaginatedUsuarios(): void {
    const startIndex = (this.currentPage - 1) * this.pageSize;
    const endIndex = startIndex + this.pageSize;
    this.paginatedUsuarios = this.datosUsuariosFiltrados.slice(startIndex, endIndex);
    console.log('Paginated Data:', this.paginatedUsuarios); // Debug log
  }

  // Page navigation
  previousPage(): void {
    if (this.currentPage > 1) {
      this.currentPage--;
      this.updatePaginatedUsuarios();
    }
  }

  nextPage(): void {
    if (this.currentPage < this.totalPages) {
      this.currentPage++;
      this.updatePaginatedUsuarios();
    }
  }


  
  masInformacion (id:number){
    this.id = id;
    console.log(id)
    this.abremodalMasInfo(true);
  }

  eliminarUsuario(id_usuario: number) {


    const urlEliminar = import.meta.env.NG_APP_API + '/usuarios/' + id_usuario;

    Swal.fire({
      title: '¿Estás seguro?',
      text: "¡No podrás revertir esto!",
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: 'Sí, eliminarlo'
    }).then((result) => {
      if (result.isConfirmed) {
        this.dataService.deleteApi(urlEliminar).subscribe({
          next: (data) => {
            Swal.fire(
              '¡Eliminado!',
              'El usuario ha sido eliminado.',
              'success'
            );
            this.getData(this.idSucursal);
          },
          error: (error) => {
            console.log(error);
            Swal.fire(
              'Error',
              'Ocurrió un error al eliminar el usuario.',
              'error'
            );
          }
        });
      }
    });
  }
  

}
