import { Component } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { ServiceService } from '../../core/service/service.service';
import { jsPDF } from 'jspdf';
import autoTable from 'jspdf-autotable';
import * as XLSX from 'xlsx';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-reportes-calificacion',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule], // Asegúrate de importar CommonModule
  templateUrl: './reportes-calificacion.component.html',
  styleUrls: ['./reportes-calificacion.component.css'],
})
export class ReportesCalificacionComponent {
  form: FormGroup;
  arregloget: any[] = [];
  datosCasosPaginados: any[] = [];
  pageSize: number = 10; // Tamaño de página
  currentPage: number = 1; // Página actual
  datosCasosFiltrados: any[] = []; // Nueva variable para mantener los datos filtrados
  isLoading: boolean = false;
  urlsPds = import.meta.env.NG_APP_API + '/download-pdf/';

  constructor(private dataService: ServiceService) {
    this.form = new FormGroup({
      search: new FormControl(''),
    });
  }

  ngOnInit(): void {
    this.getData();
    this.form.get('search')!.valueChanges.subscribe((value) => {
      this.currentPage = 1; // Reinicia a la primera página al cambiar el filtro
      this.filterData(value.toLowerCase());
    });
  }

  getData(): void {
    this.isLoading = true;

    const url = import.meta.env.NG_APP_API + '/reportes/casos/all';

    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloget = data;
        this.filterData(this.form.value.search);
        this.isLoading = false;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  filterData(value: string) {
    if (!value) {
      this.datosCasosFiltrados = this.arregloget.filter(
        (val) =>
          val.estadoCaso === 'Finalizado' || val.estadoCaso === 'Rechazado'
      ); // Si el valor está vacío, muestra todos los datos con estado 'Finalizado'
    } else {
      this.datosCasosFiltrados = this.arregloget.filter((val) => {
        return (
          val.calificacion !== null &&
          val.calificacion.toString().includes(value)
        );
      });
    }
    this.paginate();
  }

  archivosPDFSDiagnostico: any[] = [];
  archivosPDFSPruebaCalidad: any[] = [];
  estadomodal: boolean = false;
  isLoadingTable: boolean = false;
  createReport(nrCaso: string) {
    this.estadomodal = !this.estadomodal;
    this.isLoadingTable = true;
    const datos = {
      nrCaso: nrCaso,
    };

    const url = import.meta.env.NG_APP_API + '/search-seguimiento-client';

    this.dataService.postApi(url, datos).subscribe({
      next: (data) => {
        this.isLoadingTable = false;
        this.archivosPDFSDiagnostico = [];
        this.archivosPDFSPruebaCalidad = [];
        console.log(this.archivosPDFSDiagnostico);
        console.log(this.archivosPDFSPruebaCalidad);
        if (data && data.diagnostico && data.diagnostico.rutasPdf.length > 0) {
          this.archivosPDFSDiagnostico = data.diagnostico.rutasPdf;
        }
        if (data && data.pruebaCalidad && data.diagnostico.media) {
          this.archivosPDFSPruebaCalidad = data.pruebaCalidad.rutasPdf;
        }
      },
    });
  }
  showmodalclose(show: boolean) {
    this.estadomodal = show;
  }

  paginate() {
    const startIndex = (this.currentPage - 1) * this.pageSize;
    const endIndex = startIndex + this.pageSize;
    this.datosCasosPaginados = this.datosCasosFiltrados.slice(
      startIndex,
      endIndex
    );
  }

  previousPage() {
    if (this.currentPage > 1) {
      this.currentPage--;
      this.paginate();
    }
  }

  nextPage() {
    const totalPages = Math.ceil(
      this.datosCasosFiltrados.length / this.pageSize
    );
    if (this.currentPage < totalPages) {
      this.currentPage++;
      this.paginate();
    }
  }

  exportToPDF() {
    const doc = new jsPDF();
    autoTable(doc, {
      head: [
        [
          'Nº CASO',
          'TIPO SERV',
          'CLIENTE',
          'TIPO DOC',
          'EQUIPO',
          'SOPORTE',
          'CALIFICACIÓN',
          'FECHA',
        ],
      ],
      body: this.datosCasosFiltrados.map((row) => [
        row.numeroCaso,
        row.tipoServicio,
        row.cliente.nombre +
          ' ' +
          row.cliente.apellido +
          '\n ' +
          row.cliente.correoElectronico,
        row.cliente.tipoDocumento + '\n' + row.cliente.numeroDocumento,
        row.equipo.marca + '\n' + row.equipo.modelo,
        row.usuarioAsignado.nombres + '\n' + row.usuarioAsignado.email,
        row.calificacion !== null
          ? row.calificacion + ' estrellas'
          : 'No calificado',
        row.fechaRegistro,
      ]),
    });
    doc.save('Reporte_calificacion_por_casos.pdf');
  }

  exportToExcel() {
    // Mapea los datos a un formato adecuado para la exportación
    const formattedData = this.datosCasosFiltrados.map((dato) => ({
      'Número de Caso': dato.numeroCaso,
      'Tipo de Servicio': dato.tipoServicio,
      Cliente: `${dato.cliente.nombre} ${dato.cliente.apellido}`,
      'Correo Electrónico': dato.cliente.correoElectronico,
      'Tipo de Documento': dato.cliente.tipoDocumento,
      'Número de Documento': dato.cliente.numeroDocumento,
      Equipo: `${dato.equipo.marca} ${dato.equipo.modelo}`,
      'Nro Serie Equipo': dato.numeroSerie,
      'Soporte Asignado': dato.usuarioAsignado.nombres,
      'Correo del Soporte': dato.usuarioAsignado.email,
      'Periodo de Garantía': dato.periodoGarantiaMeses + ' ' + 'Meses',
      Prioridad: dato.prioridad,
      Sede: dato.sede,
      Etapa: dato.etapa,
      'Orden servicio': dato.ordenServicio,
      Calificación:
        dato.calificacion !== null
          ? dato.calificacion + ' estrellas'
          : 'No calificado',
      'Fecha de Registro': dato.fechaRegistro,
      'Próximo Mantenimiento': dato.proximoMantenimiento,
    }));

    const worksheet = XLSX.utils.json_to_sheet(formattedData);
    const workbook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(workbook, worksheet, 'Reporte');
    XLSX.writeFile(workbook, 'Reporte_calificacion_por_casos.xlsx');
  }
}
