import { Component, inject } from '@angular/core';
import {
  FormBuilder,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';
import { ServiceService } from '../../../core/service/service.service';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-post-tipo-mantenimiento',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './post-tipo-mantenimiento.component.html',
  styleUrl: './post-tipo-mantenimiento.component.css',
})
export class PostTipoMantenimientoComponent {
  frmTipoMantenimiento: FormGroup;
  apiService = inject(ServiceService);
  url = import.meta.env.NG_APP_API + '/tipoMantenimiento';
  loading: boolean = false;

  constructor(private formbuild: FormBuilder) {
    this.frmTipoMantenimiento = this.formbuild.group({
      descripcion: ['', [Validators.required, Validators.maxLength(100)]],
    });
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.frmTipoMantenimiento.get(controlName)?.hasError(errorType) &&
      this.frmTipoMantenimiento.get(controlName)?.touched
    );
  }

  ngOnInit(): void {
    initFlowbite();
  }
  refreshform() {
    this.frmTipoMantenimiento.reset();
  }
  registrar() {
    this.loading = true;
    if (this.frmTipoMantenimiento.invalid) {
      this.frmTipoMantenimiento.markAllAsTouched();
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'Please fill out all required fields.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

    this.apiService
      .postApi(this.url, this.frmTipoMantenimiento.value)
      .subscribe({
        next: (data) => {
          this.loading = false;
          console.log(data);
          Swal.fire({
            title: 'Success',
            text: 'Mantenimiento guardado correctamente.',
            icon: 'success',
            confirmButtonText: 'OK',
            allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
          }).then((result) => {
            if (result.isConfirmed) {
              this.frmTipoMantenimiento.reset();
              window.location.reload();
            }
          });
        },
        error: (error) => {
          this.loading = false;
          let errorMessage = 'Algo salió mal';
          if (error.error && error.error.message) {
            errorMessage = error.error.message;
          }
  
          Swal.fire({
            title: 'Error',
            text: errorMessage,
            icon: 'error',
            confirmButtonText: 'OK',
          });
        },
      });
  }
}
