import { Component, inject } from '@angular/core';
import { PutTipoMantenimientoComponent } from '../put-tipo-mantenimiento/put-tipo-mantenimiento.component';
import { ServiceService } from '../../../core/service/service.service';
import { GetTipoMantenimiento } from './datos';
import Swal from 'sweetalert2';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import AuthService from '../../../core/auth/auth.service';

@Component({
  selector: 'app-tabla-tipo-mantenimiento',
  standalone: true,
  imports: [PutTipoMantenimientoComponent, ReactiveFormsModule],
  templateUrl: './tabla-tipo-mantenimiento.component.html',
  styleUrl: './tabla-tipo-mantenimiento.component.css',
})
export class TablaTipoMantenimientoComponent {
  apiservice = inject(ServiceService);
  datosTipoMantenimientos: GetTipoMantenimiento[] = [];
  datosTipoMantenimientosPaginados: GetTipoMantenimiento[] = []; // Nueva variable para mantener los datos paginados

  // datos que se envian al modal en modo de @Input
  idTipoMantenimiento: number = 0;
  datosTipoMantenimiento: any = {};
  // estado del modal
  estadoModal: boolean = false;
  estadoModalEliminar: boolean = false;
  url = import.meta.env.NG_APP_API + '/tipoMantenimiento';
  pageSize: number = 10; // Tamaño de página
  currentPage: number = 1; // Página actual

  //search
  datosTipoMantenimientosFiltrados: GetTipoMantenimiento[] = []; // Nueva variable para mantener los datos filtrados
  form: FormGroup;

  constructor(private token: AuthService) {
    this.form = new FormGroup({
      search: new FormControl(''),
    });
    this.form.get('search')!.valueChanges.subscribe((value) => {
      this.filterData(value.toLowerCase());
    });
  }

  perfilSesion: string = '';

  ngOnInit(): void {
    const tokenData = this.token.decodeToken();
    this.perfilSesion = tokenData.roles;
    this.getData();
  }

  getData() {
    this.apiservice.getApi(this.url).subscribe({
      next: (data) => {
        this.datosTipoMantenimientos = data;
        this.filterData(this.form.value.search);
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  filterData(filtro: string) {
    this.datosTipoMantenimientosFiltrados = this.datosTipoMantenimientos.filter(
      (item) => item.descripcion.toLowerCase().includes(filtro)
    );
    this.paginate(filtro);
  }

  paginate(filter: string) {
    const startIndex = (this.currentPage - 1) * this.pageSize;
    const endIndex = startIndex + this.pageSize;
    if (filter === '') {
      this.datosTipoMantenimientosPaginados =
        this.datosTipoMantenimientosFiltrados.slice(startIndex, endIndex);
    } else {
      this.datosTipoMantenimientosPaginados =
        this.datosTipoMantenimientosFiltrados.slice(0, 10);
    }
  }

  previousPage() {
    if (this.currentPage > 1) {
      this.currentPage--;
      this.filterData(this.form.value.search);
    }
  }

  nextPage() {
    const totalPages = Math.ceil(
      this.datosTipoMantenimientos.length / this.pageSize
    );
    if (this.currentPage < totalPages) {
      this.currentPage++;
      this.filterData(this.form.value.search);
    }
  }
  showModal(id: number, datos: any) {
    console.log(id, datos);
    this.idTipoMantenimiento = id;
    this.datosTipoMantenimiento = datos;
    this.estadoModal = !this.estadoModal;
    console.log(id);
    console.log(datos);
  }
  closeModal(estado: boolean) {
    this.estadoModal = !this.estadoModal;
  }
  showModalEliminar(id: number) {
    this.idTipoMantenimiento = id;
    console.log(id);
    this.estadoModalEliminar = !this.estadoModalEliminar;
  }
  closeModalEliminar(estado: boolean) {
    this.estadoModalEliminar = !this.estadoModalEliminar;
  }

  deleteApi(id: number) {
    Swal.fire({
      title: '¿Estás seguro?',
      text: '¡No podrás revertir esto!',
      icon: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#3085d6',
      cancelButtonColor: '#d33',
      confirmButtonText: '¡Sí, bórralo!',
    }).then((result) => {
      if (result.isConfirmed) {
        this.apiservice.deleteApi(this.url + '/' + id).subscribe({
          next: (data) => {
            this.getData();
            Swal.fire(
              '¡Eliminado!',
              'El elemento ha sido eliminado.',
              'success'
            );
          },
          error: (error) => {
            console.log(error);
            Swal.fire('Error', 'No se pudo eliminar el elemento.', 'error');
          },
        });
      }
    });
  }
}
