import { HttpClient } from '@angular/common/http';
import { Component } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';

@Component({
  selector: 'app-imagenes',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './imagenes.component.html',
  styleUrl: './imagenes.component.css',
})
export class ImagenesComponent {
  constructor(private http: HttpClient) {}

  imagenes: any[] = [];
  imagenes2: File[] = []; // Cambiar el tipo de datos a File
  mostrarModal: boolean = false;
  imagenSeleccionada: string = '';

  onFileSelected(event: any) {
    const files = event.target.files;
    if (files) {
      for (let i = 0; i < files.length; i++) {
        const file = files[i];
        const reader = new FileReader();
        reader.onload = (e) => {
          if (typeof e.target?.result === 'string') {
            const imagenBase64 = e.target.result;
            // Verificar si la imagen ya ha sido cargada
            const imageExists = this.imagenes.some((imagen: string) => imagen === imagenBase64);
            if (!imageExists) {
              if (this.imagenes.length < 4) {
                // Limitar a 4 imágenes
                this.imagenes2.push(file); // Agregar el objeto File al arreglo
                this.imagenes.push(imagenBase64);
                if (this.imagenes.length === files.length) {
                  // Si se han seleccionado todas las imágenes, aquí puedes realizar alguna acción
                  console.log(
                    'Todas las imágenes han sido seleccionadas:',
                    this.imagenes
                  );
                }
              } else {
                // Si se intenta cargar más de 4 imágenes, mostrar una alerta
                alert('Solo se pueden subir hasta 4 imágenes');
                 // Detener el bucle
              }
            } else {
              // Si la imagen ya ha sido cargada previamente, mostrar una alerta
              alert('La imagen ya ha sido cargada previamente');
            }
          }
        };
        reader.readAsDataURL(file);
      }
    }
  }

  eliminarImagen(index: number) {
    console.log(this.imagenes);
    this.imagenes.splice(index, 1);
    this.imagenes2.splice(index, 1);
    if (this.imagenes.length === 0) {
      const fileInput = document.getElementById(
        'file_input'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  enviarDatos() {
    const formData = new FormData();

    // Agregar los datos del formulario al FormData
    formData.append('idCliente', '0');
    formData.append('tipoServicio', 'string');
    formData.append('descripcion', 'string');
    formData.append('numeroCaso', 'string');
    formData.append('aceptoTerminos', 'string');
    formData.append('ordenServicio', 'string');
    formData.append('idUsuarioAsignado', '0');
    formData.append('estadoCaso', 'string');
    formData.append('idEquipo', '0');
    formData.append('idPrioridadAtencion', '0');

    // Agregar las imágenes al FormData
    for (let i = 0; i < this.imagenes2.length; i++) {
      formData.append('imagenes[]', this.imagenes2[i], this.imagenes2[i].name);
    }

    // Enviar los datos al backend
    this.http.post('http://localhost:8085/casos', formData).subscribe({
      next: (response: any) => {
        console.log('Respuesta del backend:', response);
      },
      error: (error: any) => {
        console.error('Error al enviar los datos:', error);
        // Mostrar un mensaje de error
      },
    });
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagen(link: string) {
    this.linkimagen = link;
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }
}
