import { Component, OnInit } from '@angular/core';
import {
  AbstractControl,
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  ValidationErrors,
  Validators,
} from '@angular/forms';
import * as jwt from 'jwt-decode';
import { ServiceService } from '../core/service/service.service';
import { CommonModule } from '@angular/common';
@Component({
  selector: 'app-login',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './login.component.html',
  styleUrl: './login.component.css',
})
export class LoginComponent implements OnInit {
  ngOnInit() {
    localStorage.removeItem('token');
  }

  constructor(private serviceLogin: ServiceService) {}

  showPassword: boolean = false;

  loading: boolean = false;

  clickMostrarPassword(): void {
    this.showPassword = !this.showPassword;
  }

  formulario = new FormGroup({
    usuario: new FormControl('', [
      Validators.required,
      Validators.email,
      this.noSpacesValidator,
    ]),
    contrasena: new FormControl('', [Validators.required]),
  });

  hasErrors(formContorlName: string, errorType: string) {
    return (
      this.formulario.get(formContorlName)?.hasError(errorType) &&
      this.formulario.get(formContorlName)?.touched
    );
  }

  noSpacesValidator(control: AbstractControl): ValidationErrors | null {
    if (control.value && control.value.includes(' ')) {
      return { noSpaces: true };
    }
    return null;
  }

  errorEnSolicitud: any;

  sendForm() {
    if (this.formulario.invalid) {
      this.formulario.markAllAsTouched();
      return;
    }
    this.loading = true;
    const datosEnviar: any = this.formulario.getRawValue();
    const urlApi = import.meta.env.NG_APP_API + '/auth/login';

    this.serviceLogin.postLogin(urlApi, datosEnviar).subscribe({
      next: (respuesta: any) => {
        // Almacena el token en el localStorage
        localStorage.setItem('token', respuesta.token);
        const decodedToken = jwt.jwtDecode(respuesta.token) as any;
        if (decodedToken) {
          this.loading = false;
          localStorage.setItem('token', respuesta.token);
          window.location.href = '/dashboard';
          this.formulario.reset();
        } else {
          this.formulario.reset();
          this.loading = false;
          window.location.href = '/';
        }
      },
      error: (atrapar) => {
        this.loading = false;
        this.errorEnSolicitud = atrapar.error.message
          ? atrapar.error.message
          : 'Error en el servidor. Intente nuevamente.';
      },
    });
  }
}
