import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ServiceService } from '../core/service/service.service';

@Component({
  selector: 'app-pdf',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './pdf.component.html',
  styleUrl: './pdf.component.css'
})
export class PdfComponent {
  consulta: string = '';
  sugerencias: any[] = [];
  sugerenciasFiltradas: any[] = [];
  sugerenciasVisibles: boolean = false;
  idSeleccionado: number | null = null;

  constructor(private dataService: ServiceService) {}

  ngOnInit(): void {
    this.Consultar();
  }

  Consultar(): void {
    const url = 'https://jsonplaceholder.typicode.com/posts';
    this.dataService.getApi(url).subscribe((data: any) => {
      this.sugerencias = data;
      this.filtrarSugerencias();
    });
  }

  mostrarSugerencias(): void {
    this.sugerenciasVisibles = true;
    this.filtrarSugerencias();
  }

  ocultarSugerencias(): void {
    setTimeout(() => this.sugerenciasVisibles = false, 200);
  }

  filtrarSugerencias(): void {
    this.sugerenciasFiltradas = this.sugerencias
      .filter(sugerencia => sugerencia.title.toLowerCase().includes(this.consulta.toLowerCase()))
      .slice(0, 10);  // Limitar a las primeras 10 sugerencias
  }

  seleccionarSugerencia(sugerencia: any): void {
    this.consulta = sugerencia.title;
    this.idSeleccionado = sugerencia.id;
    this.sugerenciasVisibles = false;
    console.log(`ID seleccionado: ${this.idSeleccionado}`);
  }

  alIngresar(event: any): void {
    this.consulta = event.target.value;
    this.filtrarSugerencias();
  }
}