import { ChangeDetectorRef, Component, Input } from '@angular/core';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';
import { ServiceService } from '../../core/service/service.service';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-etapa1-editar',
  standalone: true,
  imports: [ReactiveFormsModule, CommonModule],
  templateUrl: './etapa1-editar.component.html',
  styleUrl: './etapa1-editar.component.css'
})
export class Etapa1EditarComponent {
  constructor(private dataService: ServiceService, private cdr: ChangeDetectorRef) { }
  loading: boolean = false;
  
  imagenes: any = [];
  imagenesBackend: any = [];

  @Input() datos: any = {};
  isDisabled = false;

  form = new FormGroup({
    numeroCaso: new FormControl(''),
    dni: new FormControl(''),
    nombreCliente: new FormControl(''),
    direccionCliente: new FormControl(''),
    celularCliente: new FormControl(''),
    tipoServicio: new FormControl(''),
    ordenServicio: new FormControl(''),
    idUsuarioAsignado: new FormControl(''),
    idDistribuidor: new FormControl(''),
    idEquipo: new FormControl(''),
    idCliente: new FormControl(''),
    numSerie: new FormControl(''),
    idPrioridadAtencion: new FormControl(''),
    descripcion: new FormControl(''),
    aceptoTerminos: new FormControl(''),
    garantia: new FormControl(''),
    proximoMantenimiento: new FormControl(''),
    sede :   new FormControl(''),
    periodoGarantiaMeses : new FormControl(''),
    calificacion : new FormControl(''),
    observaciones : new FormControl(''),
    estadoCaso: new FormControl(''),
    fechaRegistro: new FormControl(''),
    areaPerteneciente : new FormControl(''),
    usuarioRegistro : new FormControl(''),
    etapa : new FormControl(''),
    idSucursal: new FormControl('', Validators.required),
  });

  hasErrors(formControlName: string, errorType: string) {
    return (
      this.form.get(formControlName)?.hasError(errorType) &&
      this.form.get(formControlName)?.touched
    );
  }

  datos_etapa1: any;


  mostrarModal: boolean = false;
  fieldlocked: boolean = true;
  imagenSeleccionada: string = '';

  arreglogetCliente: any[] = [];
  arreglogetUsuarios: any[] = [];
  arreglogetPrioridad: any[] = [];

  arreglogetEquipos: any[] = [];
  arreglogetDistribuidor: any[] = [];

  equiposFiltrados: any[] = [];

  dni: string = '';
  urlMedia = import.meta.env.NG_APP_API + '/media/'


  arregloSucursales: any[] = [];
  getSucursales(){
    const url = import.meta.env.NG_APP_API + '/sucursales';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloSucursales = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }


  ngOnInit(): void {
    initFlowbite();
    this.getSucursales();
    this.getDataUsuarios();
    this.getDataPrioridad();
    this.getDistribuidor().then(() => {
      this.getDataEquipos();
    });

    this.datos_etapa1 = this.datos.caso;
    console.log(this.datos_etapa1)
    this.imagenesBackend = this.datos_etapa1.media.imagenes;


    if (this.datos_etapa1) {
      this.form.patchValue({
        numeroCaso: this.datos_etapa1?.numeroCaso ?? '',
        dni: this.datos_etapa1?.cliente?.numeroDocumento ?? '',
        nombreCliente: `${this.datos_etapa1?.cliente?.nombre ?? ''} ${this.datos_etapa1?.cliente?.apellido ?? ''}`,
        direccionCliente: this.datos_etapa1?.cliente?.direccionLegal ?? '',
        celularCliente: this.datos_etapa1?.cliente?.telefonosContacto ?? '',
        tipoServicio: this.datos_etapa1?.tipoServicio ?? '',
        ordenServicio: this.datos_etapa1?.ordenServicio ?? '',
        idUsuarioAsignado: this.datos_etapa1?.usuarioAsignado?.id ?? '',
        idCliente: this.datos_etapa1?.cliente?.id ?? '',
        idDistribuidor: this.datos_etapa1?.equipo?.distribudor?.id ?? '',
        idEquipo: this.datos_etapa1?.equipo?.id ?? '',
        numSerie: this.datos_etapa1?.numeroSerie ?? '',
        idPrioridadAtencion: this.datos_etapa1?.idPrioridad ?? '',
        descripcion: this.datos_etapa1?.descripcion ?? '',
        aceptoTerminos: this.datos_etapa1?.aceptoTerminos ?? '',
        garantia: this.datos_etapa1?.garantia ?? '',
        proximoMantenimiento: this.datos_etapa1?.proximoMantenimiento ?? '',
        sede: this.datos_etapa1?.sede ?? '',
        periodoGarantiaMeses: this.datos_etapa1?.periodoGarantiaMeses ?? '',
        observaciones: this.datos_etapa1?.observaciones ?? '',
        estadoCaso: this.datos_etapa1?.estadoCaso ?? '',
        fechaRegistro: this.datos_etapa1?.fechaRegistro ?? '',
        areaPerteneciente: this.datos_etapa1?.areaPerteneciente ?? '',
        usuarioRegistro: this.datos_etapa1?.usuarioRegistro ?? '',
        etapa: this.datos_etapa1?.etapa ?? '',
        calificacion: this.datos_etapa1?.calificacion ?? '',
        idSucursal: this.datos_etapa1?.sucursal?.id ?? ''
      });
      



      
       
      this.onDistribuidorClick({ target: { value: this.datos_etapa1.equipo.distribudor.id } });
    }
  }


  nombreCliente: any;

  tipodocumento: string = '';

  razonsocial: string = '';

  clickbuscar() {
    const url = import.meta.env.NG_APP_API + '/clientes';
    const valor = this.dni;



  
    console.log(valor);
  
    // Reiniciar datosFiltrados al hacer clic en buscar
    this.datosFiltrados = [];
  
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        // Asignar los datos recibidos a arreglogetCliente
        this.arreglogetCliente = data;
  
        // Verificar la longitud del valor ingresado
        if (valor.length === 8 || valor.length === 11) {
          // Filtrar clientes por número de documento exacto
          const datosFiltrados = this.arreglogetCliente.filter(
            (cliente: any) => cliente.numeroDocumento === valor
          );
  
          if (datosFiltrados.length === 0) {
            this.datosFiltrados = [];
            this.mostrarMensajeError('No se encontró el cliente');
          } else {
            this.datosFiltrados = datosFiltrados;
            console.log(datosFiltrados);

                // Actualizar el formulario con el valor de dni
            this.form.patchValue({ idCliente: datosFiltrados[0].id });

  
            // Asignar los datos del cliente a las variables correspondientes
            this.nombreCliente = datosFiltrados[0].nombre + ' ' + datosFiltrados[0].apellido;
            this.tipodocumento = datosFiltrados[0].tipoDocumento;
            console.log(this.tipodocumento);
            this.razonsocial = datosFiltrados[0].representanteLegal ? datosFiltrados[0].representanteLegal : '';
            this.fieldlocked = false;
          }
        } else {
          this.datosFiltrados = [];
          this.mostrarMensajeError(
            'El número de documento debe tener 8 o 11 dígitos.'
          );
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }


  equiposData : any[] = []; 

  getDataEquipos(): void {
    const url = import.meta.env.NG_APP_API + '/equipos/all';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetEquipos = data;
        if (this.datos_etapa1) {
          this.equiposData = this.arreglogetEquipos.filter((equipo: any) => equipo.id === this.datos_etapa1.equipo.id);
    
          // Verifica que hay un equipo seleccionado
          const equipoSeleccionado = this.equiposData.length > 0 ? this.equiposData[0] : null;
          console.log(equipoSeleccionado); // Log para verificar el equipo seleccionado
    
          if (equipoSeleccionado) {
            const inputElement = document.getElementById('autocompletado-input') as HTMLInputElement;
            if (inputElement) {
              inputElement.value = `${equipoSeleccionado.color} - ${equipoSeleccionado.marca} - ${equipoSeleccionado.modelo}`;
            }
            
            // Actualiza el valor de idEquipo utilizando patchValue
            this.form.patchValue({
              idEquipo: equipoSeleccionado.id
            });
          }
    
          this.onDistribuidorClick({ target: { value: this.datos_etapa1.equipo.distribudor.id } });
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }
  

    // Método para manejar el clic en un distribuidor
    onDistribuidorClick(e: any) {
      console.log(e.target.value);
      this.distribuidorSeleccionado = e.target.value;
      this.filtrarEquiposPorDistribuidor(this.distribuidorSeleccionado);
    }
  

  getDistribuidor(): Promise<void> {
    return new Promise((resolve, reject) => {
      const url = import.meta.env.NG_APP_API + '/distribuidor/all';
      this.dataService.getApi(url).subscribe({
        next: (data) => {
          this.arreglogetDistribuidor = data;
          resolve();
        },
        error: (error) => {
          console.log(error);
          reject(error);
        },
      });
    });
  }

  distribuidorSeleccionado: string = '';

  filtrarEquiposPorDistribuidor(distribuidor: string) {
    this.equiposFiltrados = this.arreglogetEquipos.filter(
      (equipo) => equipo.distribudor.id === Number(distribuidor)
    );
  }

  consulta: string = '';
  sugerencias: any[] = [];
  sugerenciasFiltradas: any[] = [];
  sugerenciasVisibles: boolean = false;
  idSeleccionado: number | null = null;


  mostrarSugerencias(): void {
    this.sugerenciasVisibles = true;
    this.filtrarSugerencias();
  }

  ocultarSugerencias(): void {
    setTimeout(() => this.sugerenciasVisibles = false, 200);
  }

  filtrarSugerencias(): void {
    const consultaLowerCase = this.consulta.toLowerCase();
    
    this.sugerenciasFiltradas = this.equiposFiltrados
      .filter(sugerencia => {
        const modeloLowerCase = sugerencia.modelo.toLowerCase();
        const marcaLowerCase = sugerencia.marca.toLowerCase();
        const colorLowerCase = sugerencia.color.toLowerCase();
        return modeloLowerCase.includes(consultaLowerCase) || 
               marcaLowerCase.includes(consultaLowerCase) || 
               colorLowerCase.includes(consultaLowerCase);
      })  // Limitar a las primeras 10 sugerencias
  }
  

  seleccionarSugerencia(sugerencia: any): void {
    this.consulta = `${sugerencia.color} - ${sugerencia.marca} - ${sugerencia.modelo}`;
    this.idSeleccionado = sugerencia.id;
    console.log(this.idSeleccionado);
    this.sugerenciasVisibles = false;
  
    // Actualizar el valor del input directamente
    const inputElement = document.getElementById('autocompletado-input') as HTMLInputElement;
    if (inputElement) {
      inputElement.value = this.consulta;
    }
  
    // Actualizar el valor del idEquipo en el formulario
    this.form.patchValue({
      idEquipo: this.idSeleccionado ? this.idSeleccionado.toString() : null,
    });
  }
  
  

  alIngresar(event: any): void {
    this.consulta = event.target.value;
    this.filtrarSugerencias();
  }




  validateInputperiodo_garantia(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 2); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  


  getDataPrioridad(): void {
    const url = import.meta.env.NG_APP_API + '/prioridad-atencion';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetPrioridad = data.content;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }



  verImagen(url: string) {
    this.imagenSeleccionada = url;
    this.mostrarModal = true;
  }

  cerrarModal() {
    this.mostrarModal = false;
  }

  // Declarar el método onCheckboxChange
  onCheckboxChange(event: Event) {
    const checkbox = event.target as HTMLInputElement;
    this.fieldlocked = checkbox.checked;
  }


  datosFiltrados: any[] = [];

  onChange(event: any) {
    this.dni = event.target.value;
  }

  //PARA VALIDAR EL CELULAR
  validateInputNumero(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 9); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }




  mostrarMensajeError(mensaje: string) {
    Swal.fire({
      icon: 'error',
      title: 'Oops...',
      text: mensaje,
    });
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagen(link: string) {
    this.linkimagen = link;
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }
  limpiarformulario(e: any) {
    e.preventDefault();
    const formulario = document.getElementById('formulario') as HTMLFormElement;
    if (formulario) {
      // Selecciona todos los elementos del formulario excepto el campo 'numerocaso'
      const elementos = formulario.querySelectorAll('input:not(#numerocaso)');
      // Itera sobre los elementos seleccionados y establece su valor en vacío
      elementos.forEach((elemento: any) => {
        elemento.value = '';
      });
    }
    this.imagenes = [];
    this.dni = '';
    this.datosFiltrados = [];
    this.fieldlocked = true;
  }

  fechaActual: string = '';


  lastSelectedFiles : any

  onFileSelected(event: any) {
    const files = event.target.files;

    const input = event.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }
    if (files) {
      for (let i = 0; i < files.length; i++) {
        const file = files[i];
        const imageUrl = URL.createObjectURL(file); // Obtén la URL temporal
        const guardarFileyURL = { file: file, url: imageUrl };

        // Verificar si la imagen ya está en la lista
        const existingImage = this.imagenes.find(
          (img: any) => img.file.name === file.name
        );
        if (existingImage) {
          alert('¡Imagen repetida!');
        } else {
          // Calcular el total de imágenes
          const totalImages = this.imagenes.length + this.imagenesBackend.length;
          if (totalImages >= 5) {
            alert('¡Ya has alcanzado el límite de 5 imágenes!');
            const fileInput = document.getElementById('file_input') as HTMLInputElement;
            fileInput.value = '';
            break; // Salir del bucle si se alcanza el límite
          } else {
            this.imagenes.push(guardarFileyURL);
          }
        }
      }
    }
  }

  eliminarImagen(url: string) {
    const index = this.imagenes.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.imagenes.splice(index, 1);
    }
    if (this.imagenes.length === 0) {
      const fileInput = document.getElementById('file_input') as HTMLInputElement;
      fileInput.value = '';
    }
  }

  elmininarImagenTraida_del_Backend(dato: any) {

    const index = this.imagenesBackend.findIndex((item: any) => item.rutaFoto === dato);
    if (index !== -1) {
      this.imagenesBackend.splice(index, 1);
    }
  }


  idUsuarioAsignado : string = '';
  idSucursalUsuarioSoporte : string = '';

  changeAgarrar(e: any) {
    let valor = e.target.value;
    this.idUsuarioAsignado = valor;
  
    const url = import.meta.env.NG_APP_API + '/usuarios/full/' + this.idUsuarioAsignado;
  
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.idSucursalUsuarioSoporte = data.idSucursal;
        // Llama a patchValue aquí para asegurarte de que se actualice después de recibir la respuesta
        this.form.patchValue({
          idSucursal: this.idSucursalUsuarioSoporte
        });
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

// Propiedad para almacenar todos los usuarios
allUsuarios: any[] = []; 

getDataUsuarios(): void {
  const url = import.meta.env.NG_APP_API + '/usuarios';
  this.dataService.getApi(url).subscribe({
    next: (data) => {
      // Guardar todos los usuarios en allUsuarios
      this.allUsuarios = data;
      
      // Filtrar usuarios con perfil "SOPORTE" y guardar en arreglogetUsuarios
      this.arreglogetUsuarios = this.allUsuarios.filter((usuario: any) => usuario.perfil === 'SOPORTE');
      console.log(this.arreglogetUsuarios);
    },
    error: (error) => {
      console.log(error);
    },
  });
}

idSucursalElegido: number 

cambiarUsuarioAsignadoDependeSucursal(e: any): void {
  this.idSucursalElegido = Number(e.target.value); // Convertir a número

  // Filtrar los usuarios por la sucursal seleccionada y el perfil "SOPORTE"
  this.arreglogetUsuarios = this.allUsuarios.filter((usuario: any) =>
    Number(usuario.idSucursal) === this.idSucursalElegido && usuario.perfil === 'SOPORTE'
  );

  console.log(this.arreglogetUsuarios);
}

  
  
  



  enviarDatos() {
    this.loading = true;
    const formData = new FormData();
    const valoresFormulario = this.form.getRawValue();
  
    // Convertir todos los valores a string y agregarlos a formData
    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(key, value !== null && value !== undefined ? String(value) : '');
    }

    if (this.idSeleccionado !== null) {
      formData.append('idEquipo', this.idSeleccionado.toString());
    } else {
      // Aquí decides qué hacer si idSeleccionado es null, por ejemplo:
      formData.append('idEquipo', '0'); // O algún otro valor por defecto
    }
    
  
    // Agregar las imágenes seleccionadas por el usuario
    if (this.imagenes && this.imagenes.length > 0) {
      for (let i = 0; i < this.imagenes.length; i++) {
        if (this.imagenes[i] && this.imagenes[i].file) {
          formData.append('media[]', this.imagenes[i].file, this.imagenes[i].file.name);
        }
      }
    }
  
    // Agregar las imágenes del backend
    if (this.imagenesBackend && this.imagenesBackend.length > 0) {
      for (let i = 0; i < this.imagenesBackend.length; i++) {
        if (this.imagenesBackend[i] && this.imagenesBackend[i].rutaFoto) {
          formData.append('mediaUrls[]', this.imagenesBackend[i].rutaFoto);
        }
      }
    }
  
    const url = `${import.meta.env.NG_APP_API}/casos/${this.datos_etapa1.id}`;
  
    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          icon: 'success',
          title: '¡Registro actualizado!',
          text: 'Los datos se han actualizado correctamente.',
        }).then(() => {
          window.location.reload();
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
  
  
  



}