import { ChangeDetectorRef, Component, Input, OnInit } from '@angular/core';
import { ServiceService } from '../../core/service/service.service';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import Swal from 'sweetalert2';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-etapa4-editar',
  standalone: true,
  imports: [ReactiveFormsModule,CommonModule],
  templateUrl: './etapa4-editar.component.html',
  styleUrl: './etapa4-editar.component.css'
})
export class Etapa4EditarComponent implements OnInit {

  @Input() datos: any = {};

  loading: boolean = false;
  datos_casos: any;
  imagenes: any[] = [];
  imagenesBackend: any[] = [];

  datos_diagnostico: any;
  mostrarModal: boolean = false;
  fieldlocked: boolean = true;
  imagenSeleccionada: string = '';

  arreglogetCliente: any[] = [];
  arreglogetUsuarios: any[] = [];
  arreglogetPrioridad: any[] = [];

  arreglogetEquipos: any[] = [];
  arreglogetDistribuidor: any[] = [];

  equiposFiltrados: any[] = [];

  dni: string = '';
  urlMedia = import.meta.env.NG_APP_API + '/media/';
  seguimientoetapa4: any[] = [];
  id_etapa: any;

  valorTiempoEspera: any;



  datos_desarrollo: any;
  datos_recibidos: any;

  id_desarrollo: any;

  descripcion_repuesto: any;
  observaciones: any;

  id_seguimiento: any;

  formularioDesarrollo = new FormGroup({
    seguimientoId: new FormControl(0),
    descripcion: new FormControl(""),
    descripcion_repuesto: new FormControl(""),
    observaciones: new FormControl(""),
  });

  formularioSeguimiento = new FormGroup({
    idCaso: new FormControl(0),
    descripcion: new FormControl(""),
    observacion: new FormControl(""),
    repuestos: new FormControl(""),
    llegadaDiasRepuesto: new FormControl(0),
    conformidadDeServicio: new FormControl(""),
    calificacion: new FormControl(""),
    nroCasoMarca: new FormControl(""),
    fechaInicio: new FormControl(""),
    fechaFin: new FormControl(""),
    horaInicio: new FormControl(""),
    horaFin: new FormControl(""),
    estadoSeguimiento: new FormControl(""),
    idEtapa: new FormControl(0)  // Change this to FormControl
  });

  constructor(private dataService: ServiceService, private cdr: ChangeDetectorRef) { }
  ngOnInit(): void {
    this.datos_recibidos = this.datos;
    console.log('Datos Recibidos:', this.datos_recibidos);
    this.datos_desarrollo = this.datos_recibidos.desarrollo;

    this.seguimientoetapa4 = this.datos.seguimientos.filter(
      (item: any) => item.etapa.id === 4
    );

    console.log('Datos Recibidos:', this.seguimientoetapa4);

    this.id_etapa = this.seguimientoetapa4[0].etapa.id;
    console.log('ID Etapa:', this.id_etapa);

    this.id_desarrollo = this.datos_desarrollo.id;

    this.descripcion_repuesto = this.seguimientoetapa4[0].descripcion;
    console.log('Descripción Repuesto:', this.descripcion_repuesto);

    this.observaciones = this.seguimientoetapa4[0].observacion;
    this.id_seguimiento = this.seguimientoetapa4[0].id_seguimiento;

    console.log('Observaciones:', this.observaciones);

    this.formularioDesarrollo.patchValue({
      seguimientoId: this.seguimientoetapa4[0].idSeguimiento || 0,
      descripcion: this.datos_desarrollo.descripcion,
      descripcion_repuesto: this.seguimientoetapa4[0].descripcion,
      observaciones: this.seguimientoetapa4[0].observacion
    });

    this.formularioSeguimiento.patchValue({
      idCaso: this.datos_recibidos.caso.id || 0,
      idEtapa: this.id_etapa,
      descripcion: this.seguimientoetapa4[0]?.descripcion || '',
      observacion: this.seguimientoetapa4[0]?.observacion || '',
      repuestos: this.seguimientoetapa4[0]?.repuestos || '',
      llegadaDiasRepuesto: this.seguimientoetapa4[0]?.llegadaDiasRepuesto || 0,
      conformidadDeServicio: this.seguimientoetapa4[0]?.conformidadDeServicio || '',
      calificacion: this.seguimientoetapa4[0]?.calificacion || "",
      nroCasoMarca: this.seguimientoetapa4[0]?.nroCasoMarca || '',
      fechaInicio: this.seguimientoetapa4[0]?.fechaInicio || '',
      fechaFin: this.seguimientoetapa4[0]?.fechaFin || '',
      horaInicio: this.seguimientoetapa4[0]?.horaInicio || '',
      horaFin: this.seguimientoetapa4[0]?.horaFin || '',
      estadoSeguimiento: this.seguimientoetapa4[0]?.estadoSeguimiento || '',
    });

    this.cdr.detectChanges();
  }

 

  changeRepuestos(event: Event): void {
    const selectElement = event.target as HTMLSelectElement;
    this.descripcion_repuesto = selectElement.value;
    this.formularioSeguimiento.patchValue({
      descripcion: this.descripcion_repuesto
    });
    console.log('Descripción Repuesto Cambiada:', this.descripcion_repuesto);
  }

  changeDescripcion(e: any): void {
    const value = e.target.value;
    this.formularioSeguimiento.patchValue({
      observacion: value
    });
    console.log('Observaciones Cambiadas:', value);
  }

  actualizar(e:any): void {
    e.preventDefault();
    this.loading = true;
    const formData = new FormData();
    const valoresFormulario = this.formularioDesarrollo.getRawValue();

    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(key, value !== null && value !== undefined ? String(value) : '');
    }

    const url = `${import.meta.env.NG_APP_API}/desarrollo/${this.id_desarrollo}`;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.loading = false;
        this.actualizarSeguimiento();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  actualizarSeguimiento(): void {
    this.loading = true;
    const formData = new FormData();
    const valoresFormulario = this.formularioSeguimiento.getRawValue();

    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(key, value !== null && value !== undefined ? String(value) : '');
    }

    const url = `${import.meta.env.NG_APP_API}/seguimiento/${this.seguimientoetapa4[0]?.idSeguimiento}`;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          icon: 'success',
          title: '¡Registro actualizado!',
          text: 'Los datos se han actualizado correctamente.',
        }).then(() => {
          window.location.reload();
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

}
