import { ChangeDetectorRef, Component, Input } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { ServiceService } from '../../core/service/service.service';
import Swal from 'sweetalert2';
import { initFlowbite } from 'flowbite';

@Component({
  selector: 'app-etapa5-editar',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './etapa5-editar.component.html',
  styleUrl: './etapa5-editar.component.css',
})
export class Etapa5EditarComponent {
  @Input() datos: any = {};

  constructor(
    private dataService: ServiceService,
    private cdr: ChangeDetectorRef
  ) {}
  loading: boolean = false;
  datos_casos: any;
  imagenes: any = [];
  imagenesBackend: any = [];

  datos_diagnostico: any;
  mostrarModal: boolean = false;
  fieldlocked: boolean = true;
  imagenSeleccionada: string = '';

  arreglogetCliente: any[] = [];
  arreglogetUsuarios: any[] = [];
  arreglogetPrioridad: any[] = [];

  arreglogetEquipos: any[] = [];
  arreglogetDistribuidor: any[] = [];

  equiposFiltrados: any[] = [];

  dni: string = '';
  urlMedia = import.meta.env.NG_APP_API + '/media/';
  seguimientoetapa5: any[] = [];
  id_etapa: any;

  valorTiempoEspera: any;

  formularioPrueba = new FormGroup({
    seguimientoId: new FormControl(0),
    descripcion: new FormControl(''),
    observaciones: new FormControl(''),
  });

  datos_prueba: any;
  datos_recibidos: any;

  id_prueba: any;

  formularioCasos = new FormGroup({
    numeroCaso: new FormControl(''),
    dni: new FormControl(''),
    nombreCliente: new FormControl(''),
    direccionCliente: new FormControl(''),
    celularCliente: new FormControl(''),
    tipoServicio: new FormControl(''),
    ordenServicio: new FormControl(''),
    idUsuarioAsignado: new FormControl(''),
    idDistribuidor: new FormControl(''),
    idEquipo: new FormControl(''),
    idCliente: new FormControl(''),
    numeroSerie: new FormControl(''),
    idPrioridadAtencion: new FormControl(''),
    descripcion: new FormControl(''),
    aceptoTerminos: new FormControl(''),
    garantia: new FormControl(''),
    proximoMantenimiento: new FormControl(''),
    sede: new FormControl(''),
    periodoGarantiaMeses: new FormControl(''),
    observaciones: new FormControl(''),
    estadoCaso: new FormControl(''),
    fechaRegistro: new FormControl(''),
    etapa: new FormControl(''),
    areaPerteneciente : new FormControl(''),
    usuarioRegistro : new FormControl(''),
  });

  fechaRecolectada: any;

  recogerFecha(e: any) {
    console.log(e.target.value);

    const fechaActual = e.target.value;

    this.formularioCasos.patchValue({ proximoMantenimiento: fechaActual });
  }

  ngOnInit(): void {
    initFlowbite();
    this.getDataUsuarios();
    this.getDataPrioridad();
    this.getDistribuidor().then(() => {
      this.getDataEquipos();
    });

    this.datos_casos = this.datos.caso;

    this.fechaRecolectada = this.datos_casos.proximoMantenimiento;

    this.datos_recibidos = this.datos;

    this.datos_prueba = this.datos_recibidos.pruebaCalidad;

    console.log(this.datos_prueba);

    this.seguimientoetapa5 = this.datos.seguimientos.filter(
      (item: any) => item.etapa.id === 5
    );

    this.id_prueba = this.datos_prueba.id;

    this.formularioPrueba.patchValue({
      seguimientoId: this.seguimientoetapa5[0].idSeguimiento || 0,
      descripcion: this.datos_prueba.descripcion,
      observaciones: this.datos_prueba.observaciones,
    });

    console.log(this.datos_casos);

    if (this.datos_casos) {
      this.formularioCasos.patchValue({
        numeroCaso: this.datos_casos.numeroCaso,
        dni: this.datos_casos.cliente.numeroDocumento,
        nombreCliente:
          this.datos_casos.cliente.nombre +
          ' ' +
          this.datos_casos.cliente.apellido,
        direccionCliente: this.datos_casos.cliente.direccionLegal,
        celularCliente: this.datos_casos.cliente.telefonosContacto,
        tipoServicio: this.datos_casos.tipoServicio,
        ordenServicio: this.datos_casos.ordenServicio,
        idUsuarioAsignado: this.datos_casos.usuarioAsignado.id,
        idCliente: this.datos_casos.cliente.id,
        idDistribuidor: this.datos_casos.equipo.distribudor.id,
        idEquipo: this.datos_casos.equipo.id,
        numeroSerie: this.datos_casos.numeroSerie,
        idPrioridadAtencion: this.datos_casos.idPrioridad,
        descripcion: this.datos_casos.descripcion,
        aceptoTerminos: this.datos_casos.aceptoTerminos,
        garantia: this.datos_casos.garantia,
        proximoMantenimiento: this.datos_casos.proximoMantenimiento,
        sede: this.datos_casos.sede,
        periodoGarantiaMeses: this.datos_casos.periodoGarantiaMeses,
        observaciones: this.datos_casos.observaciones,
        estadoCaso: this.datos_casos.estadoCaso,
        fechaRegistro: this.datos_casos.fechaRegistro,
        areaPerteneciente: this.datos_casos?.areaPerteneciente ?? '',
        usuarioRegistro: this.datos_casos?.usuarioRegistro ?? '',
        etapa: this.datos_casos.etapa,
      });
    }
  }

  actualizarDatos() {
    this.loading = true;
    const formData = new FormData();
    const valoresFormulario = this.formularioPrueba.getRawValue();

    // Convertir todos los valores a string y agregarlos a formData
    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(
        key,
        value !== null && value !== undefined ? String(value) : ''
      );
    }

    const url = `${import.meta.env.NG_APP_API}/prueba-calidad/${
      this.id_prueba
    }`;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.actualizarCasos();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  actualizarCasos() {
    this.loading = true;
    const formData = new FormData();
    const valoresFormulario = this.formularioCasos.getRawValue();

    const sucursal = this.datos_casos?.sucursal?.id;

    if (sucursal) {
      formData.append('idSucursal', sucursal);
    } else {
      Swal.fire({
        icon: 'warning',
        title: 'Campo requerido',
        text: 'La sucursal es importante y debe ser seleccionada.',
        confirmButtonText: 'Aceptar',
      });
    }

    // Convertir todos los valores a string y agregarlos a formData
    for (const [key, value] of Object.entries(valoresFormulario)) {
      formData.append(
        key,
        value !== null && value !== undefined ? String(value) : ''
      );
    }

    const url = `${import.meta.env.NG_APP_API}/casos/${this.datos_casos.id}`;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.loading = false;
        Swal.fire({
          icon: 'success',
          title: '¡Registro actualizado!',
          text: 'Los datos se han actualizado correctamente.',
        }).then(() => {
          window.location.reload();
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  getDataEquipos(): void {
    const url = import.meta.env.NG_APP_API + '/equipos';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetEquipos = data.content;
        if (this.datos_casos) {
          this.onDistribuidorClick({
            target: { value: this.datos_casos.equipo.distribudor.id },
          });
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  getDistribuidor(): Promise<void> {
    return new Promise((resolve, reject) => {
      const url = import.meta.env.NG_APP_API + '/distribuidor';
      this.dataService.getApi(url).subscribe({
        next: (data) => {
          this.arreglogetDistribuidor = data.content;
          resolve();
        },
        error: (error) => {
          console.log(error);
          reject(error);
        },
      });
    });
  }

  validateInputperiodo_garantia(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 2); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  onDistribuidorClick(e: any) {
    const distribuidor = e.target.value;
    // Filtrar los equipos relacionados al distribuidor seleccionado
    this.equiposFiltrados = this.arreglogetEquipos.filter(
      (equipo) => equipo.distribudor.id === Number(distribuidor)
    );
  }

  getDataPrioridad(): void {
    const url = import.meta.env.NG_APP_API + '/prioridad-atencion';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetPrioridad = data.content;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  getDataUsuarios(): void {
    const url = import.meta.env.NG_APP_API + '/usuarios';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arreglogetUsuarios = data;
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  verImagen(url: string) {
    this.imagenSeleccionada = url;
    this.mostrarModal = true;
  }

  cerrarModal() {
    this.mostrarModal = false;
  }

  // Declarar el método onCheckboxChange
  onCheckboxChange(event: Event) {
    const checkbox = event.target as HTMLInputElement;
    this.fieldlocked = checkbox.checked;
  }

  datosFiltrados: any[] = [];

  onChange(event: any) {
    this.dni = event.target.value;
  }

  //PARA VALIDAR EL CELULAR
  validateInputNumero(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 9); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  buscar(event: any) {
    event.preventDefault();
    this.dni = event.target.value;
    const valor = event.target.value;

    // Verificar la longitud del valor ingresado
    if (valor.length === 8 || valor.length === 11) {
      const datosFiltrados = this.arreglogetCliente.filter((cliente: any) => {
        return cliente.numeroDocumento.includes(valor);
      });

      if (datosFiltrados.length === 0) {
        this.datosFiltrados = [];
        this.mostrarMensajeError('No se encontró el cliente');
      } else {
        this.datosFiltrados = datosFiltrados;
      }
    } else {
      this.datosFiltrados = [];
      this.mostrarMensajeError(
        'El número de documento debe tener 8 o 11 dígitos.'
      );
    }
  }

  clickbuscar() {
    const url = import.meta.env.NG_APP_API + '/clientes';
    const valor = this.dni;

    this.dataService.getApi(url).subscribe({
      next: (data) => {
        // Asignar los datos recibidos a arreglogetCliente
        this.arreglogetCliente = data;

        // Verificar la longitud del valor ingresado
        if (valor.length === 8 || valor.length === 11) {
          const datosFiltrados = this.arreglogetCliente.filter(
            (cliente: any) => {
              this.fieldlocked = false;
              return cliente.numeroDocumento.includes(valor);
            }
          );

          if (datosFiltrados.length === 0) {
            this.datosFiltrados = [];
            this.mostrarMensajeError('No se encontró el cliente');
          } else {
            this.datosFiltrados = datosFiltrados;
          }
        } else {
          this.datosFiltrados = [];
          this.mostrarMensajeError(
            'El número de documento debe tener 8 o 11 dígitos.'
          );
        }
      },
      error: (error) => {
        console.log(error);
      },
    });
  }

  mostrarMensajeError(mensaje: string) {
    Swal.fire({
      icon: 'error',
      title: 'Oops...',
      text: mensaje,
    });
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagen(link: string) {
    this.linkimagen = link;
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }
  limpiarformulario(e: any) {
    e.preventDefault();
    const formulario = document.getElementById('formulario') as HTMLFormElement;
    if (formulario) {
      // Selecciona todos los elementos del formulario excepto el campo 'numerocaso'
      const elementos = formulario.querySelectorAll('input:not(#numerocaso)');
      // Itera sobre los elementos seleccionados y establece su valor en vacío
      elementos.forEach((elemento: any) => {
        elemento.value = '';
      });
    }
    this.imagenes = [];
    this.dni = '';
    this.datosFiltrados = [];
    this.fieldlocked = true;
  }

  fechaActual: string = '';

  onFileSelected(event: any) {
    const files = event.target.files;
    if (files) {
      for (let i = 0; i < files.length; i++) {
        const file = files[i];
        const imageUrl = URL.createObjectURL(file); // Obtén la URL temporal
        const guardarFileyURL = { file: file, url: imageUrl };

        // Verificar si la imagen ya está en la lista
        const existingImage = this.imagenes.find(
          (img: any) => img.file.name === file.name
        );
        if (existingImage) {
          alert('¡Imagen repetida!');
        } else {
          // Calcular el total de imágenes
          const totalImages =
            this.imagenes.length + this.imagenesBackend.length;
          if (totalImages >= 5) {
            alert('¡Ya has alcanzado el límite de 5 imágenes!');
            const fileInput = document.getElementById(
              'file_input'
            ) as HTMLInputElement;
            fileInput.value = '';
            break; // Salir del bucle si se alcanza el límite
          } else {
            this.imagenes.push(guardarFileyURL);
          }
        }
      }
    }
  }

  eliminarImagen(url: string) {
    const index = this.imagenes.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.imagenes.splice(index, 1);
    }
    if (this.imagenes.length === 0) {
      const fileInput = document.getElementById(
        'file_input'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  elmininarImagenTraida_del_Backend(dato: any) {
    const index = this.imagenesBackend.findIndex(
      (item: any) => item.rutaFoto === dato
    );
    if (index !== -1) {
      this.imagenesBackend.splice(index, 1);
    }
  }
}
