import { Component, Input } from '@angular/core';
import { ServiceService } from '../../../core/service/service.service';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-pedirplantilla',
  standalone: true,
  imports: [],
  templateUrl: './pedirplantilla.component.html',
  styleUrl: './pedirplantilla.component.css'
})
export class PedirplantillaComponent {

  @Input() datos: any = {}; // Cambiado de any[] a any

  idCaso: number = 0;
  horaFin: string = '';
  fechaFIn: string = '';
  loading: boolean = false;

  fechaenvio: string = '';
  horaenvio: string = '';
  casosActualizar: any;

  constructor(private dataService: ServiceService) {}
  ngOnInit(): void {
    initFlowbite();
    if (this.datos && this.datos.caso) {
      this.casosActualizar = this.datos.caso;
      console.log(this.datos);

      const idcaso = this.datos.caso.id;
      this.idCaso = idcaso;
      this.horaFin = this.datos.seguimientos[0].horaFin;
      this.fechaFIn = this.datos.seguimientos[0].fechaFin;
    }
  }


  archivosPdf: any[] = [];

  lastSelectedFiles: any 

  changePdf(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      if (dataPdf) {
        alert('PDF repetido!');
      } else if (this.archivosPdf.length === 1) {
        alert('Solo se Admite un pdf');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf.push(guardarFileyURL);
      }
    }
  }

  removePdf(url: string) {
    const index = this.archivosPdf.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf.splice(index, 1);
    }

    if (this.archivosPdf.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  descripcion: string = '';

  changeDescripcion(e: any) {

    this.descripcion = e.target.value;
    console.log(this.descripcion);

  }

  clickAbrirEtapa(e: any) {
    e.preventDefault();
        this.loading = true;
        if(this.loading){
          Swal.fire({
            title: 'Solicitando ',
            html: `
              <style>
                .spinner {
                  border: 4px solid rgba(0, 0, 0, 0.1);
                  width: 36px;
                  height: 36px;
                  border-radius: 50%;
                  border-left-color: #09f;
                  animation: spin 1s linear infinite;
                  display: inline-block;
                  margin-top: 10px;
                }
          
                @keyframes spin {
                  0% {
                    transform: rotate(0deg);
                  }
                  100% {
                    transform: rotate(360deg);
                  }
                }
              </style>
              <div>Se está guardando la información, por favor esperar...</div>
              <div class="spinner"></div>
            `,
            icon: 'info',
            allowOutsideClick: false,
            allowEscapeKey: false,
            showConfirmButton: false,
            showCancelButton: false,
            showCloseButton: false,
            timerProgressBar: true,
          });
          
        }
        const fecha = new Date();
        const dia = fecha.getUTCDate();
        const mes = fecha.getUTCMonth() + 1; // Los meses comienzan desde 0
        const anio = fecha.getUTCFullYear();

        

        // Formatear la fecha
        const fechaFormateada = `${anio}-${mes < 10 ? '0' + mes : mes}-${dia < 10 ? '0' + dia : dia}`;

        // Obtener la hora en formato de 24 horas
        const hora = fecha.getUTCHours();
        const minuto = fecha.getUTCMinutes();
        const segundo = fecha.getUTCSeconds();
        const milisegundo = fecha.getUTCMilliseconds();

        // Formatear la hora
        const horaFormateada = `${hora < 10 ? '0' + hora : hora}:${minuto < 10 ? '0' + minuto : minuto}:${segundo < 10 ? '0' + segundo : segundo}.${milisegundo}`;

        // Asignar los valores de fecha y hora obtenidos al objeto
        this.fechaenvio = fechaFormateada;
        this.horaenvio = horaFormateada;

        // Enviar los datos al servidor una vez que se hayan obtenido fecha y hora
        this.enviarDatosAlServidor()
  }

  actualizar() {
    const formData = new FormData();
    formData.append('idCliente', this.casosActualizar.cliente.id);
    formData.append('tipoServicio', this.casosActualizar.tipoServicio);
    formData.append('descripcion', this.casosActualizar.descripcion);
    formData.append('observaciones', this.casosActualizar.observaciones);
    formData.append('numeroCaso', this.casosActualizar.numeroCaso);
    formData.append('numSerie', this.casosActualizar.numeroSerie);
    formData.append('calificacion', "");
    formData.append('etapa', 'Responder Plantilla - BROTHER');
    formData.append('estadoCaso', 'Pendiente');
    formData.append('aceptoTerminos', 'True');
    formData.append('ordenServicio', this.casosActualizar.ordenServicio);
    formData.append('idEquipo', this.casosActualizar.equipo.id);
    formData.append('idUsuarioAsignado', this.casosActualizar.usuarioAsignado.id);
    formData.append('proximoMantenimiento', "");
    formData.append('idPrioridadAtencion', this.casosActualizar.idPrioridad);
    formData.append('garantia', this.casosActualizar.garantia);
    formData.append('idSucursal', this.casosActualizar.sucursal.id);
    formData.append('periodoGarantiaMeses', this.casosActualizar.periodoGarantiaMeses);
    formData.append('areaPerteneciente', this.casosActualizar.areaPerteneciente || '');
    formData.append('usuarioRegistro', this.casosActualizar.usuarioRegistro || '');



    const url = import.meta.env.NG_APP_API + '/casos/' + this.idCaso;
    this.dataService.putApi(url, formData).subscribe({
      next: (response) => {
        Swal.fire({
          title: '¡Éxito!',
          text: 'Se registro exitosamente.',
          icon: 'success',
          confirmButtonText: 'Aceptar',
          allowOutsideClick: false,
          allowEscapeKey: false,
          timerProgressBar: true,
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        })
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  enviarDatosAlServidor() {
    const formData = new FormData();
    formData.append('idCaso', String(this.idCaso));
    formData.append('idEtapa', '7');
    formData.append('nroCasoMarca', 'EL NUMERO DE CASO DEBER ESTAR REGISTRADO EN LA ETAPA 2');
    formData.append('descripcion', this.descripcion);
    formData.append('observacion', 'EN ESTA ETAPA SE REALIZA EL DIAGNOSTICO DEL EQUIPO CON TODAS LAS PRUEBAS CORRESPONDIENTES');
    formData.append('repuestos', 'NO HAY REGISTRO TODAVIA DE ESTO');
    formData.append('conformidadDeServicio', 'NO HAY REGISTRO TODAVIA DE ESTO');
    formData.append('fechaInicio', this.fechaFIn);
    formData.append('fechaFin', this.fechaenvio);
    formData.append('horaInicio', this.horaFin);
    formData.append('horaFin', this.horaenvio);
    formData.append('estadoSeguimiento', 'Pendiente');
    if (this.archivosPdf.length === 0) {
      console.log('No hay archivos PDF para enviar.');
    } else {
      for (let i = 0; i < this.archivosPdf.length; i++) {
        formData.append('pdf[]', this.archivosPdf[i].file, this.archivosPdf[i].file.name);
      }
    }

    const url = import.meta.env.NG_APP_API + '/seguimiento';

    this.dataService.postApi(url, formData).subscribe(
      {
        next: (data) => {
          this.actualizar()
        },
        error: (error) => {
          this.loading = false;
          let errorMessage = 'Algo salió mal';
          if (error.error && error.error.message) {
            errorMessage = error.error.message;
          }
  
          Swal.fire({
            title: 'Error',
            text: errorMessage,
            icon: 'error',
            confirmButtonText: 'OK',
          });
        },
      }
    )
    
  }


}
