import { Component, Input } from '@angular/core';
import { ServiceService } from '../../../core/service/service.service';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-respuestacasnumerodecaso',
  standalone: true,
  imports: [],
  templateUrl: './respuestacasnumerodecaso.component.html',
  styleUrl: './respuestacasnumerodecaso.component.css'
})
export class RespuestacasnumerodecasoComponent {
  @Input() datos: any = {}; // Cambiado de any[] a any

  idCaso: number = 0;
  horaFin: string = '';
  fechaFIn: string = '';
  loading: boolean = false;
  urlsPds = import.meta.env.NG_APP_API + '/download-pdf/'
  fechaenvio: string = '';
  horaenvio: string = '';
  casosActualizar: any;
  seguimientoetapa2 : any = [];
  archivopdf : any
  constructor(private dataService: ServiceService) {}
  ngOnInit(): void {
    initFlowbite();
    if (this.datos && this.datos.caso) {
      this.casosActualizar = this.datos.caso;

      const idcaso = this.datos.caso.id;
      this.idCaso = idcaso;
      this.horaFin = this.datos.seguimientos[0].horaFin;
      this.fechaFIn = this.datos.seguimientos[0].fechaFin;

      this.seguimientoetapa2 = this.datos.seguimientos.filter(
        (item: any) => item.etapa.id === 2
      );

      this.archivopdf = this.seguimientoetapa2[0].rutasPdf[0].rutaDocumento
    }
  }

  numerodecaso: string = '';

  agarrarNumeroCaso(event: any) {
    this.numerodecaso = event.target.value;
  }

  enviarDatos(e: any) {
    
    e.preventDefault();
    this.loading = true;
    if (this.loading) {
        Swal.fire({
          title: 'Guardando...',
          html: `
            <style>
              .spinner {
                border: 4px solid rgba(0, 0, 0, 0.1);
                width: 36px;
                height: 36px;
                border-radius: 50%;
                border-left-color: #09f;
                animation: spin 1s linear infinite;
                display: inline-block;
                margin-top: 10px;
              }
        
              @keyframes spin {
                0% {
                  transform: rotate(0deg);
                }
                100% {
                  transform: rotate(360deg);
                }
              }
            </style>
            <div>Se está guardando la información, por favor esperar...</div>
            <div class="spinner"></div>
          `,
          icon: 'info',
          allowOutsideClick: false,
          allowEscapeKey: false,
          showConfirmButton: false,
          showCancelButton: false,
          showCloseButton: false,
          timerProgressBar: true,
        });
    }
    const fecha = new Date();
    const dia = fecha.getUTCDate();
    const mes = fecha.getUTCMonth() + 1; // Los meses comienzan desde 0
    const anio = fecha.getUTCFullYear();

    // Formatear la fecha
    const fechaFormateada = `${anio}-${mes < 10 ? '0' + mes : mes}-${
      dia < 10 ? '0' + dia : dia
    }`;

    // Obtener la hora en formato de 24 horas
    const hora = fecha.getUTCHours();
    const minuto = fecha.getUTCMinutes();
    const segundo = fecha.getUTCSeconds();
    const milisegundo = fecha.getUTCMilliseconds();

    // Formatear la hora
    const horaFormateada = `${hora < 10 ? '0' + hora : hora}:${
      minuto < 10 ? '0' + minuto : minuto
    }:${segundo < 10 ? '0' + segundo : segundo}.${milisegundo}`;

    // Asignar los valores de fecha y hora obtenidos al objeto
    this.fechaenvio = fechaFormateada;
    this.horaenvio = horaFormateada;

    this.actualizarSeguimiento()

  }

  actualizarCasos() {
    const formData = new FormData();
    formData.append('idCliente', this.casosActualizar.cliente.id);
    formData.append('tipoServicio', this.casosActualizar.tipoServicio);
    formData.append('descripcion', this.casosActualizar.descripcion);
    formData.append('observaciones', this.casosActualizar.observaciones);
    formData.append('numeroCaso', this.casosActualizar.numeroCaso);
    formData.append('numSerie', this.casosActualizar.numeroSerie);
    formData.append('calificacion', "");
    formData.append('etapa', '2');
    formData.append('estadoCaso', 'Completado');
    formData.append('aceptoTerminos', 'True');
    formData.append('ordenServicio', this.casosActualizar.ordenServicio);
    formData.append('idEquipo', this.casosActualizar.equipo.id);
    formData.append('idUsuarioAsignado', this.casosActualizar.usuarioAsignado.id);
    formData.append('proximoMantenimiento', "");
    formData.append('idPrioridadAtencion', this.casosActualizar.idPrioridad);
    formData.append('garantia', this.casosActualizar.garantia);
    formData.append('idSucursal', this.casosActualizar.sucursal.id);
    formData.append('periodoGarantiaMeses', this.casosActualizar.periodoGarantiaMeses);
    formData.append('areaPerteneciente', this.casosActualizar.areaPerteneciente || '');
    formData.append('usuarioRegistro', this.casosActualizar.usuarioRegistro || '');



    const url = import.meta.env.NG_APP_API + '/casos/' + this.idCaso;
    this.dataService.putApi(url, formData).subscribe({
      next: (response) => {
        Swal.fire({
          title: '¡Éxito!',
          text: 'Se ha registrado correctamente',
          icon: 'success',
          confirmButtonText: 'Aceptar',
          allowOutsideClick: false,
          allowEscapeKey: false,
          timerProgressBar: true,
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  actualizarSeguimiento() {
    const formData = new FormData();
    formData.append('idCaso', String(this.idCaso));
    formData.append('idEtapa', '2');
    formData.append('nroCasoMarca', this.numerodecaso);
    formData.append(
      'descripcion',
      'EL CAS ENVIO CORRECTAMENTE EL NUMERO DE CASO DEL CLIENTE'
    );
    formData.append(
      'observacion',
      'EL NUMERO DE CASO DE LA MARCA FUE RECIBIDO CORRECTAMENTE'
    );
    formData.append('repuestos', 'NO HAY REGISTRO TODAVIA DE ESTO');
    formData.append('conformidadDeServicio', 'NO HAY REGISTRO TODAVIA DE ESTO');
    formData.append('fechaInicio', this.fechaFIn);
    formData.append('fechaFin', this.fechaenvio);
    formData.append('horaInicio', this.horaFin);
    formData.append('horaFin', this.horaenvio);
    formData.append('estadoSeguimiento', 'Completado');

    const url =
    import.meta.env.NG_APP_API +
    '/seguimiento/' +
    this.seguimientoetapa2[0].idSeguimiento;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        this.actualizarCasos();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

}
