import { Component, Input } from '@angular/core';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../core/service/service.service';
import { Postfallas2Component } from './postfallas2/postfallas2.component';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-diagnostico',
  standalone: true,
  imports: [Postfallas2Component, CommonModule],
  templateUrl: './diagnostico.component.html',
  styleUrl: './diagnostico.component.css',
})
export class DiagnosticoComponent {
  constructor(private dataService: ServiceService) {}

  @Input() datos: any = {}; // Cambiado de any[] a any
  seguimientoetapa3: any[] = [];
  idCaso: number = 0;
  casosActualizar: any;
  horaFin: any;
  fechaFIn: any;

  estadoGarantia: any;

  ngOnInit(): void {
    this.getMantenimiento();
    this.getFallas();
    if (this.datos && this.datos.caso) {
      this.casosActualizar = this.datos.caso;
      this.estadoGarantia = this.casosActualizar.garantia;
      this.idCaso = this.datos.caso.id;
      this.seguimientoetapa3 = this.datos.seguimientos.filter(
        (item: any) => item.etapa.id === 3
      );
      this.horaFin = this.datos.seguimientos[0].horaFin;
      this.fechaFIn = this.datos.seguimientos[0].fechaFin;
    }
  }

  recibirLaRepuestaDelPostHiJOParaActualizar(event: boolean) {
    if (event) {
      this.getFallas(); // Actualizar la tabla después de la solicitud POST
    }
  }


  estadoModal: boolean = false;

  closemodal(estado: boolean) {
    this.estadoModal = estado;
  }

  arregloMantenimiento: any = [];
  getMantenimiento() {
    const url = import.meta.env.NG_APP_API + '/tipoMantenimiento';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        this.arregloMantenimiento = data;
      },
      error: (error) => {
        console.error('There was an error!', error);
      },
    });
  }

  consulta: string = '';
  sugerencias: any[] = [];
  sugerenciasFiltradas: any[] = [];
  sugerenciasVisibles: boolean = false;
  idSeleccionado: number | null = null;
  
  arregloFallas: any = [];
  getFallas() {
    const url = import.meta.env.NG_APP_API + '/fallas/all';
    this.dataService.getApi(url).subscribe({
      next: (data) => {
        console.log(data);
        this.arregloFallas = data;
        this.filtrarSugerencias();
      },
      error: (error) => {
        console.error('There was an error!', error);
      },
    });
  }
  
  mostrarSugerencias(): void {
    this.sugerenciasVisibles = true;
    this.filtrarSugerencias();
  }
  
  ocultarSugerencias(): void {
    setTimeout(() => this.sugerenciasVisibles = false, 200);
  }
  
  filtrarSugerencias(): void {
    this.sugerenciasFiltradas = this.arregloFallas
      .filter((sugerencia: any) => 
        sugerencia.codigoFalla.toLowerCase().includes(this.consulta.toLowerCase()) || 
        sugerencia.descripcion.toLowerCase().includes(this.consulta.toLowerCase())
      )

      console.log(this.sugerenciasFiltradas);
  }
  
  seleccionarSugerencia(sugerencia: any): void {
    this.consulta = ''; // Limpiar el campo de entrada
    this.idSeleccionado = sugerencia.id;
    this.agregarSeleccion(sugerencia); // Agregar la selección directamente
    this.mostrarSugerencias(); // Mantener visible la lista de sugerencias
    console.log(`ID seleccionado: ${this.idSeleccionado}`);
  }
  
  alIngresar(event: any): void {
    this.consulta = event.target.value;
    this.filtrarSugerencias();
  }
  
  arregloSelecciones: { id: number; nombre: string; descripcion: string }[] = [];
  arregloPuroId: any[] = [];
  
  agregarSeleccion(sugerencia: any) {
    const idSeleccionado = sugerencia.id;
    const seleccionExistente = this.arregloSelecciones.find(
      (seleccion) => seleccion.id === idSeleccionado
    );
    if (seleccionExistente) {
      alert('Esta falla ya ha sido seleccionada.');
      const selectElement = document.getElementById('autocompletado-input') as any;
      selectElement.value = '';
      return; // No agregamos la selección si ya existe
    }
    const selectElement = document.getElementById('autocompletado-input') as any;
    selectElement.value = '';
    this.arregloPuroId.push(idSeleccionado.toString());
    console.log(this.arregloPuroId);
    this.arregloSelecciones.push({
      id: sugerencia.id,
      nombre: sugerencia.codigoFalla,
      descripcion: sugerencia.descripcion,
    });
    

  }
  
  eliminarSeleccion(id: number): void {
    const indice = this.arregloPuroId.findIndex(
      (idSeleccion) => idSeleccion === id.toString()
    );
    const indice2 = this.arregloSelecciones.findIndex(
      (seleccion) => seleccion.id === id
    );
    if (indice !== -1) {
      // Verifica que se encontró el elemento
      this.arregloPuroId.splice(indice, 1); // Elimina 1 elemento a partir del índice encontrado
      this.arregloSelecciones.splice(indice2, 1);
    }
  }
  

  imagenes: any = [];
  mostrarModal: boolean = false;
  imagenSeleccionada: string = '';

  lastSelectedFiles2 : any

  onFileSelected(event: any) {
    const files = event.target.files;

    const input = event.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles2 = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles2) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles2.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles2[i]);
        }
        input.files = dataTransfer.files;
      }
    }
    if (files) {
      for (let i = 0; i < files.length; i++) {
        const file = files[i];

        // Verificar si el archivo no supera los 10 MB
        const fileSizeInMB = file.size / (1024 * 1024);
        if (fileSizeInMB > 15) {
          alert('¡El tamaño de la imagen no debe superar los 15 MB!');
          if (this.imagenes.length === 0) {
            const fileInput = document.getElementById(
              'file_input'
            ) as HTMLInputElement;
            fileInput.value = '';
          }
          continue; // Saltar a la siguiente iteración si el archivo es demasiado grande
        }
        const imageUrl = URL.createObjectURL(file); // Obtén la URL temporal
        const guardarFileyURL = { file: file, url: imageUrl };

        // Verificar si la imagen ya está en la lista
        const existingImage = this.imagenes.find(
          (img: any) => img.file.name === file.name
        );
        if (existingImage) {
          alert('¡Imagen repetida!');
        } else if (this.imagenes.length >= 5) {
          alert('¡Ya has alcanzado el límite de 5 imágenes!');
          break; // Salir del bucle si se alcanza el límite
        } else {
          this.imagenes.push(guardarFileyURL);
        }
      }
    }
  }

  eliminarImagen(url: string) {
    const index = this.imagenes.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.imagenes.splice(index, 1);
    }
    if (this.imagenes.length === 0) {
      const fileInput = document.getElementById(
        'file_input'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  linkimagen: string = '';
  modalimg: boolean = false;
  verimagen(link: string) {
    this.linkimagen = link;
    this.modalimg = !this.modalimg;
  }
  cerrarmodalimg() {
    this.modalimg = !this.modalimg;
  }

  videosFiles: any = [];
  // videos

  lastSelectedFiles3 : any
  changevideosFiles(e: any) {
    
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles3 = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles3) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles3.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles3[i]);
        }
        input.files = dataTransfer.files;
      }
    }


    for (let i = 0; i < files.length; i++) {
      const file = files[i];

      // Verificar si el archivo no supera los 10 MB
      const fileSizeInMB = file.size / (1024 * 1024);
      if (fileSizeInMB > 30) {
        alert('¡El tamaño de la imagen no debe superar los 30 MB!');
        if (this.videosFiles.length === 0) {
          const fileInput = document.getElementById(
            'file_input_videos'
          ) as HTMLInputElement;
          fileInput.value = '';
        }
        continue; // Saltar a la siguiente iteración si el archivo es demasiado grande
      }

      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataVideo = this.videosFiles.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      if (dataVideo) {
        alert('Video repetido!');
      } else if (this.videosFiles.length >= 5) {
        alert('¡Ya has alcanzado el límite de 5 videos!');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.videosFiles.push(guardarFileyURL);
      }
    }
  }

  removeVideo(url: string) {
    console.log(url);
    const index = this.videosFiles.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.videosFiles.splice(index, 1);
    }
    if (this.videosFiles.length === 0) {
      const fileInput = document.getElementById(
        'file_input_videos'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  linkVideo: string = '';
  modalVideo: boolean = false;
  verVideo(link: string) {
    this.linkVideo = link;
    this.modalVideo = !this.modalVideo;
  }
  cerrarmodalVideo() {
    this.modalVideo = !this.modalVideo;
  }

  aceptoCliente: any;

  aceptoTerminos(event: any) {
    console.log(event.target.value);
    this.aceptoCliente = event.target.value;
  }

  repuestos: string = '';
  repuestosCliente(event: any) {
    console.log(event.target.value);
    this.repuestos = event.target.value;
  }

  garantiaconfirmada: any;
  garantia(event: any) {
    console.log(event.target.value);
    this.garantiaconfirmada = event.target.value;
  }

  archivosPdf: any[] = [];
  lastSelectedFiles4 : any
  changePdf(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles4 = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles4) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles4.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles4[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      if (dataPdf) {
        alert('PDF repetido!');
      } else if (this.archivosPdf.length === 1) {
        alert('Solo se Admite un pdf');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf.push(guardarFileyURL);
      }
    }
  }

  removePdf(url: string) {
    const index = this.archivosPdf.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf.splice(index, 1);
    }

    if (this.archivosPdf.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  lastSelectedFiles: any

  archivosPdf2: any[] = [];
  changePdf2(e: any) {
    const files = e.target.files;

    const input = e.target;
    if (input.files && input.files.length > 0) {
      // Almacenar los archivos seleccionados
      this.lastSelectedFiles = input.files;
    } else {
      // Restaurar los archivos seleccionados anteriormente si no se seleccionan nuevos archivos
      if (this.lastSelectedFiles) {
        const dataTransfer = new DataTransfer();
        for (let i = 0; i < this.lastSelectedFiles.length; i++) {
          dataTransfer.items.add(this.lastSelectedFiles[i]);
        }
        input.files = dataTransfer.files;
      }
    }

    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      const guardarFileyURL = { file: file, url: URL.createObjectURL(file) };

      const dataPdf = this.archivosPdf2.find(
        (data: any) => data.file.name.toLowerCase() === file.name.toLowerCase()
      );
      if (dataPdf) {
        alert('PDF repetido!');
      } else if (this.archivosPdf2.length === 5) {
        alert('Solo se Admite 5 pdfs');
        break; // Salir del bucle si se alcanza el límite
      } else {
        this.archivosPdf2.push(guardarFileyURL);
      }
    }
  }

  removePdf2(url: string) {
    console.log(url);
    const index = this.archivosPdf2.findIndex((item: any) => item.url === url);
    if (index !== -1) {
      this.archivosPdf2.splice(index, 1);
    }

    if (this.archivosPdf2.length === 0) {
      const fileInput = document.getElementById(
        'file_input_pdf2'
      ) as HTMLInputElement;
      fileInput.value = '';
    }
  }

  //
  mostrarDatosImpresora: boolean = false;

  esImpresora(event: any) {
    console.log(event);
    const valor = event.target.checked;
    this.mostrarDatosImpresora = !!valor; // Convierte el valor a booleano
  }

  validarTiempoDeLlegadadeRepuestos(event: any) {
    const inputValue = event.target.value;
    const numericValue = inputValue.replace(/\D/g, ''); // Elimina caracteres no numéricos
    const truncatedValue = numericValue.substring(0, 2); // Limita la longitud a 8 dígitos
    event.target.value = truncatedValue; // Actualiza el valor del input
  }

  fechaenvio: any;
  horaenvio: any;
  observaciones: any;
  loading: boolean = false;

  tiempoesperaRepuestos: any;

  enviarDatos(e: any) {
    e.preventDefault();
    this.loading = true;
  
    // Mostrar Swal solo si loading es true
    if (this.loading) {
      Swal.fire({
        title: 'Guardando',
        html: `
          <style>
            .spinner {
              border: 4px solid rgba(0, 0, 0, 0.1);
              width: 36px;
              height: 36px;
              border-radius: 50%;
              border-left-color: #09f;
              animation: spin 1s linear infinite;
              display: inline-block;
              margin-top: 10px;
            }
        
            @keyframes spin {
              0% {
                transform: rotate(0deg);
              }
              100% {
                transform: rotate(360deg);
              }
            }
          </style>
          <div>Se está guardando la información, por favor espera...</div>
          <div class="spinner"></div>
        `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        showCloseButton: false,
        timerProgressBar: true,
      });
    }
  
    const formData = new FormData(e.target);
    const mediaFiles = [...this.imagenes, ...this.videosFiles];
    this.tiempoesperaRepuestos = formData.get('tiemporepuestos');
  
    // Agregar archivos PDF al FormData
    for (let i = 0; i < this.archivosPdf2.length; i++) {
      formData.append('pdf[]', this.archivosPdf2[i].file, this.archivosPdf2[i].file.name);
    }
  
    // Agregar archivos de media al FormData
    for (let i = 0; i < mediaFiles.length; i++) {
      formData.append('media[]', mediaFiles[i].file, mediaFiles[i].file.name);
    }
  
    // Agregar IDs de fallas al FormData
    for (let i = 0; i < this.arregloPuroId.length; i++) {
      formData.append('fallasId[]', this.arregloPuroId[i]);
    }
  
    // Agregar el ID de seguimiento al FormData
    if (this.seguimientoetapa3 && this.seguimientoetapa3.length > 0) {
      formData.append('seguimientoId', String(this.seguimientoetapa3[0].idSeguimiento));
    }
  
    const url = import.meta.env.NG_APP_API + '/diagnostico';
  
    this.dataService.postApi(url, formData).subscribe({
      next: (data) => {
        const fecha = new Date();
        const dia = fecha.getUTCDate();
        const mes = fecha.getUTCMonth() + 1;
        const anio = fecha.getUTCFullYear();
  
        const fechaFormateada = `${anio}-${mes < 10 ? '0' + mes : mes}-${dia < 10 ? '0' + dia : dia}`;
        const hora = fecha.getUTCHours();
        const minuto = fecha.getUTCMinutes();
        const segundo = fecha.getUTCSeconds();
        const milisegundo = fecha.getUTCMilliseconds();
  
        const horaFormateada = `${hora < 10 ? '0' + hora : hora}:${minuto < 10 ? '0' + minuto : minuto}:${segundo < 10 ? '0' + segundo : segundo}.${milisegundo}`;
  
        this.fechaenvio = fechaFormateada;
        this.horaenvio = horaFormateada;
  
        if (this.garantiaconfirmada === 'SI') {
          if (this.repuestos === 'SI') {
            this.actualizarSeguimiento('Pedido');
          } else {
            this.actualizarSeguimiento('Completado');
          }
        } else if (this.garantiaconfirmada === 'NO') {
          this.actualizarSeguimiento('Finalizado');
        } else {
          this.actualizarSeguimiento('Completado');
        }
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
  

  actualizarCasos(estadoActualizar: string) {
    const formData = new FormData();
    formData.append('idCliente', this.casosActualizar.cliente.id);
    formData.append('tipoServicio', this.casosActualizar.tipoServicio);
    formData.append('descripcion', this.casosActualizar.descripcion);
    formData.append('observaciones', this.casosActualizar.observaciones);
    formData.append('numeroCaso', this.casosActualizar.numeroCaso);
    formData.append('numSerie', this.casosActualizar.numeroSerie);
    formData.append('calificacion', '');
    

    if(this.estadoGarantia === 'false'){
      formData.append('etapa', '2');
    }
    else{
      formData.append('etapa', '3');
    }

    formData.append('estadoCaso', estadoActualizar);
    formData.append('aceptoTerminos', 'True');
    formData.append('ordenServicio', this.casosActualizar.ordenServicio);
    formData.append('idEquipo', this.casosActualizar.equipo.id);
    formData.append(
      'idUsuarioAsignado',
      this.casosActualizar.usuarioAsignado.id
    );
    formData.append('proximoMantenimiento', '');
    formData.append('idPrioridadAtencion', this.casosActualizar.idPrioridad);
    formData.append('garantia', this.casosActualizar.garantia);
    formData.append('idSucursal', this.casosActualizar.sucursal.id);
    formData.append(
      'periodoGarantiaMeses',
      this.casosActualizar.periodoGarantiaMeses
    );
    formData.append('areaPerteneciente', this.casosActualizar.areaPerteneciente || '');
    formData.append('usuarioRegistro', this.casosActualizar.usuarioRegistro || '');

    const url = import.meta.env.NG_APP_API + '/casos/' + this.idCaso;
    this.dataService.putApi(url, formData).subscribe({
      next: (response) => {
        Swal.fire({
          title: '¡Éxito!',
          text: 'Se registro exitosamente.',
          icon: 'success',
          confirmButtonText: 'Aceptar',
          allowOutsideClick: false,
          allowEscapeKey: false,
          timerProgressBar: true,
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  // Función de actualizar seguimiento

  actualizarSeguimiento(estadoActualizar: string) {
    const formData = new FormData();
    formData.append('idCaso', String(this.idCaso));
    formData.append('idEtapa', '3');
    formData.append(
      'llegadaDiasRepuesto',
      this.tiempoesperaRepuestos != null ? this.tiempoesperaRepuestos : '0'
    );

    formData.append(
      'nroCasoMarca',
      'EL NUMERO DE CASO YA ESTA REGISTRADO EN LA ETAPA 2'
    );
    formData.append(
      'descripcion',
      'SE HA REGISTRADO CORRECTAMENTE EL DIAGNOSTICO DEL EQUIPO'
    );
    formData.append(
      'observacion',
      'EN ESTA ETAPA SE REGISTRO TODO LOS DATOS DEL DIAGNOSTICO DEL EQUIPO'
    );
    formData.append(
      'repuestos',
      this.repuestos === 'SI'
        ? 'SI SE NECESITARON REPUESTOS, SE HA SOLICITADO AL CAS LOS REPUESTOS NECESARIOS'
        : 'NO SE NECESITARON REPUESTOS PARA ESTE CASO'
    );
    formData.append('conformidadDeServicio', 'NO HAY REGISTRO TODAVIA DE ESTO');
    formData.append('fechaInicio', this.fechaFIn);
    formData.append('fechaFin', this.fechaenvio);
    formData.append('horaInicio', this.horaFin);
    formData.append('horaFin', this.horaenvio);
    formData.append('estadoSeguimiento', estadoActualizar);

    // Si se necesitan repuestos, adjunta los archivos PDF al FormData
    if (this.repuestos === 'SI') {
      for (let i = 0; i < this.archivosPdf.length; i++) {
        formData.append(
          'pdf[]',
          this.archivosPdf[i].file,
          this.archivosPdf[i].file.name
        );
      }
    }

    // Construye la URL para la solicitud PUT
    const url =
      import.meta.env.NG_APP_API +
      '/seguimiento/' +
      this.seguimientoetapa3[0].idSeguimiento;

    // Realiza la solicitud PUT a la API
    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        console.log(this.garantiaconfirmada, this.repuestos);
        // Maneja la respuesta de la API
        if (this.garantiaconfirmada === 'SI') {
          if (this.repuestos === 'SI') {
            this.actualizarCasos('Pedido');
          } else if (this.repuestos === 'NO') {
            this.actualizarCasos('Completado');
          }
        } else if (this.garantiaconfirmada === 'NO') {
          this.actualizarCasos('Finalizado');
        } else {
          if (this.repuestos === 'SI') {
            this.actualizarCasos('Completado');
          } else if (this.repuestos === 'NO') {
            this.actualizarCasos('Completado');
          }
        }
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  encasoNoAcepteElCliente() {
    this.loading = true;
    if (this.loading) {
      Swal.fire({
        title: 'Guardando',
        html: `
          <style>
            .spinner {
              border: 4px solid rgba(0, 0, 0, 0.1);
              width: 36px;
              height: 36px;
              border-radius: 50%;
              border-left-color: #09f;
              animation: spin 1s linear infinite;
              display: inline-block;
              margin-top: 10px;
            }
      
            @keyframes spin {
              0% {
                transform: rotate(0deg);
              }
              100% {
                transform: rotate(360deg);
              }
            }
          </style>
          <div>Se está guardando la información, por favor espera...</div>
          <div class="spinner"></div>
        `,
        icon: 'info',
        allowOutsideClick: false,
        allowEscapeKey: false,
        showConfirmButton: false,
        showCancelButton: false,
        showCloseButton: false,
        timerProgressBar: true,
      });
      const fecha = new Date();
      const dia = fecha.getUTCDate();
      const mes = fecha.getUTCMonth() + 1; // Los meses comienzan desde 0
      const anio = fecha.getUTCFullYear();

      // Formatear la fecha
      const fechaFormateada = `${anio}-${mes < 10 ? '0' + mes : mes}-${
        dia < 10 ? '0' + dia : dia
      }`;

      // Obtener la hora en formato de 24 horas
      const hora = fecha.getUTCHours();
      const minuto = fecha.getUTCMinutes();
      const segundo = fecha.getUTCSeconds();
      const milisegundo = fecha.getUTCMilliseconds();

      // Formatear la hora
      const horaFormateada = `${hora < 10 ? '0' + hora : hora}:${
        minuto < 10 ? '0' + minuto : minuto
      }:${segundo < 10 ? '0' + segundo : segundo}.${milisegundo}`;

      // Asignar los valores de fecha y hora obtenidos al objeto
      this.fechaenvio = fechaFormateada;
      this.horaenvio = horaFormateada;
    }
    this.actualizarSeguimiento('Rechazado');
    this.actualizarCasos('Rechazado');
  }
}
