import { Component, ElementRef, EventEmitter, Output, ViewChild, inject } from '@angular/core';
import { FormBuilder, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../../core/service/service.service';

@Component({
  selector: 'app-postfallas2',
  standalone: true,
  imports: [ReactiveFormsModule],
  templateUrl: './postfallas2.component.html',
  styleUrl: './postfallas2.component.css'
})
export class Postfallas2Component {

  frmFallas: FormGroup;
  apiService = inject(ServiceService);
  url = import.meta.env.NG_APP_API + '/fallas';
  loading: boolean = false;

  @Output() Completed = new EventEmitter<any>();
 
  @ViewChild('cerrarBoton') cerrarBotonRef!: ElementRef;

  constructor(private formbuild: FormBuilder) {
    this.frmFallas = this.formbuild.group({
      codigoFalla: ['', [Validators.required, Validators.maxLength(10)]],
      descripcion: ['', [Validators.required, Validators.maxLength(100)]],
    });
  }
  hasErrors(controlName: string, errorType: string) {
    return (
      this.frmFallas.get(controlName)?.hasError(errorType) &&
      this.frmFallas.get(controlName)?.touched
    );
  }
  cerrarModal: any
  ngOnInit(): void {
    initFlowbite();
  }
  refreshform() {
    this.frmFallas.reset();
  }



  registrar() {
    this.loading = true;
    if (this.frmFallas.invalid) {
      this.frmFallas.markAllAsTouched();
      this.loading = false;
      Swal.fire({
        title: 'Error',
        text: 'Por favor, llene todos los campos.',
        icon: 'error',
        confirmButtonText: 'OK',
      });
      return;
    }

   

    this.apiService.postApi(this.url, this.frmFallas.value).subscribe({
      next: (data) => {
        this.loading = false;
        this.Completed.emit(true)
        Swal.fire({
          title: 'Success',
          text: 'Falla registrada exitosamente!',
          icon: 'success',
          confirmButtonText: 'OK',
          allowOutsideClick: false, // Desactiva el cierre al hacer clic fuera de la alerta
        }).then((result) => {
          if (result.isConfirmed) {
            this.frmFallas.reset();
            this.refreshform()
             // Simular clic en el botón 'cerrarBoton'
             this.cerrarBotonRef.nativeElement.click();
 
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
