import { Component, Input } from '@angular/core';
import { initFlowbite } from 'flowbite';
import Swal from 'sweetalert2';
import { ServiceService } from '../../../core/service/service.service';
import { CommonModule } from '@angular/common';
import { MostraraceptarterminosComponent } from '../mostraraceptarterminos/mostraraceptarterminos.component';

@Component({
  selector: 'app-formularioconformidad',
  standalone: true,
  imports: [CommonModule, MostraraceptarterminosComponent],
  templateUrl: './formularioconformidad.component.html',
  styleUrl: './formularioconformidad.component.css',
})
export class FormularioconformidadComponent {
  constructor(private dataService: ServiceService) {}
  @Input() datos: any = {}; // Cambiado de any[] a any
  seguimientoetapa6: any[] = [];
  idCaso: number = 0;
  respuesto: string = '';

  casosActualizar: any;

  estadoGarantia: any;

  ngOnInit(): void {
    initFlowbite();
    if (this.datos && this.datos.caso) {
      this.casosActualizar = this.datos.caso;

      this.estadoGarantia = this.datos.caso.garantia;

      this.idCaso = this.datos.caso.id;
      this.seguimientoetapa6 = this.datos.seguimientos.filter(
        (item: any) => item.etapa.id === 6
      );
    }
  }

  mostrarEstrellas = false;

  check(e: any) {
    if (e.target.checked) {
      this.mostrarEstrellas = true;
      console.log(this.mostrarEstrellas);
    } else {
      this.mostrarEstrellas = false;
      console.log(this.mostrarEstrellas);
    }
  }

  // CARDS DE ESTRELLAS DE LA ETAPA 7
  rating = 0;
  hovered = 0;
  stars = [
    { value: 0, icon: 'star' },
    { value: 1, icon: 'star' },
    { value: 2, icon: 'star' },
    { value: 3, icon: 'star' },
    { value: 4, icon: 'star' },
  ];

  rate(rating: number) {
    console.log(rating);
    this.rating = rating;
  }

  hover(index: number) {
    this.hovered = index;
  }

  //

  fechaenvio: string = '';
  horaenvio: string = '';
  loading: boolean = false;
  clickResponder(e: any) {
    e.preventDefault();
    if (this.rating === 0) {
      // Show alert if no star is selected
      Swal.fire({
        title: 'La calificacion es requerida',
        text: 'Por favor, califique nuestro servicio con las estrellas',
        icon: 'info',
        confirmButtonText: 'Entendido',
      });
    } else {
      this.loading = true;
      if (this.loading) {
        Swal.fire({
          title: '¡Muchas gracias por confiar en nosotros!',
          html: `
          <style>
            .spinner {
              border: 4px solid rgba(0, 0, 0, 0.1);
              width: 36px;
              height: 36px;
              border-radius: 50%;
              border-left-color: #09f;
              animation: spin 1s linear infinite;
              display: inline-block;
              margin-top: 10px;
            }
      
            @keyframes spin {
              0% {
                transform: rotate(0deg);
              }
              100% {
                transform: rotate(360deg);
              }
            }
          </style>
          <div>Esperamos volver a verte pronto.</div>
          <div class="spinner"></div>
        `,
          icon: 'info',
          allowOutsideClick: false,
          allowEscapeKey: false,
          showConfirmButton: false,
          showCancelButton: false,
          showCloseButton: false,
          timerProgressBar: true,
        });
      }
      const fecha = new Date();
      const dia = fecha.getUTCDate();
      const mes = fecha.getUTCMonth() + 1; // Los meses comienzan desde 0
      const anio = fecha.getUTCFullYear();

      // Formatear la fecha
      const fechaFormateada = `${anio}-${mes < 10 ? '0' + mes : mes}-${
        dia < 10 ? '0' + dia : dia
      }`;

      // Obtener la hora en formato de 24 horas
      const hora = fecha.getUTCHours();
      const minuto = fecha.getUTCMinutes();
      const segundo = fecha.getUTCSeconds();
      const milisegundo = fecha.getUTCMilliseconds();

      // Formatear la hora
      const horaFormateada = `${hora < 10 ? '0' + hora : hora}:${
        minuto < 10 ? '0' + minuto : minuto
      }:${segundo < 10 ? '0' + segundo : segundo}.${milisegundo}`;

      // Asignar los valores de fecha y hora obtenidos al objeto
      this.fechaenvio = fechaFormateada;
      this.horaenvio = horaFormateada;

      // Enviar los datos al servidor una vez que se hayan obtenido fecha y hora
      this.actualizar();
    }
  }

  actualizar() {
    const formData = new FormData();
    formData.append('idCliente', this.casosActualizar.cliente.id);
    formData.append('tipoServicio', this.casosActualizar.tipoServicio);
    formData.append('descripcion', this.casosActualizar.descripcion);
    formData.append('observaciones', this.casosActualizar.observaciones);
    formData.append('numeroCaso', this.casosActualizar.numeroCaso);
    formData.append('numSerie', this.casosActualizar.numeroSerie);
    formData.append('calificacion', this.rating.toString());
    if (this.estadoGarantia === 'false') {
      formData.append('etapa', '5');
    } else {
      formData.append('etapa', '6');
    }
    formData.append('estadoCaso', 'Finalizado');
    formData.append('aceptoTerminos', 'True');
    formData.append('ordenServicio', this.casosActualizar.ordenServicio);
    formData.append('idEquipo', this.casosActualizar.equipo.id);
    formData.append(
      'idUsuarioAsignado',
      this.casosActualizar.usuarioAsignado.id
    );
    formData.append(
      'proximoMantenimiento',
      this.casosActualizar.proximoMantenimiento
    );
    formData.append('idPrioridadAtencion', this.casosActualizar.idPrioridad);
    formData.append('garantia', this.casosActualizar.garantia);
    formData.append('idSucursal', this.casosActualizar.sucursal.id);
    formData.append(
      'periodoGarantiaMeses',
      this.casosActualizar.periodoGarantiaMeses
    );
    formData.append('areaPerteneciente', this.casosActualizar.areaPerteneciente || '');
    formData.append('usuarioRegistro', this.casosActualizar.usuarioRegistro || '');

    const url = `${import.meta.env.NG_APP_API}/casos/${this.idCaso}`;
    this.dataService.putApi(url, formData).subscribe({
      next: (response) => {
        this.enviarDatosAlServidor();
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }

  enviarDatosAlServidor() {
    const formData = new FormData();

    formData.append('idCaso', String(this.idCaso));
    formData.append('idEtapa', '6');
    formData.append('nroCasoMarca', 'no aplica para este caso');
    formData.append(
      'descripcion',
      'EL CLIENTE ACEPTO LA CONFORMIDAD DE LOS SERVICIOS'
    );
    formData.append(
      'observacion',
      'EL CLIENTE ACEPTO LA CONFORMIDAD DE LOS SERVICIOS'
    );
    formData.append('repuestos', 'NO APLICA PARA ESTA ETAPA');
    formData.append(
      'conformidadDeServicio',
      'EL CLIENTE ACEPTO LA CONFORMIDAD DE LOS SERVICIOS'
    );
    formData.append('fechaInicio', this.seguimientoetapa6[0].fechaFin);
    formData.append('fechaFin', this.fechaenvio);
    formData.append('horaInicio', this.seguimientoetapa6[0].horaFin);
    formData.append('horaFin', this.horaenvio);
    formData.append('estadoSeguimiento', 'Completado');
    formData.append('calificacion', this.rating.toString());

    const url =
      import.meta.env.NG_APP_API +
      '/seguimiento/' +
      this.seguimientoetapa6[0].idSeguimiento;

    this.dataService.putApi(url, formData).subscribe({
      next: (data) => {
        Swal.fire({
          title: '¡Éxito!',
          text: 'Se ha registrado correctamente la conformidad de servicios',
          icon: 'success',
          confirmButtonText: 'Aceptar',
          allowOutsideClick: false,
          allowEscapeKey: false,
          timerProgressBar: true,
        }).then((result) => {
          if (result.isConfirmed) {
            window.location.reload();
          }
        });
      },
      error: (error) => {
        this.loading = false;
        let errorMessage = 'Algo salió mal';
        if (error.error && error.error.message) {
          errorMessage = error.error.message;
        }

        Swal.fire({
          title: 'Error',
          text: errorMessage,
          icon: 'error',
          confirmButtonText: 'OK',
        });
      },
    });
  }
}
